DROP TABLE Antifoul;

CREATE TABLE Antifoul (
   Net_No varchar(20) NOT NULL,
   Cage_Size varchar(10) NOT NULL,
   Date_Antifouled varchar(10) NOT NULL,
   Anitfouled_type varchar(100) NULL,
   Net_Growth numeric(10,2) NULL,
   Anti_Qty numeric(10,2) NULL,
   Qty_Thinners numeric(10,2) NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Antifoul_Net_No ON Antifoul (Net_No,Cage_Size,Date_Antifouled);

DROP TABLE Asset;

CREATE TABLE Asset (
   Asset_No integer NOT NULL,
   Asset_Name varchar(120) NOT NULL,
   Purchase_Date varchar(10) NOT NULL,
   Org_Amt numeric(10,2) NOT NULL,
   Detail_Description varchar(250) NULL
);

CREATE UNIQUE CLUSTERED INDEX Asset_Asset_No ON Asset (Asset_No,Asset_Name);

CREATE INDEX Asset_Purchase_Date ON Asset (Purchase_Date);

DROP TABLE Asset_Item;

CREATE TABLE Asset_Item (
   Asset_No integer NOT NULL,
   Asset_Name varchar(120) NOT NULL,
   Asset_Item varchar(100) NOT NULL,
   Purchase_Date varchar(10) NOT NULL,
   Purchase_Amt numeric(10,2) NOT NULL,
   Detail_Description varchar(250) NULL
);

CREATE UNIQUE CLUSTERED INDEX Asset_Item_Asset_No ON Asset_Item (Asset_No,Asset_Name,Asset_Item);

CREATE INDEX Asset_Item_Purchase_Date ON Asset_Item (Purchase_Date);

DROP TABLE Assigned_Fish_Category;

CREATE TABLE Assigned_Fish_Category (
   Fish_Id varchar(10) NOT NULL,
   Date_Assigned varchar(10) NOT NULL,
   Category_Name varchar(70) NOT NULL,
   Calendar_Year integer NOT NULL,
   Date_Unassigned varchar(10) NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Assigned_Fish_Category_Fish_Id ON Assigned_Fish_Category (Fish_Id,Date_Assigned,Category_Name,Calendar_Year);

DROP TABLE Bath_Cage;

CREATE TABLE Bath_Cage (
   Job_No integer NOT NULL,
   Job_Date varchar(10) NOT NULL,
   EFPB varchar(10) NOT NULL,
   Bath_Cage varchar(4) NULL,
   EFTGIL integer NULL,
   Grade_Type varchar(15) NULL,
   Est_Avg_Weight numeric(10,2) NULL,
   Liner_Size integer NOT NULL,
   Bath_Equipment varchar(20) NULL,
   Water_Source varchar(20) NULL,
   Bath_Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Bath_Cage_Job_No ON Bath_Cage (Job_No,Job_Date,EFPB);

CREATE INDEX Bath_Cage_Liner_Size ON Bath_Cage (Liner_Size);

DROP TABLE Bath_Grade;

CREATE TABLE Bath_Grade (
   Job_No integer NOT NULL,
   Job_Date varchar(10) NOT NULL,
   Src_Fish_Id varchar(10) NOT NULL,
   Fish_Count integer NULL,
   Src_Cage_Id varchar(10) NULL,
   Src_Date_Assigned varchar(10) NULL,
   Action_Performed varchar(30) NOT NULL,
   AGD_Severity varchar(20) NULL,
   LH_Name varchar(20) NOT NULL,
   Sug_Len_Time_Bath numeric(4,0) NULL,
   No_Prev_Baths integer NULL,
   No_Prev_Grades integer NULL,
   Comment varchar(200) NULL,
   Sug_Grader_Bar varchar(10) NULL,
   No_Big_Fish integer NULL,
   Grade_Scale varchar(15) NULL,
   Mature_Fish varchar(4) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Bath_Grade_Job_No ON Bath_Grade (Job_No,Job_Date);

CREATE INDEX Bath_Grade_Src_Fish_Id ON Bath_Grade (Src_Fish_Id);

CREATE INDEX Bath_Grade_LH_Name ON Bath_Grade (LH_Name);

DROP TABLE Bath_Grade_Completion;

CREATE TABLE Bath_Grade_Completion (
   Job_No integer NOT NULL,
   Job_Date varchar(10) NOT NULL,
   Date_Bathed varchar(10) NOT NULL,
   Dest_Fish_Id varchar(10) NOT NULL,
   Dest_Fish_Count integer NULL,
   Dest_Cage_Id varchar(10) NULL,
   Dest_Date_Assigned varchar(10) NULL,
   Expect_Swim_Fish_Id varchar(10) NULL,
   Completed_Grade_Type varchar(15) NULL,
   No_Fish_In integer NULL,
   Time_Fish_In varchar(8) NULL,
   Time_Fish_Out varchar(8) NULL,
   Time_in_Bath varchar(8) NULL,
   Net_No_In varchar(20) NULL,
   Net_No_Out varchar(20) NULL,
   Weather varchar(150) NULL,
   Comments varchar(200) NULL,
   Bath_Crew varchar(100) NULL,
   Src_Fish_Id varchar(10) NOT NULL,
   Src_Cage_Id varchar(10) NULL,
   Src_Date_Assigned varchar(10) NULL,
   CTIB varchar(8) NULL,
   CTOB varchar(8) NULL,
   DOMU varchar(30) NULL,
   DOMC numeric(4,0) NULL,
   DOMCheck varchar(4) NULL,
   Dissolver varchar(4) NULL,
   NoDRack numeric(3,0) NULL,
   OUCrowd varchar(4) NULL,
   CMethod varchar(15) NULL,
   C1_Start varchar(8) NULL,
   CEnd1 varchar(8) NULL,
   CStart2 varchar(8) NULL,
   CEnd2 varchar(8) NULL,
   CStart3 varchar(8) NULL,
   CEnd3 varchar(8) NULL,
   CStart4 varchar(8) NULL,
   CEnd4 varchar(8) NULL,
   CStart5 varchar(8) NULL,
   CEnd5 varchar(8) NULL,
   CRComment varchar(200) NULL,
   Ct_Count integer NULL,
   Ct_Accurate varchar(4) NULL,
   Ct_Calib varchar(4) NULL,
   MC_Check varchar(4) NULL,
   CFWeight numeric(5,0) NULL,
   Ct_Speed varchar(11) NULL,
   Fish_No_Adjust varchar(4) NULL,
   AUB varchar(20) NULL,
   BWT_Start numeric(5,2) NULL,
   BWT_End numeric(5,2) NULL,
   O_Start varchar(10) NULL,
   O_End varchar(10) NULL,
   Salinity_Start varchar(10) NULL,
   Salinity_End varchar(10) NULL,
   SW_Temp numeric(5,2) NULL,
   Seawater_Oxygen varchar(10) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Bath_Grade_Completion_Job_No ON Bath_Grade_Completion (Job_No,Job_Date,Date_Bathed,Dest_Fish_Id);

CREATE INDEX Bath_Grade_Completion_Expect_Swim_Fish_Id ON Bath_Grade_Completion (Expect_Swim_Fish_Id);

CREATE INDEX Bath_Grade_Completion_Src_Fish_Id ON Bath_Grade_Completion (Src_Fish_Id);

DROP TABLE Budget_Sale;

CREATE TABLE Budget_Sale (
   Name varchar(30) NOT NULL,
   Budget_Year integer NOT NULL,
   Stock_Item varchar(20) NOT NULL,
   Comment varchar(200) NULL,
   Stock_Name varchar(40) NULL,
   Item_Type_Name varchar(20) NULL
);

CREATE UNIQUE CLUSTERED INDEX Budget_Sale_Name ON Budget_Sale (Name,Budget_Year,Stock_Item);

DROP TABLE Budget_Weeks;

CREATE TABLE Budget_Weeks (
   Name varchar(30) NOT NULL,
   Budget_Year integer NOT NULL,
   Stock_Item varchar(20) NOT NULL,
   Start_Date varchar(10) NOT NULL,
   End_Date varchar(10) NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Tdummy4 char(1) NULL,
   Prem_No_Carton integer NULL,
   Prem_Fish_No integer NULL,
   Prem_HOGG_Biomass numeric(10,2) NULL,
   Prem_Price numeric(10,2) NULL,
   Vaps_No_Carton integer NULL,
   Vaps_Fish_No integer NULL,
   Vaps_HOGG_Biomass numeric(10,2) NULL,
   Vaps_Price numeric(10,2) NULL,
   Export_No_Carton integer NULL,
   Export_Fish_No integer NULL,
   Export_HOGG_Biomass numeric(10,2) NULL,
   Export_Price numeric(10,2) NULL,
   Process_Form_1 varchar(15) NULL,
   Grade_1 varchar(15) NULL,
   Fish_No_1 integer NULL,
   No_Cartons_1 integer NULL,
   Biomass_1 numeric(10,2) NULL,
   Price_1 numeric(10,2) NULL,
   Process_Form_2 varchar(15) NULL,
   Grade_2 varchar(15) NULL,
   Fish_No_2 integer NULL,
   No_Cartons_2 integer NULL,
   Biomass_2 numeric(10,2) NULL,
   Price_2 numeric(10,2) NULL,
   Process_Form_3 varchar(15) NULL,
   Grade_3 varchar(15) NULL,
   Fish_No_3 integer NULL,
   No_Cartons_3 integer NULL,
   Biomass_3 numeric(10,2) NULL,
   Price_3 numeric(10,2) NULL,
   Process_Form_4 varchar(15) NULL,
   Grade_4 varchar(15) NULL,
   Fish_No_4 integer NULL,
   No_Cartons_4 integer NULL,
   Biomass_4 numeric(10,2) NULL,
   Price_4 numeric(10,2) NULL,
   Process_Form_5 varchar(15) NULL,
   Grade_5 varchar(15) NULL,
   Fish_No_5 integer NULL,
   No_Cartons_5 integer NULL,
   Biomass_5 numeric(10,2) NULL,
   Price_5 numeric(10,2) NULL,
   Process_Form_6 varchar(15) NULL,
   Grade_6 varchar(15) NULL,
   Fish_No_6 integer NULL,
   No_Cartons_6 integer NULL,
   Biomass_6 numeric(10,2) NULL,
   Price_6 numeric(10,2) NULL,
   Process_Form_7 varchar(15) NULL,
   Grade_7 varchar(15) NULL,
   Fish_No_7 integer NULL,
   No_Cartons_7 integer NULL,
   Biomass_7 numeric(10,2) NULL,
   Price_7 numeric(10,2) NULL,
   Process_Form_8 varchar(15) NULL,
   Grade_8 varchar(15) NULL,
   Fish_No_8 integer NULL,
   No_Cartons_8 integer NULL,
   Biomass_8 numeric(10,2) NULL,
   Price_8 numeric(10,2) NULL,
   Process_Form_9 varchar(15) NULL,
   Grade_9 varchar(15) NULL,
   Fish_No_9 integer NULL,
   No_Cartons_9 integer NULL,
   Biomass_9 numeric(10,2) NULL,
   Price_9 numeric(10,2) NULL,
   Process_Form_10 varchar(15) NULL,
   Grade_10 varchar(15) NULL,
   Fish_No_10 integer NULL,
   No_Cartons_10 integer NULL,
   Biomass_10 numeric(10,2) NULL,
   Price_10 numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Budget_Weeks_Name ON Budget_Weeks (Name,Budget_Year,Stock_Item,Start_Date);

DROP TABLE Cage;

CREATE TABLE Cage (
   Cage_Id varchar(10) NOT NULL,
   In_Use varchar(4) NULL,
   Cage_Size varchar(10) NOT NULL,
   Cage_Registration_No varchar(40) NULL,
   Year_Installed integer NULL,
   Comment varchar(200) NULL,
   Cost_Price numeric(10,2) NULL,
   Chained varchar(4) NULL,
   Inside_Collar numeric(10,2) NULL,
   Outside_Collar numeric(10,2) NULL,
   Cage_Type varchar(50) NULL
);

CREATE UNIQUE CLUSTERED INDEX Cage_Cage_Id ON Cage (Cage_Id);

DROP TABLE Cage_Assignment;

CREATE TABLE Cage_Assignment (
   Fish_Id varchar(10) NOT NULL,
   Cage_Id varchar(10) NOT NULL,
   Date_Assigned varchar(10) NOT NULL,
   Comment varchar(200) NULL,
   Swim_Off integer NULL,
   Swim_To integer NULL,
   Graded_From integer NULL,
   Graded integer NULL,
   Cage_Size varchar(10) NULL,
   Fish_Count integer NULL,
   Date_UnAssigned varchar(10) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Cage_Assignment_Fish_Id ON Cage_Assignment (Fish_Id,Cage_Id,Date_Assigned);

CREATE INDEX Cage_Assignment_Date_UnAssigned ON Cage_Assignment (Date_UnAssigned);

DROP TABLE Cage_Condition;

CREATE TABLE Cage_Condition (
   Fish_Id varchar(10) NOT NULL,
   Cage_Id varchar(10) NOT NULL,
   Date_Assigned varchar(10) NOT NULL,
   Date_Checked varchar(10) NOT NULL,
   Staff_Name varchar(30) NOT NULL,
   Site_Suitable varchar(15) NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Cage_Condition_Fish_Id ON Cage_Condition (Fish_Id,Cage_Id,Date_Assigned,Date_Checked);

DROP TABLE Cage_Net;

CREATE TABLE Cage_Net (
   Cage_Id varchar(10) NOT NULL,
   Cage_Size varchar(10) NULL,
   Net_No varchar(20) NOT NULL,
   Date_Installed varchar(10) NOT NULL,
   Comment varchar(200) NULL,
   Net_Use_Type varchar(15) NULL,
   Date_UnInstalled varchar(10) NULL,
   Uninstall_Location varchar(15) NULL,
   Prev_Days integer NULL
);

CREATE UNIQUE CLUSTERED INDEX Cage_Net_Cage_Id ON Cage_Net (Cage_Id,Net_No,Date_Installed);

CREATE INDEX Cage_Net_Date_UnInstalled ON Cage_Net (Date_UnInstalled);

DROP TABLE Cage_Net_History;

CREATE TABLE Cage_Net_History (
   Cage_Id varchar(10) NOT NULL,
   Cage_Size varchar(10) NULL,
   Net_No varchar(20) NOT NULL,
   Date_Installed varchar(10) NOT NULL,
   Comment varchar(200) NULL,
   Net_Use_Type varchar(15) NULL,
   Date_UnInstalled varchar(10) NULL
);

CREATE UNIQUE CLUSTERED INDEX Cage_Net_History_Cage_Id ON Cage_Net_History (Cage_Id,Net_No,Date_Installed);

CREATE INDEX Cage_Net_History_Date_UnInstalled ON Cage_Net_History (Date_UnInstalled);

DROP TABLE Carrier;

CREATE TABLE Carrier (
   Name varchar(30) NOT NULL,
   Contact varchar(30) NULL,
   Address varchar(50) NULL,
   Suburb varchar(30) NULL,
   State varchar(10) NULL,
   Postcode numeric(6,0) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Mobile_No varchar(15) NULL,
   Email varchar(50) NULL,
   Sales_Tax varchar(10) NULL,
   ABN varchar(20) NULL,
   Abbrev_Name varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Carrier_Name ON Carrier (Name);

DROP TABLE Carrier_Freight;

CREATE TABLE Carrier_Freight (
   Carrier_Name varchar(30) NOT NULL,
   Date_From varchar(10) NOT NULL,
   Cart_Price numeric(10,2) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Carrier_Freight_Carrier_Name ON Carrier_Freight (Carrier_Name,Date_From);

DROP TABLE Carton_Weight;

CREATE TABLE Carton_Weight (
   Create_Date varchar(10) NOT NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Jan_hogg numeric(10,2) NULL,
   Jan_Fish integer NULL,
   Feb_hogg numeric(10,2) NULL,
   Feb_Fish integer NULL,
   Mar_hogg numeric(10,2) NULL,
   Mar_Fish integer NULL,
   Apr_hogg numeric(10,2) NULL,
   Apr_Fish integer NULL,
   May_hogg numeric(10,2) NULL,
   May_Fish integer NULL,
   Jun_hogg numeric(10,2) NULL,
   Jun_Fish integer NULL,
   Jul_hogg numeric(10,2) NULL,
   Jul_Fish integer NULL,
   Aug_hogg numeric(10,2) NULL,
   Aug_Fish integer NULL,
   Sep_hogg numeric(10,2) NULL,
   Sep_Fish integer NULL,
   Oct_hogg numeric(10,2) NULL,
   Oct_Fish integer NULL,
   Nov_hogg numeric(10,2) NULL,
   Nov_Fish integer NULL,
   Dec_hogg numeric(10,2) NULL,
   Dec_Fish integer NULL
);

CREATE UNIQUE CLUSTERED INDEX Carton_Weight_Create_Date ON Carton_Weight (Create_Date);

DROP TABLE Change_Start_Weight;

CREATE TABLE Change_Start_Weight (
   Fish_Id varchar(10) NOT NULL,
   Change_Date varchar(10) NOT NULL,
   Change_Weight numeric(10,2) NOT NULL,
   Fish_No integer NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Change_Start_Weight_Fish_Id ON Change_Start_Weight (Fish_Id,Change_Date);

DROP TABLE Company;

CREATE TABLE Company (
   Name varchar(30) NOT NULL,
   Report_by varchar(4) NOT NULL,
   Contact varchar(30) NULL,
   Address varchar(50) NULL,
   Suburb varchar(30) NULL,
   State varchar(10) NULL,
   Postcode numeric(6,0) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL,
   Sales_Tax varchar(10) NULL,
   ABN varchar(15) NULL,
   ACN varchar(15) NULL,
   Web_Site varchar(40) NULL,
   Comment varchar(200) NULL,
   Post_Address varchar(50) NULL,
   Post_Address2 varchar(50) NULL,
   Post_Suburb varchar(30) NULL,
   Post_State varchar(10) NULL,
   Post_Postcode numeric(6,0) NULL,
   Tdummy1 char(1) NULL,
   CO_Address varchar(50) NULL,
   CO_Suburb varchar(30) NULL,
   CO_State varchar(10) NULL,
   CO_Postcode numeric(6,0) NULL,
   CO_Email varchar(50) NULL,
   CO_Phone varchar(15) NULL,
   CO_Fax varchar(15) NULL
);

CREATE UNIQUE CLUSTERED INDEX Company_Name ON Company (Name);

DROP TABLE Connote;

CREATE TABLE Connote (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Harvest_Date varchar(10) NOT NULL,
   Processor_Name varchar(30) NOT NULL,
   Process_Date varchar(10) NOT NULL,
   Process_Time varchar(10) NOT NULL,
   Carrier_Name varchar(30) NOT NULL,
   Consignment_Note varchar(30) NOT NULL,
   Consignment_Date varchar(10) NOT NULL,
   Cartons_Qty integer NULL,
   Pallet_Qty integer NULL,
   Gross_Weight numeric(10,2) NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Connote_Name ON Connote (Name,Cust_Order_No,Order_Date,Order_Item,Harvest_Ref_No,Harvest_Date,Processor_Name,Process_Date,Process_Time,Carrier_Name,Consignment_Note,Consignment_Date);

DROP TABLE Connote_HO;

CREATE TABLE Connote_HO (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Harvest_Date varchar(10) NOT NULL,
   Processor_Name varchar(30) NOT NULL,
   Process_Date varchar(10) NOT NULL,
   Process_Time varchar(10) NOT NULL,
   Carrier_Name varchar(30) NOT NULL,
   Consignment_Note varchar(30) NOT NULL,
   Consignment_Date varchar(10) NOT NULL,
   Cartons_Qty integer NULL,
   Pallet_Qty integer NULL,
   Gross_Weight numeric(10,2) NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Connote_HO_Name ON Connote_HO (Name,Cust_Order_No,Order_Date,Order_Item,Harvest_Ref_No,Harvest_Date,Processor_Name,Process_Date,Process_Time,Carrier_Name,Consignment_Note,Consignment_Date);

DROP TABLE Contact;

CREATE TABLE Contact (
   Name varchar(30) NOT NULL,
   Contact varchar(30) NULL,
   Address varchar(50) NULL,
   Suburb varchar(30) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL,
   Web_Site varchar(40) NULL,
   Classification varchar(20) NOT NULL,
   Responsibility varchar(20) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Contact_Name ON Contact (Name);

DROP TABLE Country;

CREATE TABLE Country (
   Country varchar(40) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Country_Country ON Country (Country);

DROP TABLE Customer;

CREATE TABLE Customer (
   Name varchar(30) NOT NULL,
   Contact varchar(30) NULL,
   Address varchar(50) NULL,
   Suburb varchar(30) NULL,
   State varchar(10) NULL,
   Postcode numeric(6,0) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL,
   Sales_Tax varchar(10) NULL,
   ABN varchar(15) NULL,
   ACN varchar(15) NULL,
   Web_Site varchar(40) NULL,
   Comment varchar(200) NULL,
   Group_Name varchar(30) NULL,
   Country varchar(40) NULL,
   Delivery_Detail varchar(100) NULL,
   Carrier varchar(30) NULL
);

CREATE UNIQUE CLUSTERED INDEX Customer_Name ON Customer (Name);

CREATE INDEX Customer_Group_Name ON Customer (Group_Name);

CREATE INDEX Customer_Country ON Customer (Country);

DROP TABLE Customer_Carrier;

CREATE TABLE Customer_Carrier (
   Customer_Name varchar(30) NOT NULL,
   Carrier_Name varchar(30) NOT NULL,
   Date_From varchar(10) NOT NULL,
   Date_To varchar(10) NOT NULL,
   Comment varchar(255) NULL
);

CREATE UNIQUE CLUSTERED INDEX Customer_Carrier_Customer_Name ON Customer_Carrier (Customer_Name,Carrier_Name,Date_From,Date_To);

DROP TABLE Customer_Delivery_Address;

CREATE TABLE Customer_Delivery_Address (
   Customer_Name varchar(30) NOT NULL,
   Delivery_Address varchar(120) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Customer_Delivery_Address_Customer_Name ON Customer_Delivery_Address (Customer_Name,Delivery_Address);

DROP TABLE Customer_Group;

CREATE TABLE Customer_Group (
   Group_Name varchar(30) NOT NULL,
   Comment varchar(255) NULL,
   Default_Group varchar(4) NULL,
   Default_for_Reports varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Customer_Group_Group_Name ON Customer_Group (Group_Name);

DROP TABLE Customer_Harvest;

CREATE TABLE Customer_Harvest (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Harvest_Date varchar(10) NOT NULL,
   Fish_Allocated integer NOT NULL,
   Price_Name varchar(30) NULL,
   Price_Date varchar(10) NULL,
   Price_Description varchar(50) NULL,
   Con_Notes varchar(100) NULL
);

CREATE UNIQUE CLUSTERED INDEX Customer_Harvest_Name ON Customer_Harvest (Name,Cust_Order_No,Order_Date,Order_Item,Harvest_Ref_No,Harvest_Date);

CREATE INDEX Customer_Harvest_Price_Name ON Customer_Harvest (Price_Name);

CREATE INDEX Customer_Harvest_Price_Date ON Customer_Harvest (Price_Date);

CREATE INDEX Customer_Harvest_Price_Description ON Customer_Harvest (Price_Description);

DROP TABLE Customer_Order;

CREATE TABLE Customer_Order (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Comment varchar(200) NULL,
   Staff_Name varchar(20) NULL,
   Delivery_Detail varchar(250) NULL,
   Customer_Ref_No varchar(20) NULL,
   Notification varchar(80) NULL,
   Collection_Time varchar(15) NULL,
   Carrier varchar(30) NULL,
   Delivery_Time_Date varchar(30) NULL,
   Dest_Carrier varchar(30) NULL,
   Customer_Name varchar(30) NULL,
   Delivery_Address varchar(120) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Customer_Order_Name ON Customer_Order (Name,Cust_Order_No,Order_Date);

CREATE INDEX Customer_Order_Staff_Name ON Customer_Order (Staff_Name);

DROP TABLE Customer_Order_Carton_Items;

CREATE TABLE Customer_Order_Carton_Items (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Process_Form_1 varchar(15) NULL,
   Grade_1 varchar(15) NULL,
   Fish_Category_Name_1 varchar(20) NULL,
   No_Cartons_1 integer NULL,
   Comments_1 varchar(80) NULL,
   Process_Form_2 varchar(15) NULL,
   Grade_2 varchar(15) NULL,
   Fish_Category_Name_2 varchar(20) NULL,
   No_Cartons_2 integer NULL,
   Comments_2 varchar(80) NULL,
   Process_Form_3 varchar(15) NULL,
   Grade_3 varchar(15) NULL,
   Fish_Category_Name_3 varchar(20) NULL,
   No_Cartons_3 integer NULL,
   Comments_3 varchar(80) NULL,
   Process_Form_4 varchar(15) NULL,
   Grade_4 varchar(15) NULL,
   Fish_Category_Name_4 varchar(20) NULL,
   No_Cartons_4 integer NULL,
   Comments_4 varchar(80) NULL,
   Process_Form_5 varchar(15) NULL,
   Grade_5 varchar(15) NULL,
   Fish_Category_Name_5 varchar(20) NULL,
   No_Cartons_5 integer NULL,
   Comments_5 varchar(80) NULL,
   Process_Form_6 varchar(15) NULL,
   Grade_6 varchar(15) NULL,
   Fish_Category_Name_6 varchar(20) NULL,
   No_Cartons_6 integer NULL,
   Comments_6 varchar(80) NULL,
   Process_Form_7 varchar(15) NULL,
   Grade_7 varchar(15) NULL,
   Fish_Category_Name_7 varchar(20) NULL,
   No_Cartons_7 integer NULL,
   Comments_7 varchar(80) NULL,
   Process_Form_8 varchar(15) NULL,
   Grade_8 varchar(15) NULL,
   Fish_Category_Name_8 varchar(20) NULL,
   No_Cartons_8 integer NULL,
   Comments_8 varchar(80) NULL,
   Process_Form_9 varchar(15) NULL,
   Grade_9 varchar(15) NULL,
   Fish_Category_Name_9 varchar(20) NULL,
   No_Cartons_9 integer NULL,
   Comments_9 varchar(80) NULL,
   Process_Form_10 varchar(15) NULL,
   Grade_10 varchar(15) NULL,
   Fish_Category_Name_10 varchar(20) NULL,
   No_Cartons_10 integer NULL,
   Comments_10 varchar(80) NULL,
   Process_Form_11 varchar(15) NULL,
   Grade_11 varchar(15) NULL,
   Fish_Category_Name_11 varchar(20) NULL,
   No_Cartons_11 integer NULL,
   Comments_11 varchar(80) NULL,
   Process_Form_12 varchar(15) NULL,
   Grade_12 varchar(15) NULL,
   Fish_Category_Name_12 varchar(20) NULL,
   No_Cartons_12 integer NULL,
   Comments_12 varchar(80) NULL,
   Process_Form_13 varchar(15) NULL,
   Grade_13 varchar(15) NULL,
   Fish_Category_Name_13 varchar(20) NULL,
   No_Cartons_13 integer NULL,
   Comments_13 varchar(80) NULL,
   Process_Form_14 varchar(15) NULL,
   Grade_14 varchar(15) NULL,
   Fish_Category_Name_14 varchar(20) NULL,
   No_Cartons_14 integer NULL,
   Comments_14 varchar(80) NULL,
   Process_Form_15 varchar(15) NULL,
   Grade_15 varchar(15) NULL,
   Fish_Category_Name_15 varchar(20) NULL,
   No_Cartons_15 integer NULL,
   Comments_15 varchar(80) NULL
);

CREATE UNIQUE CLUSTERED INDEX Customer_Order_Carton_Items_Name ON Customer_Order_Carton_Items (Name,Cust_Order_No,Order_Date,Order_Item);

DROP TABLE Cust_Order_Item;

CREATE TABLE Cust_Order_Item (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Exp_Date varchar(10) NOT NULL,
   Processor_Name varchar(30) NULL,
   Premium_Box integer NULL,
   Premium_Box_Weight numeric(10,2) NULL,
   Premium_Biomass numeric(10,2) NULL,
   Vap_Box integer NULL,
   Vap_Box_Weight numeric(10,2) NULL,
   Vap_Biomass numeric(10,2) NULL,
   Export_Box integer NULL,
   Export_Box_Weight numeric(10,2) NULL,
   Export_Biomass numeric(10,2) NULL,
   Fish_No integer NULL,
   Order_Qty numeric(10,2) NULL,
   Comment varchar(200) NULL,
   Order_Status varchar(15) NULL,
   Delivery_Detail varchar(300) NULL,
   Carrier varchar(30) NULL,
   Amended_Order varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Cust_Order_Item_Name ON Cust_Order_Item (Name,Cust_Order_No,Order_Date,Order_Item);

CREATE INDEX Cust_Order_Item_Exp_Date ON Cust_Order_Item (Exp_Date);

CREATE INDEX Cust_Order_Item_Processor_Name ON Cust_Order_Item (Processor_Name);

DROP TABLE Delivery;

CREATE TABLE Delivery (
   Order_No varchar(20) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Carrier_Name varchar(30) NOT NULL,
   Supplier_Name varchar(30) NOT NULL,
   Qty_Delivered integer NOT NULL,
   Carrier_Docket_No varchar(20) NULL,
   Pallets_Received integer NULL,
   Pallets_Returned integer NULL,
   Driver_Name varchar(30) NULL,
   Freight numeric(10,2) NULL,
   Container_No varchar(20) NULL,
   Run_No varchar(20) NULL,
   Comment varchar(255) NULL
);

CREATE UNIQUE CLUSTERED INDEX Delivery_Order_No ON Delivery (Order_No,Stock_Name,Delivered_Date,Delivered_Time,Carrier_Name);

CREATE INDEX Delivery_Supplier_Name ON Delivery (Supplier_Name);

CREATE INDEX Delivery_Carrier_Docket_No ON Delivery (Carrier_Docket_No);

DROP TABLE Delivery_Check;

CREATE TABLE Delivery_Check (
   Fish_Id varchar(10) NOT NULL,
   Fish_Stock_No integer NULL,
   Smolt_Intake_Date varchar(10) NOT NULL,
   Hatchery_Name varchar(40) NOT NULL,
   Time_Check varchar(8) NOT NULL,
   Location varchar(20) NOT NULL,
   Tank_1_DO varchar(10) NULL,
   Tank_2_DO varchar(10) NULL,
   Tank_3_DO varchar(10) NULL,
   Tank_1_Temp varchar(10) NULL,
   Tank_2_Temp varchar(10) NULL,
   Tank_3_Temp varchar(10) NULL,
   Staff_Name varchar(20) NOT NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Delivery_Check_Fish_Id ON Delivery_Check (Fish_Id,Smolt_Intake_Date,Hatchery_Name,Time_Check,Location);

CREATE INDEX Delivery_Check_Fish_Stock_No ON Delivery_Check (Fish_Stock_No);

CREATE INDEX Delivery_Check_Staff_Name ON Delivery_Check (Staff_Name);

DROP TABLE Despatch_Details;

CREATE TABLE Despatch_Details (
   Fish_Id varchar(10) NOT NULL,
   Despatch_Form_No varchar(10) NOT NULL,
   Despatch_Detail_No integer NOT NULL,
   Farm varchar(10) NOT NULL,
   Tank varchar(10) NOT NULL,
   Truck_Tank varchar(10) NULL,
   Marine_Cage varchar(10) NULL,
   Fish_Type varchar(20) NULL,
   Size_Category varchar(10) NULL,
   No_of_Fish integer NOT NULL,
   Mean_weight numeric(5,2) NOT NULL,
   Total_Weight numeric(10,2) NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Despatch_Details_Fish_Id ON Despatch_Details (Fish_Id,Despatch_Form_No,Despatch_Detail_No);

DROP TABLE Dive_Record;

CREATE TABLE Dive_Record (
   Job_No integer NOT NULL,
   Job_No_P integer NOT NULL,
   Fish_Id varchar(10) NOT NULL,
   Date_Moved varchar(10) NOT NULL,
   Dive_Date varchar(10) NOT NULL,
   Dive_Type_Name varchar(30) NOT NULL,
   Diver_Name varchar(20) NOT NULL,
   Supervisor_Name varchar(20) NULL,
   Comment varchar(200) NULL,
   Wind_Speed varchar(10) NULL,
   Wind_Direction varchar(10) NULL,
   Sea_Height varchar(10) NULL,
   Tide varchar(10) NULL,
   Water_Visibility varchar(10) NULL,
   Time_in_water integer NULL,
   Net_Max_Depth numeric(10,2) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Dive_Record_Job_No ON Dive_Record (Job_No);

CREATE INDEX Dive_Record_Job_No_P ON Dive_Record (Job_No_P);

CREATE INDEX Dive_Record_Fish_Id ON Dive_Record (Fish_Id);

CREATE INDEX Dive_Record_Date_Moved ON Dive_Record (Date_Moved);

CREATE INDEX Dive_Record_Dive_Date ON Dive_Record (Dive_Date);

CREATE INDEX Dive_Record_Dive_Type_Name ON Dive_Record (Dive_Type_Name);

CREATE INDEX Dive_Record_Supervisor_Name ON Dive_Record (Supervisor_Name);

DROP TABLE Dive_Type;

CREATE TABLE Dive_Type (
   Name varchar(30) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Dive_Type_Name ON Dive_Type (Name);

DROP TABLE Email_Group;

CREATE TABLE Email_Group (
   Group_Name varchar(30) NOT NULL,
   Comment varchar(120) NULL
);

CREATE UNIQUE CLUSTERED INDEX Email_Group_Group_Name ON Email_Group (Group_Name);

DROP TABLE Email_Members;

CREATE TABLE Email_Members (
   Group_Name varchar(30) NOT NULL,
   Email_Seq_No varchar(20) NOT NULL,
   Staff_Name varchar(20) NULL,
   Customer_Name varchar(30) NULL,
   Processor_Name varchar(30) NULL
);

CREATE UNIQUE CLUSTERED INDEX Email_Members_Group_Name ON Email_Members (Group_Name,Email_Seq_No);

DROP TABLE ErrorMessage;

CREATE TABLE ErrorMessage (
   emRef integer NOT NULL,
   emText varchar(255) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX ErrorMessage_emRef ON ErrorMessage (emRef);

DROP TABLE Export_Fish_Sale_Item;

CREATE TABLE Export_Fish_Sale_Item (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Fish_Category_Name_1 varchar(20) NULL,
   No_Cartons_1 integer NULL,
   Comments_1 varchar(80) NULL,
   Fish_Category_Name_2 varchar(20) NULL,
   No_Cartons_2 integer NULL,
   Comments_2 varchar(80) NULL,
   Fish_Category_Name_3 varchar(20) NULL,
   No_Cartons_3 integer NULL,
   Comments_3 varchar(80) NULL,
   Fish_Category_Name_4 varchar(20) NULL,
   No_Cartons_4 integer NULL,
   Comments_4 varchar(80) NULL,
   Fish_Category_Name_5 varchar(20) NULL,
   No_Cartons_5 integer NULL,
   Comments_5 varchar(80) NULL
);

CREATE UNIQUE CLUSTERED INDEX Export_Fish_Sale_Item_Name ON Export_Fish_Sale_Item (Name,Cust_Order_No,Order_Date,Order_Item);

DROP TABLE Farm_Cost;

CREATE TABLE Farm_Cost (
   Operating_Year numeric(4,0) NOT NULL,
   Staff_Cost numeric(10,2) NULL,
   Var_Staff_Cost numeric(4,2) NULL,
   Maintenance_Cost numeric(10,2) NULL,
   Var_Maintenance_Cost numeric(4,2) NULL,
   Farm_Operation_Cost numeric(10,2) NULL,
   Var_Farm_Operation_Cost numeric(4,2) NULL,
   Stock_Cost numeric(10,2) NULL,
   Var_Stock_Cost numeric(4,2) NULL,
   Rates_and_Taxes numeric(10,2) NULL,
   Var_Rates_and_Taxes_Cost numeric(4,2) NULL,
   Fuel_Cost numeric(10,2) NULL,
   Var_Fuel_Cost numeric(4,2) NULL,
   Consulting_Cost numeric(10,2) NULL,
   Var_Consulting_Cost numeric(4,2) NULL,
   Loans_Cost numeric(10,2) NULL,
   Var_Loan_Cost numeric(4,2) NULL,
   Oxygen_Cost numeric(10,2) NULL,
   Var_Oxygen_Cost numeric(4,2) NULL,
   Diving_Cost numeric(10,2) NULL,
   Var_Diving_Cost numeric(4,2) NULL,
   Packaging_Cost numeric(10,2) NULL,
   Var_Packing_Cost numeric(4,2) NULL,
   Insurance_Cost numeric(10,2) NULL,
   Var_Insurance_Cost numeric(4,2) NULL,
   Marketing_Cost numeric(10,2) NULL,
   Var_Marketing_Cost numeric(4,2) NULL,
   Operating_Capacity numeric(10,2) NULL,
   Var_Operating_capacity numeric(4,2) NULL,
   Selling_Price numeric(10,2) NULL,
   Var_Selling_Price numeric(4,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Farm_Cost_Operating_Year ON Farm_Cost (Operating_Year);

DROP TABLE FCR_Table;

CREATE TABLE FCR_Table (
   FCR_Name varchar(15) NOT NULL,
   Date_Created varchar(10) NOT NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Tdummy4 char(1) NULL,
   Tdummy7 char(1) NULL,
   Tdummy8 char(1) NULL,
   Fish_50_10 numeric(3,2) NULL,
   Fish_50_12 numeric(3,2) NULL,
   Fish_50_14 numeric(3,2) NULL,
   Fish_50_16 numeric(3,2) NULL,
   Fish_50_17 numeric(3,2) NULL,
   Fish_50_18 numeric(3,2) NULL,
   Fish_100_10 numeric(3,2) NULL,
   Fish_100_12 numeric(3,2) NULL,
   Fish_100_14 numeric(3,2) NULL,
   Fish_100_16 numeric(3,2) NULL,
   Fish_100_17 numeric(3,2) NULL,
   Fish_100_18 numeric(3,2) NULL,
   Fish_500_10 numeric(3,2) NULL,
   Fish_500_12 numeric(3,2) NULL,
   Fish_500_14 numeric(3,2) NULL,
   Fish_500_16 numeric(3,2) NULL,
   Fish_500_17 numeric(3,2) NULL,
   Fish_500_18 numeric(3,2) NULL,
   Fish_750_10 numeric(3,2) NULL,
   Fish_750_12 numeric(3,2) NULL,
   Fish_750_14 numeric(3,2) NULL,
   Fish_750_16 numeric(3,2) NULL,
   Fish_750_17 numeric(3,2) NULL,
   Fish_750_18 numeric(3,2) NULL,
   Fish_1000_10 numeric(3,2) NULL,
   Fish_1000_12 numeric(3,2) NULL,
   Fish_1000_14 numeric(3,2) NULL,
   Fish_1000_16 numeric(3,2) NULL,
   Fish_1000_17 numeric(3,2) NULL,
   Fish_1000_18 numeric(3,2) NULL,
   Fish_1500_10 numeric(3,2) NULL,
   Fish_1500_12 numeric(3,2) NULL,
   Fish_1500_14 numeric(3,2) NULL,
   Fish_1500_16 numeric(3,2) NULL,
   Fish_1500_17 numeric(3,2) NULL,
   Fish_1500_18 numeric(3,2) NULL,
   Fish_2000_10 numeric(3,2) NULL,
   Fish_2000_12 numeric(3,2) NULL,
   Fish_2000_14 numeric(3,2) NULL,
   Fish_2000_16 numeric(3,2) NULL,
   Fish_2000_17 numeric(3,2) NULL,
   Fish_2000_18 numeric(3,2) NULL,
   Fish_3000_10 numeric(3,2) NULL,
   Fish_3000_12 numeric(3,2) NULL,
   Fish_3000_14 numeric(3,2) NULL,
   Fish_3000_16 numeric(3,2) NULL,
   Fish_3000_17 numeric(3,2) NULL,
   Fish_3000_18 numeric(3,2) NULL,
   Fish_4000_10 numeric(3,2) NULL,
   Fish_4000_12 numeric(3,2) NULL,
   Fish_4000_14 numeric(3,2) NULL,
   Fish_4000_16 numeric(3,2) NULL,
   Fish_4000_17 numeric(3,2) NULL,
   Fish_4000_18 numeric(3,2) NULL,
   Fish_5000_10 numeric(3,2) NULL,
   Fish_5000_12 numeric(3,2) NULL,
   Fish_5000_14 numeric(3,2) NULL,
   Fish_5000_16 numeric(3,2) NULL,
   Fish_5000_17 numeric(3,2) NULL,
   Fish_5000_18 numeric(3,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX FCR_Table_FCR_Name ON FCR_Table (FCR_Name);

CREATE INDEX FCR_Table_Date_Created ON FCR_Table (Date_Created);

DROP TABLE Feeding_Detail;

CREATE TABLE Feeding_Detail (
   Fish_Id varchar(10) NOT NULL,
   Feeding_Date varchar(10) NOT NULL,
   Item_Type varchar(20) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Stock_Item_Type varchar(20) NULL,
   Qty numeric(10,2) NOT NULL,
   Use_in_Total varchar(4) NOT NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feeding_Detail_Fish_Id ON Feeding_Detail (Fish_Id,Feeding_Date,Item_Type,Stock_Name);

CREATE INDEX Feeding_Detail_Stock_Item_Type ON Feeding_Detail (Stock_Item_Type);

DROP TABLE Feeding_Schedule;

CREATE TABLE Feeding_Schedule (
   Fish_Id varchar(10) NOT NULL,
   Job_No integer NOT NULL,
   Date_Moved varchar(10) NOT NULL,
   Fish_Count integer NULL,
   Feeding_Date varchar(10) NOT NULL,
   Mooring_to_Site_Name varchar(20) NOT NULL,
   Bin_Fill numeric(10,2) NULL,
   Stock_Name varchar(40) NULL,
   Bin_Stock_Item_Type varchar(20) NULL,
   Aq_Qty numeric(10,2) NULL,
   Aq_Stock_Name varchar(40) NULL,
   Aq_Stock_Item_Type varchar(20) NULL,
   DO_3m numeric(10,2) NULL,
   DO_Sat numeric(10,2) NULL,
   Hand_Qty numeric(10,2) NULL,
   Hand_Stock_Name varchar(40) NULL,
   Hand_Stock_Item_Type varchar(20) NULL,
   Blow_Qty numeric(10,2) NULL,
   Blow_Stock_Name varchar(40) NULL,
   Blow_Stock_Item_Type varchar(20) NULL,
   Total_Feed numeric(10,2) NULL,
   Comment varchar(200) NULL,
   Mooring_to_Mooring_Id varchar(15) NOT NULL,
   Mooring_To_Occupy_Date varchar(10) NOT NULL,
   Bin_Fill_2 numeric(10,2) NULL,
   Stock_Name_2 varchar(40) NULL,
   Bin_Stock_Item_Type_2 varchar(20) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feeding_Schedule_Fish_Id ON Feeding_Schedule (Fish_Id,Feeding_Date);

CREATE INDEX Feeding_Schedule_Job_No ON Feeding_Schedule (Job_No);

CREATE INDEX Feeding_Schedule_Date_Moved ON Feeding_Schedule (Date_Moved);

CREATE INDEX Feeding_Schedule_Mooring_to_Site_Name ON Feeding_Schedule (Mooring_to_Site_Name);

CREATE INDEX Feeding_Schedule_Stock_Name ON Feeding_Schedule (Stock_Name);

CREATE INDEX Feeding_Schedule_Bin_Stock_Item_Type ON Feeding_Schedule (Bin_Stock_Item_Type);

CREATE INDEX Feeding_Schedule_Aq_Stock_Name ON Feeding_Schedule (Aq_Stock_Name);

CREATE INDEX Feeding_Schedule_Aq_Stock_Item_Type ON Feeding_Schedule (Aq_Stock_Item_Type);

CREATE INDEX Feeding_Schedule_Hand_Stock_Name ON Feeding_Schedule (Hand_Stock_Name);

CREATE INDEX Feeding_Schedule_Hand_Stock_Item_Type ON Feeding_Schedule (Hand_Stock_Item_Type);

CREATE INDEX Feeding_Schedule_Blow_Stock_Name ON Feeding_Schedule (Blow_Stock_Name);

CREATE INDEX Feeding_Schedule_Blow_Stock_Item_Type ON Feeding_Schedule (Blow_Stock_Item_Type);

CREATE INDEX Feeding_Schedule_Mooring_to_Mooring_Id ON Feeding_Schedule (Mooring_to_Mooring_Id);

CREATE INDEX Feeding_Schedule_Mooring_To_Occupy_Date ON Feeding_Schedule (Mooring_To_Occupy_Date);

CREATE INDEX Feeding_Schedule_Stock_Name_2 ON Feeding_Schedule (Stock_Name_2);

CREATE INDEX Feeding_Schedule_Bin_Stock_Item_Type_2 ON Feeding_Schedule (Bin_Stock_Item_Type_2);

DROP TABLE Feed_Bin;

CREATE TABLE Feed_Bin (
   Bin_Serial_No varchar(50) NOT NULL,
   Bin_Size integer NOT NULL,
   Bin_Status varchar(30) NOT NULL,
   Comment varchar(255) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Bin_Bin_Serial_No ON Feed_Bin (Bin_Serial_No,Bin_Size);

DROP TABLE Feed_Bin_Assignment;

CREATE TABLE Feed_Bin_Assignment (
   Fish_Id varchar(10) NOT NULL,
   Date_Assigned varchar(10) NOT NULL,
   Bin_Size integer NOT NULL,
   Bin_Serial_No varchar(50) NOT NULL,
   Date_Unassigned varchar(10) NULL,
   Comment varchar(255) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Bin_Assignment_Fish_Id ON Feed_Bin_Assignment (Fish_Id,Date_Assigned,Bin_Size,Bin_Serial_No);

DROP TABLE Feed_Credit_Invoice;

CREATE TABLE Feed_Credit_Invoice (
   Supplier_Name varchar(30) NOT NULL,
   Invoice_No varchar(20) NOT NULL,
   Invoice_Date varchar(10) NOT NULL,
   Year_Class varchar(6) NOT NULL,
   Credit_Invoice_Amt numeric(10,2) NOT NULL,
   Credit_GST numeric(10,2) NOT NULL,
   Total_Credit numeric(10,2) NOT NULL,
   TDummy1 char(1) NULL,
   Qty_Feed numeric(10,2) NULL,
   Levy_Credit numeric(10,2) NULL,
   Levy_GST numeric(10,2) NULL,
   Total_Levy_Credit numeric(10,2) NULL,
   Total_Invoice_Credit numeric(10,2) NOT NULL,
   Total_Invoice_GST numeric(10,2) NOT NULL,
   Grand_Total numeric(10,2) NOT NULL,
   Comment varchar(200) NULL,
   Supplier_Invoice_No varchar(20) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Credit_Invoice_Supplier_Name ON Feed_Credit_Invoice (Supplier_Name,Invoice_No,Invoice_Date);

CREATE INDEX Feed_Credit_Invoice_Year_Class ON Feed_Credit_Invoice (Year_Class);

DROP TABLE Feed_Delivery;

CREATE TABLE Feed_Delivery (
   Carrier_Name varchar(30) NOT NULL,
   Container_No varchar(60) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Carrier_Inv_No varchar(20) NULL,
   Consignment_Note varchar(30) NULL,
   Carrier_Inv_Date varchar(10) NULL,
   Tdummy1 char(1) NULL,
   Carrier_Inv_Amt numeric(10,2) NULL,
   Carrier_GST numeric(10,2) NULL,
   Total_Charge numeric(10,2) NULL,
   Total_Qty numeric(10,2) NULL,
   Comment varchar(255) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Delivery_Carrier_Name ON Feed_Delivery (Carrier_Name,Container_No,Delivered_Date,Delivered_Time);

DROP TABLE Feed_Del_Invoice;

CREATE TABLE Feed_Del_Invoice (
   Carrier_Name varchar(30) NOT NULL,
   Container_No varchar(60) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Del_Docket_No varchar(20) NOT NULL,
   Order_Item_Order_No varchar(20) NOT NULL,
   Order_Item_Stock_Name varchar(40) NOT NULL,
   Date_Invoice varchar(10) NOT NULL,
   Invoice_No varchar(20) NOT NULL,
   Qty_Feed numeric(10,2) NOT NULL,
   Invoice_Price numeric(10,2) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Del_Invoice_Carrier_Name ON Feed_Del_Invoice (Carrier_Name,Container_No,Delivered_Date,Delivered_Time,Del_Docket_No,Order_Item_Order_No,Order_Item_Stock_Name,Date_Invoice,Invoice_No);

DROP TABLE Feed_Fish_Pellet_Size;

CREATE TABLE Feed_Fish_Pellet_Size (
   Stock_Name varchar(40) NOT NULL,
   Item_Type_Name varchar(20) NOT NULL,
   Date_Created varchar(10) NOT NULL,
   Tdummy1 char(1) NULL,
   TDummy2 varchar(1) NULL,
   TDummy3 integer NULL,
   Fish_Size_1_3 numeric(3,1) NULL,
   Fish_Size_1_3_End numeric(3,1) NULL,
   No_1_3 integer NULL,
   Fish_Size_3_5 numeric(3,1) NULL,
   Fish_Size_3_5_End numeric(3,1) NULL,
   No_3_5 integer NULL,
   Fish_Size_5_180 numeric(3,1) NULL,
   Fish_Size_5_180_End numeric(3,1) NULL,
   No_5_180 integer NULL,
   Fish_Size_180_400 numeric(3,1) NULL,
   Fish_Size_180_400_End numeric(3,1) NULL,
   No_180_400 integer NULL,
   Fish_Size_400_750 numeric(3,1) NULL,
   Fish_Size_400_750_End numeric(3,1) NULL,
   No_400_750 integer NULL,
   Fish_Size_750_1500 numeric(3,1) NULL,
   Fish_Size_750_1500_End numeric(3,1) NULL,
   No_750_1500 integer NULL,
   Fish_Size_1500_2200 numeric(3,1) NULL,
   Fish_Size_1500_2200_End numeric(3,1) NULL,
   No_1500_2200 integer NULL,
   Fish_Size_2200_3200 numeric(3,1) NULL,
   Fish_Size_2200_3200_End numeric(3,1) NULL,
   No_2200_3200 integer NULL,
   Fish_Size_3200 numeric(3,1) NULL,
   Fish_Size_3200_End numeric(3,1) NULL,
   No_3200 integer NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Fish_Pellet_Size_Stock_Name ON Feed_Fish_Pellet_Size (Stock_Name,Item_Type_Name,Date_Created);

DROP TABLE Feed_Monthly_Levy;

CREATE TABLE Feed_Monthly_Levy (
   Supplier_Name varchar(30) NOT NULL,
   Levy_Month varchar(4) NOT NULL,
   Levy_Year numeric(4,0) NOT NULL,
   Invoice_Date varchar(10) NOT NULL,
   Invoice_No varchar(20) NOT NULL,
   Year_Class varchar(6) NOT NULL,
   Qty_Feed numeric(10,2) NOT NULL,
   Levy_Amt numeric(10,2) NOT NULL,
   Levy_GST numeric(10,2) NOT NULL,
   Total_Invoice numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Monthly_Levy_Supplier_Name ON Feed_Monthly_Levy (Supplier_Name,Levy_Month,Levy_Year,Invoice_Date,Invoice_No,Year_Class);

DROP TABLE Feed_Movement;

CREATE TABLE Feed_Movement (
   Feed_Move_Date varchar(10) NOT NULL,
   From_Company_Name varchar(30) NOT NULL,
   From_Site_Name varchar(20) NOT NULL,
   Del_Docket_No varchar(20) NOT NULL,
   Carrier_Name varchar(30) NULL,
   Carrier_Inv_Date varchar(10) NULL,
   GST_Date_From varchar(10) NULL,
   GST numeric(10,2) NULL,
   Carrier_Inv_No varchar(20) NULL,
   Invoice_Value numeric(10,2) NULL,
   Invoice_GST numeric(10,2) NULL,
   Invoice_Total numeric(10,2) NULL,
   Total_Pallets integer NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Movement_Feed_Move_Date ON Feed_Movement (Feed_Move_Date,From_Company_Name,From_Site_Name,Del_Docket_No);

CREATE INDEX Feed_Movement_GST_Date_From ON Feed_Movement (GST_Date_From);

DROP TABLE Feed_Movement_Item;

CREATE TABLE Feed_Movement_Item (
   Feed_Move_Date varchar(10) NOT NULL,
   From_Company_Name varchar(30) NOT NULL,
   From_Site_Name varchar(20) NOT NULL,
   Del_Docket_No varchar(20) NOT NULL,
   Supplier_Name varchar(30) NOT NULL,
   Feed_Name varchar(40) NOT NULL,
   To_Company_Name varchar(30) NOT NULL,
   To_Site_Name varchar(20) NOT NULL,
   Load_No integer NOT NULL,
   Year_Class varchar(6) NULL,
   No_Bags integer NOT NULL,
   Qty_Weight numeric(10,2) NOT NULL,
   Pallets_Used integer NULL,
   Run_No varchar(20) NULL,
   Carrier_Name varchar(30) NULL,
   Carrier_Inv_No varchar(20) NULL,
   Carrier_Inv_Date varchar(10) NULL,
   Carrier_Inv_Amt numeric(10,2) NULL,
   Carrier_GST numeric(10,2) NULL,
   Total_Charge numeric(10,2) NULL,
   Cart_Acct_Code varchar(10) NULL,
   Date_Invoice varchar(10) NULL,
   Invoice_No varchar(20) NULL,
   Qty_Feed numeric(10,2) NULL,
   Pred_Price numeric(10,2) NULL,
   Manual_Override varchar(4) NULL,
   Invoice_Price numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Movement_Item_Feed_Move_Date ON Feed_Movement_Item (Feed_Move_Date,From_Company_Name,From_Site_Name,Del_Docket_No,Supplier_Name,Feed_Name,To_Company_Name,To_Site_Name,Load_No);

CREATE INDEX Feed_Movement_Item_Year_Class ON Feed_Movement_Item (Year_Class);

CREATE INDEX Feed_Movement_Item_Date_Invoice ON Feed_Movement_Item (Date_Invoice);

DROP TABLE Feed_Price;

CREATE TABLE Feed_Price (
   Supplier_Name varchar(30) NOT NULL,
   Description varchar(60) NOT NULL,
   Date_Effective varchar(10) NOT NULL,
   Date_Valid_Until varchar(10) NULL,
   Comment varchar(255) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Price_Supplier_Name ON Feed_Price (Supplier_Name,Description,Date_Effective);

CREATE INDEX Feed_Price_Date_Valid_Until ON Feed_Price (Date_Valid_Until);

DROP TABLE Feed_Price_Item;

CREATE TABLE Feed_Price_Item (
   Supplier_Name varchar(30) NOT NULL,
   Description varchar(60) NOT NULL,
   Date_Effective varchar(10) NOT NULL,
   Supplier_Supplier_Name varchar(30) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Base_Feed_Price numeric(10,2) NOT NULL,
   Pigment integer NULL,
   Pigment_Price numeric(10,2) NULL,
   Total_Pigment_Price numeric(10,2) NULL,
   Sub_Total numeric(10,2) NULL,
   GST numeric(10,2) NULL,
   Total_Price numeric(10,2) NULL,
   Date_Valid_Until varchar(10) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Price_Item_Supplier_Name ON Feed_Price_Item (Supplier_Name,Description,Date_Effective,Supplier_Supplier_Name,Stock_Name);

CREATE INDEX Feed_Price_Item_Date_Valid_Until ON Feed_Price_Item (Date_Valid_Until);

DROP TABLE Feed_Rate_Period;

CREATE TABLE Feed_Rate_Period (
   Category_Name varchar(70) NOT NULL,
   Calendar_Year integer NOT NULL,
   Week_No integer NOT NULL,
   Start_Date varchar(10) NOT NULL,
   End_Date varchar(10) NOT NULL,
   Tdummy char(1) NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Tdummy4 char(1) NULL,
   Tdummy7 char(1) NULL,
   Tdummy8 char(1) NULL,
   Tdummy9 char(1) NULL,
   Tdummy10 char(1) NULL,
   Tdummy11 char(1) NULL,
   Tdummy12 char(1) NULL,
   Fish_5_1_10 numeric(3,2) NULL,
   Fish_5_1_11 numeric(3,2) NULL,
   Fish_5_1_12 numeric(3,2) NULL,
   Fish_5_1_13 numeric(3,2) NULL,
   Fish_5_1_14 numeric(3,2) NULL,
   Fish_5_1_15 numeric(3,2) NULL,
   Fish_5_1_16 numeric(3,2) NULL,
   Fish_5_1_17 numeric(3,2) NULL,
   Fish_5_1_18 numeric(3,2) NULL,
   Fish_5_1_19 numeric(3,2) NULL,
   Fish_1_2_10 numeric(3,2) NULL,
   Fish_1_2_11 numeric(3,2) NULL,
   Fish_1_2_12 numeric(3,2) NULL,
   Fish_1_2_13 numeric(3,2) NULL,
   Fish_1_2_14 numeric(3,2) NULL,
   Fish_1_2_15 numeric(3,2) NULL,
   Fish_1_2_16 numeric(3,2) NULL,
   Fish_1_2_17 numeric(3,2) NULL,
   Fish_1_2_18 numeric(3,2) NULL,
   Fish_1_2_19 numeric(3,2) NULL,
   Fish_2_3_10 numeric(3,2) NULL,
   Fish_2_3_11 numeric(3,2) NULL,
   Fish_2_3_12 numeric(3,2) NULL,
   Fish_2_3_13 numeric(3,2) NULL,
   Fish_2_3_14 numeric(3,2) NULL,
   Fish_2_3_15 numeric(3,2) NULL,
   Fish_2_3_16 numeric(3,2) NULL,
   Fish_2_3_17 numeric(3,2) NULL,
   Fish_2_3_18 numeric(3,2) NULL,
   Fish_2_3_19 numeric(3,2) NULL,
   Fish_3_5_10 numeric(3,2) NULL,
   Fish_3_5_11 numeric(3,2) NULL,
   Fish_3_5_12 numeric(3,2) NULL,
   Fish_3_5_13 numeric(3,2) NULL,
   Fish_3_5_14 numeric(3,2) NULL,
   Fish_3_5_15 numeric(3,2) NULL,
   Fish_3_5_16 numeric(3,2) NULL,
   Fish_3_5_17 numeric(3,2) NULL,
   Fish_3_5_18 numeric(3,2) NULL,
   Fish_3_5_19 numeric(3,2) NULL,
   Fish_5_7_10 numeric(3,2) NULL,
   Fish_5_7_11 numeric(3,2) NULL,
   Fish_5_7_12 numeric(3,2) NULL,
   Fish_5_7_13 numeric(3,2) NULL,
   Fish_5_7_14 numeric(3,2) NULL,
   Fish_5_7_15 numeric(3,2) NULL,
   Fish_5_7_16 numeric(3,2) NULL,
   Fish_5_7_17 numeric(3,2) NULL,
   Fish_5_7_18 numeric(3,2) NULL,
   Fish_5_7_19 numeric(3,2) NULL,
   Fish_7_9_10 numeric(3,2) NULL,
   Fish_7_9_11 numeric(3,2) NULL,
   Fish_7_9_12 numeric(3,2) NULL,
   Fish_7_9_13 numeric(3,2) NULL,
   Fish_7_9_14 numeric(3,2) NULL,
   Fish_7_9_15 numeric(3,2) NULL,
   Fish_7_9_16 numeric(3,2) NULL,
   Fish_7_9_17 numeric(3,2) NULL,
   Fish_7_9_18 numeric(3,2) NULL,
   Fish_7_9_19 numeric(3,2) NULL,
   Fish_9_11_10 numeric(3,2) NULL,
   Fish_9_11_11 numeric(3,2) NULL,
   Fish_9_11_12 numeric(3,2) NULL,
   Fish_9_11_13 numeric(3,2) NULL,
   Fish_9_11_14 numeric(3,2) NULL,
   Fish_9_11_15 numeric(3,2) NULL,
   Fish_9_11_16 numeric(3,2) NULL,
   Fish_9_11_17 numeric(3,2) NULL,
   Fish_9_11_18 numeric(3,2) NULL,
   Fish_9_11_19 numeric(3,2) NULL,
   Fish_11_13_10 numeric(3,2) NULL,
   Fish_11_13_11 numeric(3,2) NULL,
   Fish_11_13_12 numeric(3,2) NULL,
   Fish_11_13_13 numeric(3,2) NULL,
   Fish_11_13_14 numeric(3,2) NULL,
   Fish_11_13_15 numeric(3,2) NULL,
   Fish_11_13_16 numeric(3,2) NULL,
   Fish_11_13_17 numeric(3,2) NULL,
   Fish_11_13_18 numeric(3,2) NULL,
   Fish_11_13_19 numeric(3,2) NULL,
   Fish_13_15_10 numeric(3,2) NULL,
   Fish_13_15_11 numeric(3,2) NULL,
   Fish_13_15_12 numeric(3,2) NULL,
   Fish_13_15_13 numeric(3,2) NULL,
   Fish_13_15_14 numeric(3,2) NULL,
   Fish_13_15_15 numeric(3,2) NULL,
   Fish_13_15_16 numeric(3,2) NULL,
   Fish_13_15_17 numeric(3,2) NULL,
   Fish_13_15_18 numeric(3,2) NULL,
   Fish_13_15_19 numeric(3,2) NULL,
   Fish_15_175_10 numeric(3,2) NULL,
   Fish_15_175_11 numeric(3,2) NULL,
   Fish_15_175_12 numeric(3,2) NULL,
   Fish_15_175_13 numeric(3,2) NULL,
   Fish_15_175_14 numeric(3,2) NULL,
   Fish_15_175_15 numeric(3,2) NULL,
   Fish_15_175_16 numeric(3,2) NULL,
   Fish_15_175_17 numeric(3,2) NULL,
   Fish_15_175_18 numeric(3,2) NULL,
   Fish_15_175_19 numeric(3,2) NULL,
   Tdummy5 char(1) NULL,
   Tdummy16 char(1) NULL,
   Tdummy17 char(1) NULL,
   Tdummy18 char(1) NULL,
   Tdummy19 char(1) NULL,
   Tdummy20 char(1) NULL,
   Tdummy21 char(1) NULL,
   Tdummy22 char(1) NULL,
   Tdummy23 char(1) NULL,
   Tdummy24 char(1) NULL,
   Tdummy25 char(1) NULL,
   Fish_175_2_10 numeric(3,2) NULL,
   Fish_175_2_11 numeric(3,2) NULL,
   Fish_175_2_12 numeric(3,2) NULL,
   Fish_175_2_13 numeric(3,2) NULL,
   Fish_175_2_14 numeric(3,2) NULL,
   Fish_175_2_15 numeric(3,2) NULL,
   Fish_175_2_16 numeric(3,2) NULL,
   Fish_175_2_17 numeric(3,2) NULL,
   Fish_175_2_18 numeric(3,2) NULL,
   Fish_175_2_19 numeric(3,2) NULL,
   Fish_20_225_10 numeric(3,2) NULL,
   Fish_20_225_11 numeric(3,2) NULL,
   Fish_20_225_12 numeric(3,2) NULL,
   Fish_20_225_13 numeric(3,2) NULL,
   Fish_20_225_14 numeric(3,2) NULL,
   Fish_20_225_15 numeric(3,2) NULL,
   Fish_20_225_16 numeric(3,2) NULL,
   Fish_20_225_17 numeric(3,2) NULL,
   Fish_20_225_18 numeric(3,2) NULL,
   Fish_20_225_19 numeric(3,2) NULL,
   Fish_225_25_10 numeric(3,2) NULL,
   Fish_225_25_11 numeric(3,2) NULL,
   Fish_225_25_12 numeric(3,2) NULL,
   Fish_225_25_13 numeric(3,2) NULL,
   Fish_225_25_14 numeric(3,2) NULL,
   Fish_225_25_15 numeric(3,2) NULL,
   Fish_225_25_16 numeric(3,2) NULL,
   Fish_225_25_17 numeric(3,2) NULL,
   Fish_225_25_18 numeric(3,2) NULL,
   Fish_225_25_19 numeric(3,2) NULL,
   Fish_25_30_10 numeric(3,2) NULL,
   Fish_25_30_11 numeric(3,2) NULL,
   Fish_25_30_12 numeric(3,2) NULL,
   Fish_25_30_13 numeric(3,2) NULL,
   Fish_25_30_14 numeric(3,2) NULL,
   Fish_25_30_15 numeric(3,2) NULL,
   Fish_25_30_16 numeric(3,2) NULL,
   Fish_25_30_17 numeric(3,2) NULL,
   Fish_25_30_18 numeric(3,2) NULL,
   Fish_25_30_19 numeric(3,2) NULL,
   Fish_30_35_10 numeric(3,2) NULL,
   Fish_30_35_11 numeric(3,2) NULL,
   Fish_30_35_12 numeric(3,2) NULL,
   Fish_30_35_13 numeric(3,2) NULL,
   Fish_30_35_14 numeric(3,2) NULL,
   Fish_30_35_15 numeric(3,2) NULL,
   Fish_30_35_16 numeric(3,2) NULL,
   Fish_30_35_17 numeric(3,2) NULL,
   Fish_30_35_18 numeric(3,2) NULL,
   Fish_30_35_19 numeric(3,2) NULL,
   Fish_35_40_10 numeric(3,2) NULL,
   Fish_35_40_11 numeric(3,2) NULL,
   Fish_35_40_12 numeric(3,2) NULL,
   Fish_35_40_13 numeric(3,2) NULL,
   Fish_35_40_14 numeric(3,2) NULL,
   Fish_35_40_15 numeric(3,2) NULL,
   Fish_35_40_16 numeric(3,2) NULL,
   Fish_35_40_17 numeric(3,2) NULL,
   Fish_35_40_18 numeric(3,2) NULL,
   Fish_35_40_19 numeric(3,2) NULL,
   Fish_40_45_10 numeric(3,2) NULL,
   Fish_40_45_11 numeric(3,2) NULL,
   Fish_40_45_12 numeric(3,2) NULL,
   Fish_40_45_13 numeric(3,2) NULL,
   Fish_40_45_14 numeric(3,2) NULL,
   Fish_40_45_15 numeric(3,2) NULL,
   Fish_40_45_16 numeric(3,2) NULL,
   Fish_40_45_17 numeric(3,2) NULL,
   Fish_40_45_18 numeric(3,2) NULL,
   Fish_40_45_19 numeric(3,2) NULL,
   Fish_45_50_10 numeric(3,2) NULL,
   Fish_45_50_11 numeric(3,2) NULL,
   Fish_45_50_12 numeric(3,2) NULL,
   Fish_45_50_13 numeric(3,2) NULL,
   Fish_45_50_14 numeric(3,2) NULL,
   Fish_45_50_15 numeric(3,2) NULL,
   Fish_45_50_16 numeric(3,2) NULL,
   Fish_45_50_17 numeric(3,2) NULL,
   Fish_45_50_18 numeric(3,2) NULL,
   Fish_45_50_19 numeric(3,2) NULL,
   Fish_5000_10 numeric(3,2) NULL,
   Fish_5000_11 numeric(3,2) NULL,
   Fish_5000_12 numeric(3,2) NULL,
   Fish_5000_13 numeric(3,2) NULL,
   Fish_5000_14 numeric(3,2) NULL,
   Fish_5000_15 numeric(3,2) NULL,
   Fish_5000_16 numeric(3,2) NULL,
   Fish_5000_17 numeric(3,2) NULL,
   Fish_5000_18 numeric(3,2) NULL,
   Fish_5000_19 numeric(3,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Rate_Period_Category_Name ON Feed_Rate_Period (Category_Name,Calendar_Year,Week_No,Start_Date,End_Date);

DROP TABLE Feed_Size_Range;

CREATE TABLE Feed_Size_Range (
   Size_Name varchar(30) NOT NULL,
   Start_Size numeric(10,2) NOT NULL,
   End_Size numeric(10,2) NOT NULL,
   Pellet_Size integer NOT NULL,
   Protein integer NOT NULL,
   Oil integer NOT NULL,
   Pigment integer NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Size_Range_Size_Name ON Feed_Size_Range (Size_Name,Start_Size,End_Size,Pellet_Size,Protein,Oil,Pigment);

DROP TABLE Feed_Stock_Adjust;

CREATE TABLE Feed_Stock_Adjust (
   Stock_Name varchar(40) NOT NULL,
   Stock_Item_Type varchar(20) NOT NULL,
   Adjust_Date varchar(10) NOT NULL,
   Adjust_Qty integer NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Stock_Adjust_Stock_Name ON Feed_Stock_Adjust (Stock_Name,Stock_Item_Type,Adjust_Date);

DROP TABLE Feed_Stock_Delivered;

CREATE TABLE Feed_Stock_Delivered (
   Carrier_Name varchar(30) NOT NULL,
   Container_No varchar(60) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Del_Docket_No varchar(20) NOT NULL,
   Order_Item_Order_No varchar(20) NOT NULL,
   Order_Item_Stock_Name varchar(40) NOT NULL,
   Run_No varchar(20) NULL,
   Order_Item_Supplier_Name varchar(30) NOT NULL,
   Year_Class varchar(6) NULL,
   No_Bags integer NOT NULL,
   Qty_Del numeric(10,2) NOT NULL,
   To_Company_Name varchar(30) NOT NULL,
   To_Site_Name varchar(20) NOT NULL,
   Carrier_Inv_No varchar(20) NULL,
   Carrier_Inv_Date varchar(10) NULL,
   Price_Tonne numeric(10,2) NULL,
   Carrier_Inv_Amt numeric(10,2) NULL,
   Carrier_Inv_Adj numeric(10,2) NULL,
   Carrier_GST numeric(10,2) NULL,
   Total_Charge numeric(10,2) NULL,
   Cart_Acct_Code varchar(10) NULL,
   Comment varchar(200) NULL,
   Date_Invoice varchar(10) NULL,
   Invoice_No varchar(20) NULL,
   Qty_Feed numeric(10,2) NULL,
   Pred_Price numeric(10,2) NULL,
   Manual_Override varchar(4) NULL,
   Invoice_Price numeric(10,2) NULL,
   Supplier_Name varchar(30) NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Stock_Delivered_Carrier_Name ON Feed_Stock_Delivered (Carrier_Name,Container_No,Delivered_Date,Delivered_Time,Del_Docket_No,Order_Item_Order_No,Order_Item_Stock_Name);

CREATE INDEX Feed_Stock_Delivered_Order_Item_Supplier_Name ON Feed_Stock_Delivered (Order_Item_Supplier_Name);

CREATE INDEX Feed_Stock_Delivered_To_Company_Name ON Feed_Stock_Delivered (To_Company_Name);

CREATE INDEX Feed_Stock_Delivered_To_Site_Name ON Feed_Stock_Delivered (To_Site_Name);

CREATE INDEX Feed_Stock_Delivered_Date_Invoice ON Feed_Stock_Delivered (Date_Invoice);

DROP TABLE Fish_Adjustment;

CREATE TABLE Fish_Adjustment (
   Adjust_Fish_Id varchar(10) NOT NULL,
   Adjust_Date varchar(10) NOT NULL,
   Adjust_Qty integer NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Adjustment_Adjust_Fish_Id ON Fish_Adjustment (Adjust_Fish_Id,Adjust_Date);

DROP TABLE Fish_Category;

CREATE TABLE Fish_Category (
   Category_Name varchar(70) NOT NULL,
   Calendar_Year integer NOT NULL,
   Comment varchar(250) NULL,
   Abbrev_Name varchar(10) NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Category_Category_Name ON Fish_Category (Category_Name,Calendar_Year);

DROP TABLE Fish_Category_Size_Class;

CREATE TABLE Fish_Category_Size_Class (
   Fish_Category_Name varchar(20) NOT NULL,
   Fish_Size_Class_Name varchar(20) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Category_Size_Class_Fish_Category_Name ON Fish_Category_Size_Class (Fish_Category_Name,Fish_Size_Class_Name);

DROP TABLE Fish_Checked;

CREATE TABLE Fish_Checked (
   Fish_Id varchar(10) NOT NULL,
   Fish_No varchar(20) NOT NULL,
   FH_Date varchar(10) NOT NULL,
   Check_Type varchar(15) NOT NULL,
   AGD varchar(15) NULL,
   Avg_Fish_Length numeric(10,2) NULL,
   Weight numeric(10,2) NULL,
   Sea_Lice varchar(4) NULL,
   ISA varchar(4) NULL,
   Furunculosis varchar(4) NULL,
   BKD varchar(4) NULL,
   ERM varchar(4) NULL,
   CWD varchar(4) NULL,
   Vibriosis varchar(4) NULL,
   IPN varchar(4) NULL,
   SSSV varchar(4) NULL,
   Yersinia_Ruckeri varchar(4) NULL,
   Flexibacter varchar(4) NULL,
   VA varchar(4) NULL,
   Piscirickettsiosis varchar(4) NULL,
   VHS varchar(4) NULL,
   Lab_Results_Other varchar(200) NULL,
   Sample_Weight numeric(5,2) NULL,
   Sat_Fat numeric(5,2) NULL,
   Mono_Fat numeric(5,2) NULL,
   Poly_Fat numeric(5,2) NULL,
   Omega_3 numeric(10,2) NULL,
   Cholesterol integer NULL,
   Carbohydrate numeric(3,2) NULL,
   Energy integer NULL,
   Sodium numeric(5,2) NULL,
   Calcium numeric(5,2) NULL,
   Iron numeric(5,2) NULL,
   Vitamin_A numeric(5,2) NULL,
   Thiamin numeric(5,2) NULL,
   Riboflavin numeric(5,2) NULL,
   Niacin numeric(5,2) NULL,
   Vitamin_B12 numeric(5,2) NULL,
   Vitamin_C numeric(5,2) NULL,
   Vitamin_D numeric(5,2) NULL,
   Vitamin_E numeric(5,2) NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Checked_Fish_Id ON Fish_Checked (Fish_Id,Fish_No,FH_Date,Check_Type);

DROP TABLE Fish_Health;

CREATE TABLE Fish_Health (
   Fish_Id varchar(10) NOT NULL,
   FH_Date varchar(10) NOT NULL,
   Check_Type varchar(15) NOT NULL,
   Total_Fish numeric(6,0) NOT NULL,
   Staff_Name varchar(20) NOT NULL,
   AGD_Clear numeric(3,0) NULL,
   AGD_FSpot numeric(3,0) NULL,
   AGD_Spot numeric(3,0) NULL,
   AGD_Patch numeric(3,0) NULL,
   Mature numeric(3,0) NULL,
   Mature_Female numeric(3,0) NULL,
   Gill_Health_Good numeric(3,0) NULL,
   Gill_Health_Moppy numeric(3,0) NULL,
   Gill_Health_CN numeric(3,0) NULL,
   Gill_Health_Other numeric(3,0) NULL,
   Weight_Method varchar(10) NULL,
   Weight_Fish_Total integer NULL,
   Avg_Live_Weight numeric(10,0) NULL,
   Adjust_Factor numeric(4,2) NULL,
   Weight_Check numeric(10,2) NULL,
   Accept_Weight_Check varchar(4) NULL,
   Reject_Comment varchar(255) NULL,
   Weight_Coefficient varchar(10) NULL,
   Weight_Variation varchar(10) NULL,
   Weight_Comment varchar(100) NULL,
   Comment varchar(200) NULL,
   Sample_date varchar(10) NULL,
   No_Fish_Sampled integer NULL,
   Sample_Type varchar(35) NULL,
   Samples_Sent varchar(100) NULL,
   Samples_Comment varchar(200) NULL,
   Lesions numeric(3,0) NULL,
   Deformed_Jaw numeric(3,0) NULL,
   Deformaties numeric(3,0) NULL,
   Runts numeric(3,0) NULL,
   Pinhead numeric(3,0) NULL,
   Avg_Fish_Length numeric(10,2) NULL,
   Fish_Count integer NULL,
   Other numeric(3,0) NULL,
   Good_Fish numeric(3,0) NULL,
   Operculum numeric(3,0) NULL,
   Bent numeric(3,0) NULL,
   Swollen_Bladder numeric(3,0) NULL,
   Blind numeric(3,0) NULL,
   Isopod numeric(3,0) NULL,
   Hunchback numeric(3,0) NULL,
   Sfumpy numeric(3,0) NULL,
   DSBath integer NULL,
   AGD_Comment varchar(240) NULL,
   Est_Start_Weight numeric(10,0) NULL,
   Calc_Start_Weight numeric(10,0) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Health_Fish_Id ON Fish_Health (Fish_Id,FH_Date,Check_Type);

CREATE INDEX Fish_Health_Staff_Name ON Fish_Health (Staff_Name);

DROP TABLE Fish_Health_Detail;

CREATE TABLE Fish_Health_Detail (
   Fish_Id varchar(10) NOT NULL,
   FH_Date varchar(10) NOT NULL,
   Check_Type varchar(15) NOT NULL,
   Name varchar(20) NOT NULL,
   Affected_No integer NOT NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Health_Detail_Fish_Id ON Fish_Health_Detail (Fish_Id,FH_Date,Check_Type,Name);

DROP TABLE Fish_Id_File_Note;

CREATE TABLE Fish_Id_File_Note (
   Fish_Id varchar(10) NOT NULL,
   Note_Date varchar(10) NOT NULL,
   Staff_Name varchar(20) NOT NULL,
   Comment varchar(4096) NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Id_File_Note_Fish_Id ON Fish_Id_File_Note (Fish_Id,Note_Date,Staff_Name);

DROP TABLE Fish_Oxygen;

CREATE TABLE Fish_Oxygen (
   Job_No integer NOT NULL,
   Fish_Id varchar(10) NOT NULL,
   Date_Moved varchar(10) NOT NULL,
   Monitor_Date varchar(10) NOT NULL,
   Current_Mooring_Id varchar(15) NOT NULL,
   Current_Site_Name varchar(20) NULL,
   Comment varchar(255) NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Tdummy4 char(1) NULL,
   Tdummy5 char(1) NULL,
   Tdummy6 char(1) NULL,
   Tdummy7 char(1) NULL,
   Time1_Om varchar(8) NULL,
   Om_1_0m numeric(10,2) NULL,
   Om_1_0mt numeric(10,2) NULL,
   Om_1_3m numeric(10,2) NULL,
   Om_1_3mt numeric(10,2) NULL,
   Om_1_5m numeric(10,2) NULL,
   Om_1_5mt numeric(10,2) NULL,
   Time2_Om varchar(8) NULL,
   Om_2_0m numeric(10,2) NULL,
   Om_2_0mt numeric(10,2) NULL,
   Om_2_3m numeric(10,2) NULL,
   Om_2_3mt numeric(10,2) NULL,
   Om_2_5m numeric(10,2) NULL,
   Om_2_5mt numeric(10,2) NULL,
   Time3_Om varchar(8) NULL,
   Om_3_0m numeric(10,2) NULL,
   Om_3_0mt numeric(10,2) NULL,
   Om_3_3m numeric(10,2) NULL,
   Om_3_3mt numeric(10,2) NULL,
   Om_3_5m numeric(10,2) NULL,
   Om_3_5mt numeric(10,2) NULL,
   Time4_Om varchar(8) NULL,
   Om_4_0m numeric(10,2) NULL,
   Om_4_0mt numeric(10,2) NULL,
   Om_4_3m numeric(10,2) NULL,
   Om_4_3mt numeric(10,2) NULL,
   Om_4_5m numeric(10,2) NULL,
   Om_4_5mt numeric(10,2) NULL,
   Time5_Om varchar(8) NULL,
   Om_5_0m numeric(10,2) NULL,
   Om_5_0mt numeric(10,2) NULL,
   Om_5_3m numeric(10,2) NULL,
   Om_5_3mt numeric(10,2) NULL,
   Om_5_5m numeric(10,2) NULL,
   Om_5_5mt numeric(10,2) NULL,
   Time6_Om varchar(8) NULL,
   Om_6_0m numeric(10,2) NULL,
   Om_6_0mt numeric(10,2) NULL,
   Om_6_3m numeric(10,2) NULL,
   Om_6_3mt numeric(10,2) NULL,
   Om_6_5m numeric(10,2) NULL,
   Om_6_5mt numeric(10,2) NULL,
   Time7_Om varchar(8) NULL,
   Om_7_0m numeric(10,2) NULL,
   Om_7_0mt numeric(10,2) NULL,
   Om_7_3m numeric(10,2) NULL,
   Om_7_3mt numeric(10,2) NULL,
   Om_7_5m numeric(10,2) NULL,
   Om_7_5mt numeric(10,2) NULL,
   Time8_Om varchar(8) NULL,
   Om_8_0m numeric(10,2) NULL,
   Om_8_0mt numeric(10,2) NULL,
   Om_8_3m numeric(10,2) NULL,
   Om_8_3mt numeric(10,2) NULL,
   Om_8_5m numeric(10,2) NULL,
   Om_8_5mt numeric(10,2) NULL,
   Tdummy8 char(1) NULL,
   Tdummy9 char(1) NULL,
   Tdummy10 char(1) NULL,
   Tdummy11 char(1) NULL,
   Tdummy12 char(1) NULL,
   Tdummy13 char(1) NULL,
   Tdummy14 char(1) NULL,
   Time1_Oms varchar(8) NULL,
   Om_1_0ms numeric(10,2) NULL,
   Om_1_0mts numeric(10,2) NULL,
   Om_1_3ms numeric(10,2) NULL,
   Om_1_3mts numeric(10,2) NULL,
   Om_1_5ms numeric(10,2) NULL,
   Om_1_5mts numeric(10,2) NULL,
   Time2_Oms varchar(8) NULL,
   Om_2_0ms numeric(10,2) NULL,
   Om_2_0mts numeric(10,2) NULL,
   Om_2_3ms numeric(10,2) NULL,
   Om_2_3mts numeric(10,2) NULL,
   Om_2_5ms numeric(10,2) NULL,
   Om_2_5mts numeric(10,2) NULL,
   Time3_Oms varchar(8) NULL,
   Om_3_0ms numeric(10,2) NULL,
   Om_3_0mts numeric(10,2) NULL,
   Om_3_3ms numeric(10,2) NULL,
   Om_3_3mts numeric(10,2) NULL,
   Om_3_5ms numeric(10,2) NULL,
   Om_3_5mts numeric(10,2) NULL,
   Time4_Oms varchar(8) NULL,
   Om_4_0ms numeric(10,2) NULL,
   Om_4_0mts numeric(10,2) NULL,
   Om_4_3ms numeric(10,2) NULL,
   Om_4_3mts numeric(10,2) NULL,
   Om_4_5ms numeric(10,2) NULL,
   Om_4_5mts numeric(10,2) NULL,
   Time5_Oms varchar(8) NULL,
   Om_5_0ms numeric(10,2) NULL,
   Om_5_0mts numeric(10,2) NULL,
   Om_5_3ms numeric(10,2) NULL,
   Om_5_3mts numeric(10,2) NULL,
   Om_5_5ms numeric(10,2) NULL,
   Om_5_5mts numeric(10,2) NULL,
   Time6_Oms varchar(8) NULL,
   Om_6_0ms numeric(10,2) NULL,
   Om_6_0mts numeric(10,2) NULL,
   Om_6_3ms numeric(10,2) NULL,
   Om_6_3mts numeric(10,2) NULL,
   Om_6_5ms numeric(10,2) NULL,
   Om_6_5mts numeric(10,2) NULL,
   Time7_Oms varchar(8) NULL,
   Om_7_0ms numeric(10,2) NULL,
   Om_7_0mts numeric(10,2) NULL,
   Om_7_3ms numeric(10,2) NULL,
   Om_7_3mts numeric(10,2) NULL,
   Om_7_5ms numeric(10,2) NULL,
   Om_7_5mts numeric(10,2) NULL,
   Time8_Oms varchar(8) NULL,
   Om_8_0ms numeric(10,2) NULL,
   Om_8_0mts numeric(10,2) NULL,
   Om_8_3ms numeric(10,2) NULL,
   Om_8_3mts numeric(10,2) NULL,
   Om_8_5ms numeric(10,2) NULL,
   Om_8_5mts numeric(10,2) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Oxygen_Job_No ON Fish_Oxygen (Job_No,Fish_Id,Date_Moved,Monitor_Date);

CREATE INDEX Fish_Oxygen_Current_Mooring_Id ON Fish_Oxygen (Current_Mooring_Id);

DROP TABLE Fish_Processor;

CREATE TABLE Fish_Processor (
   Name varchar(30) NOT NULL,
   Contact varchar(30) NULL,
   Address varchar(50) NULL,
   Suburb varchar(30) NULL,
   State varchar(10) NULL,
   Postcode numeric(6,0) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL,
   Sales_Tax varchar(10) NULL,
   ABN_No varchar(20) NULL,
   ACN_No varchar(20) NULL,
   Comment varchar(200) NULL,
   Web_Site varchar(40) NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Processor_Name ON Fish_Processor (Name);

DROP TABLE Fish_Size_Category;

CREATE TABLE Fish_Size_Category (
   Fish_Category_Name varchar(20) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Size_Category_Fish_Category_Name ON Fish_Size_Category (Fish_Category_Name);

DROP TABLE Fish_Size_Class;

CREATE TABLE Fish_Size_Class (
   Fish_Size_Class_Name varchar(20) NOT NULL,
   Start_Size numeric(10,2) NOT NULL,
   End_Size numeric(10,2) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Size_Class_Fish_Size_Class_Name ON Fish_Size_Class (Fish_Size_Class_Name);

DROP TABLE Fish_Specie;

CREATE TABLE Fish_Specie (
   Specie_Name varchar(20) NOT NULL,
   Commercial_Name varchar(30) NULL,
   Scientific_Name varchar(60) NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Specie_Specie_Name ON Fish_Specie (Specie_Name);

DROP TABLE Fish_Stock;

CREATE TABLE Fish_Stock (
   Fish_Id varchar(10) NOT NULL,
   Fish_Stock_No integer NOT NULL,
   Smolt_Intake_Date varchar(10) NOT NULL,
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(20) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Stock_Item_Type varchar(20) NOT NULL,
   Fish_Type varchar(20) NOT NULL,
   Hatchery_Name varchar(40) NOT NULL,
   No_Fish_Delivered numeric(10,0) NOT NULL,
   Avg_Fish_Weight numeric(10,2) NOT NULL,
   Biomass numeric(12,4) NOT NULL,
   Customer_1 varchar(30) NULL,
   Customer_1_Stock numeric(5,2) NULL,
   Customer_2 varchar(30) NULL,
   Customer_2_Stock numeric(5,2) NULL,
   Customer_3 varchar(30) NULL,
   Customer_3_Stock numeric(5,2) NULL,
   Fish_Cost numeric(10,2) NULL,
   Fish_Age varchar(10) NULL,
   Dissolved_Oxygen varchar(10) NULL,
   Temperature varchar(10) NULL,
   Salinity varchar(10) NULL,
   Comment varchar(200) NULL,
   Lighting varchar(15) NULL,
   Date_Lit varchar(10) NULL,
   Date_UnLit varchar(10) NULL,
   Archive varchar(4) NULL,
   Invoice_Date varchar(10) NULL,
   Invoice_No varchar(20) NULL,
   No_Fish integer NULL,
   Price_per_Fish numeric(10,2) NULL,
   GST numeric(10,2) NULL,
   Invoice_Comment varchar(255) NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Stock_Fish_Id ON Fish_Stock (Fish_Id,Fish_Stock_No);

CREATE INDEX Fish_Stock_Smolt_Intake_Date ON Fish_Stock (Smolt_Intake_Date);

CREATE INDEX Fish_Stock_Company_Name ON Fish_Stock (Company_Name);

CREATE INDEX Fish_Stock_Site_Name ON Fish_Stock (Site_Name);

CREATE INDEX Fish_Stock_Stock_Name ON Fish_Stock (Stock_Name);

CREATE INDEX Fish_Stock_Stock_Item_Type ON Fish_Stock (Stock_Item_Type);

CREATE INDEX Fish_Stock_Hatchery_Name ON Fish_Stock (Hatchery_Name);

CREATE INDEX Fish_Stock_Customer_1 ON Fish_Stock (Customer_1);

CREATE INDEX Fish_Stock_Customer_2 ON Fish_Stock (Customer_2);

CREATE INDEX Fish_Stock_Customer_3 ON Fish_Stock (Customer_3);

CREATE INDEX Fish_Stock_Invoice_Date ON Fish_Stock (Invoice_Date);

DROP TABLE Fish_Type;

CREATE TABLE Fish_Type (
   Fish_Type varchar(20) NOT NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Fish_Type_Fish_Type ON Fish_Type (Fish_Type);

DROP TABLE Forecast;

CREATE TABLE Forecast (
   Forecast_Name varchar(60) NOT NULL,
   Emp_Name varchar(20) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Stock_Item_Type varchar(20) NOT NULL,
   Active_Fish varchar(4) NOT NULL,
   Date_From varchar(10) NOT NULL,
   Date_To varchar(10) NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Forecast_Name ON Forecast (Forecast_Name);

CREATE INDEX Forecast_Stock_Item_Type ON Forecast (Stock_Item_Type);

CREATE INDEX Forecast_Date_From ON Forecast (Date_From);

CREATE INDEX Forecast_Date_To ON Forecast (Date_To);

DROP TABLE Forecast_Cage_Id;

CREATE TABLE Forecast_Cage_Id (
   Cage_Id varchar(20) NOT NULL,
   Cage_Size integer NOT NULL,
   Cage_Radius numeric(10,2) NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Cage_Id_Cage_Id ON Forecast_Cage_Id (Cage_Id);

DROP TABLE Forecast_Feed;

CREATE TABLE Forecast_Feed (
   Forecast_Feed_Name varchar(30) NOT NULL,
   Supplier_Name varchar(30) NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Feed_Forecast_Feed_Name ON Forecast_Feed (Forecast_Feed_Name,Supplier_Name);

DROP TABLE Forecast_Feed_Item;

CREATE TABLE Forecast_Feed_Item (
   Forecast_Feed_Name varchar(30) NOT NULL,
   Supplier_Name varchar(30) NOT NULL,
   Size_Name varchar(30) NOT NULL,
   Start_Size numeric(10,2) NOT NULL,
   End_Size numeric(10,2) NOT NULL,
   Pellet_Size integer NOT NULL,
   Protein integer NOT NULL,
   Oil integer NOT NULL,
   Pigment integer NOT NULL,
   Archive varchar(4) NULL,
   Feed_Rate numeric(10,2) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Feed_Item_Forecast_Feed_Name ON Forecast_Feed_Item (Forecast_Feed_Name,Supplier_Name,Size_Name,Start_Size,End_Size);

DROP TABLE Forecast_Fish_Growth;

CREATE TABLE Forecast_Fish_Growth (
   Forecast_Name varchar(60) NOT NULL,
   Fish_Id varchar(10) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Week_Date varchar(10) NOT NULL,
   End_Date varchar(10) NOT NULL,
   Day_No integer NOT NULL,
   Start_Weight numeric(10,2) NOT NULL,
   Feed_Rate numeric(10,2) NOT NULL,
   Feed numeric(10,2) NOT NULL,
   FCR numeric(10,2) NOT NULL,
   Growth numeric(10,2) NOT NULL,
   Close_Weight numeric(10,2) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Fish_Growth_Forecast_Name ON Forecast_Fish_Growth (Forecast_Name,Fish_Id,Stock_Name,Week_Date,End_Date,Day_No);

DROP TABLE Forecast_Fish_Id;

CREATE TABLE Forecast_Fish_Id (
   Forecast_Name varchar(60) NOT NULL,
   Fish_Id varchar(10) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Date_From varchar(10) NOT NULL,
   Date_To varchar(10) NOT NULL,
   Mort_Name varchar(30) NOT NULL,
   Forecast_Feed_Name varchar(30) NOT NULL,
   Supplier_Name varchar(30) NOT NULL,
   Cage_Id varchar(20) NULL,
   Net_Id varchar(30) NULL,
   Site_Name varchar(60) NULL,
   Mooring_Id varchar(20) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Fish_Id_Forecast_Name ON Forecast_Fish_Id (Forecast_Name,Fish_Id,Stock_Name);

CREATE INDEX Forecast_Fish_Id_Date_From ON Forecast_Fish_Id (Date_From);

CREATE INDEX Forecast_Fish_Id_Date_To ON Forecast_Fish_Id (Date_To);

CREATE INDEX Forecast_Fish_Id_Mort_Name ON Forecast_Fish_Id (Mort_Name);

DROP TABLE Forecast_Fish_Period;

CREATE TABLE Forecast_Fish_Period (
   Forecast_Name varchar(60) NOT NULL,
   Fish_Id varchar(10) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Week_Date varchar(10) NOT NULL,
   Open_Fish_Count integer NOT NULL,
   Morts integer NOT NULL,
   Mort_Name varchar(30) NOT NULL,
   Harvest integer NOT NULL,
   Avg_Weight numeric(10,2) NOT NULL,
   Total_Biomass numeric(10,2) NOT NULL,
   Transfer_Count integer NOT NULL,
   Closing_Fish_Count integer NOT NULL,
   Forecast_Feed_Name varchar(30) NOT NULL,
   Supplier_Name varchar(30) NOT NULL,
   Pellet_Size integer NOT NULL,
   Protein integer NOT NULL,
   Oil integer NOT NULL,
   Pigment integer NOT NULL,
   Close_Cage_Id varchar(20) NULL,
   Mesh_Group_Size varchar(10) NULL,
   Close_Net_Id varchar(30) NULL,
   Stock_Density numeric(10,2) NULL,
   Close_Site_Name varchar(60) NULL,
   Close_Mooring_Id varchar(20) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Fish_Period_Forecast_Name ON Forecast_Fish_Period (Forecast_Name,Fish_Id,Stock_Name,Week_Date);

CREATE INDEX Forecast_Fish_Period_Mort_Name ON Forecast_Fish_Period (Mort_Name);

DROP TABLE Forecast_Harvest;

CREATE TABLE Forecast_Harvest (
   Harvest_Name varchar(30) NOT NULL,
   Harvest_Week varchar(10) NOT NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Name_1 varchar(30) NULL,
   Fish_No_1 integer NULL,
   Biomass_1 numeric(10,3) NULL,
   Name_2 varchar(30) NULL,
   Fish_No_2 integer NULL,
   Biomass_2 numeric(10,3) NULL,
   Name_3 varchar(30) NULL,
   Fish_No_3 integer NULL,
   Biomass_3 numeric(10,3) NULL,
   Name_4 varchar(30) NULL,
   Fish_No_4 integer NULL,
   Biomass_4 numeric(10,3) NULL,
   Name_5 varchar(30) NULL,
   Fish_No_5 integer NULL,
   Biomass_5 numeric(10,3) NULL,
   Tdummy6 varchar(10) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Harvest_Harvest_Name ON Forecast_Harvest (Harvest_Name,Harvest_Week);

DROP TABLE Forecast_Harvest_Fish;

CREATE TABLE Forecast_Harvest_Fish (
   Harvest_Name varchar(30) NOT NULL,
   Harvest_Week varchar(10) NOT NULL,
   Forecast_Name varchar(60) NOT NULL,
   Fish_Id varchar(10) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Week_Date varchar(10) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Harvest_Fish_Harvest_Name ON Forecast_Harvest_Fish (Harvest_Name,Harvest_Week,Forecast_Name,Fish_Id,Stock_Name,Week_Date);

DROP TABLE Forecast_Mooring;

CREATE TABLE Forecast_Mooring (
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(60) NOT NULL,
   Mooring_Id varchar(20) NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Mooring_Site_Name ON Forecast_Mooring (Site_Name,Mooring_Id);

CREATE INDEX Forecast_Mooring_Company_Name ON Forecast_Mooring (Company_Name);

DROP TABLE Forecast_Mort;

CREATE TABLE Forecast_Mort (
   Mort_Name varchar(30) NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Mort_Mort_Name ON Forecast_Mort (Mort_Name);

DROP TABLE Forecast_Mort_Item;

CREATE TABLE Forecast_Mort_Item (
   Mort_Name varchar(30) NOT NULL,
   Size_Name varchar(30) NOT NULL,
   Start_Size numeric(10,2) NOT NULL,
   End_Size numeric(10,2) NOT NULL,
   Archive varchar(4) NULL,
   Percent_Rate numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Mort_Item_Mort_Name ON Forecast_Mort_Item (Mort_Name,Size_Name,Start_Size,End_Size);

DROP TABLE Forecast_Net_Id;

CREATE TABLE Forecast_Net_Id (
   Net_Id varchar(30) NOT NULL,
   Net_Diam numeric(10,2) NOT NULL,
   Net_Depth numeric(10,2) NOT NULL,
   Net_Capacity numeric(10,2) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Net_Id_Net_Id ON Forecast_Net_Id (Net_Id);

DROP TABLE Forecast_Site;

CREATE TABLE Forecast_Site (
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(60) NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Site_Company_Name ON Forecast_Site (Company_Name,Site_Name);

DROP TABLE Forecast_Site_Temp;

CREATE TABLE Forecast_Site_Temp (
   Temp_Year integer NOT NULL,
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(20) NOT NULL,
   Jan numeric(3,1) NULL,
   Feb numeric(3,1) NULL,
   Mar numeric(3,1) NULL,
   Apr numeric(3,1) NULL,
   May numeric(3,1) NULL,
   Jun numeric(3,1) NULL,
   Jul numeric(3,1) NULL,
   Aug numeric(3,1) NULL,
   Sep numeric(3,1) NULL,
   Oct numeric(3,1) NULL,
   Nov numeric(3,1) NULL,
   December numeric(3,1) NULL
);

CREATE UNIQUE CLUSTERED INDEX Forecast_Site_Temp_Temp_Year ON Forecast_Site_Temp (Temp_Year,Company_Name,Site_Name);

DROP TABLE Growth_Rate;

CREATE TABLE Growth_Rate (
   Name varchar(15) NOT NULL,
   Date_Created varchar(10) NOT NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Tdummy4 char(1) NULL,
   Tdummy7 char(1) NULL,
   Tdummy8 char(1) NULL,
   Fish_50_10 numeric(3,2) NULL,
   Fish_50_12 numeric(3,2) NULL,
   Fish_50_14 numeric(3,2) NULL,
   Fish_50_16 numeric(3,2) NULL,
   Fish_50_17 numeric(3,2) NULL,
   Fish_50_18 numeric(3,2) NULL,
   Fish_100_10 numeric(3,2) NULL,
   Fish_100_12 numeric(3,2) NULL,
   Fish_100_14 numeric(3,2) NULL,
   Fish_100_16 numeric(3,2) NULL,
   Fish_100_17 numeric(3,2) NULL,
   Fish_100_18 numeric(3,2) NULL,
   Fish_500_10 numeric(3,2) NULL,
   Fish_500_12 numeric(3,2) NULL,
   Fish_500_14 numeric(3,2) NULL,
   Fish_500_16 numeric(3,2) NULL,
   Fish_500_17 numeric(3,2) NULL,
   Fish_500_18 numeric(3,2) NULL,
   Fish_750_10 numeric(3,2) NULL,
   Fish_750_12 numeric(3,2) NULL,
   Fish_750_14 numeric(3,2) NULL,
   Fish_750_16 numeric(3,2) NULL,
   Fish_750_17 numeric(3,2) NULL,
   Fish_750_18 numeric(3,2) NULL,
   Fish_1000_10 numeric(3,2) NULL,
   Fish_1000_12 numeric(3,2) NULL,
   Fish_1000_14 numeric(3,2) NULL,
   Fish_1000_16 numeric(3,2) NULL,
   Fish_1000_17 numeric(3,2) NULL,
   Fish_1000_18 numeric(3,2) NULL,
   Fish_1500_10 numeric(3,2) NULL,
   Fish_1500_12 numeric(3,2) NULL,
   Fish_1500_14 numeric(3,2) NULL,
   Fish_1500_16 numeric(3,2) NULL,
   Fish_1500_17 numeric(3,2) NULL,
   Fish_1500_18 numeric(3,2) NULL,
   Fish_2000_10 numeric(3,2) NULL,
   Fish_2000_12 numeric(3,2) NULL,
   Fish_2000_14 numeric(3,2) NULL,
   Fish_2000_16 numeric(3,2) NULL,
   Fish_2000_17 numeric(3,2) NULL,
   Fish_2000_18 numeric(3,2) NULL,
   Fish_3000_10 numeric(3,2) NULL,
   Fish_3000_12 numeric(3,2) NULL,
   Fish_3000_14 numeric(3,2) NULL,
   Fish_3000_16 numeric(3,2) NULL,
   Fish_3000_17 numeric(3,2) NULL,
   Fish_3000_18 numeric(3,2) NULL,
   Fish_4000_10 numeric(3,2) NULL,
   Fish_4000_12 numeric(3,2) NULL,
   Fish_4000_14 numeric(3,2) NULL,
   Fish_4000_16 numeric(3,2) NULL,
   Fish_4000_17 numeric(3,2) NULL,
   Fish_4000_18 numeric(3,2) NULL,
   Fish_5000_10 numeric(3,2) NULL,
   Fish_5000_12 numeric(3,2) NULL,
   Fish_5000_14 numeric(3,2) NULL,
   Fish_5000_16 numeric(3,2) NULL,
   Fish_5000_17 numeric(3,2) NULL,
   Fish_5000_18 numeric(3,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Growth_Rate_Name ON Growth_Rate (Name);

CREATE INDEX Growth_Rate_Date_Created ON Growth_Rate (Date_Created);

DROP TABLE GST;

CREATE TABLE GST (
   Date_From varchar(10) NOT NULL,
   GST numeric(10,2) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX GST_Date_From ON GST (Date_From);

DROP TABLE Harvest;

CREATE TABLE Harvest (
   Harvest_Ref_No varchar(20) NOT NULL,
   Harvest_Date varchar(10) NOT NULL,
   Comment varchar(200) NULL,
   Processor_Name varchar(30) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Harvest_Harvest_Ref_No ON Harvest (Harvest_Ref_No,Harvest_Date);

DROP TABLE Harvest_Detail;

CREATE TABLE Harvest_Detail (
   Harvest_Ref_No varchar(20) NOT NULL,
   Harvest_Date varchar(10) NOT NULL,
   Fish_Id varchar(10) NOT NULL,
   Harvest_Time varchar(8) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Wharf_Count integer NOT NULL,
   Avg_Weight numeric(10,3) NOT NULL,
   Avg_Biomass numeric(10,3) NULL,
   Avg_Ungutted numeric(10,3) NULL,
   Avg_Ungutted_Biomass numeric(10,3) NULL,
   C1_Start varchar(8) NULL,
   CEnd1 varchar(8) NULL,
   CStart2 varchar(8) NULL,
   CEnd2 varchar(8) NULL,
   CStart3 varchar(8) NULL,
   CEnd3 varchar(8) NULL,
   CStart4 varchar(8) NULL,
   CEnd4 varchar(8) NULL,
   CStart5 varchar(8) NULL,
   CEnd5 varchar(8) NULL,
   CRComment varchar(200) NULL,
   LH_Name varchar(20) NULL,
   Good_Fish integer NULL,
   Old integer NULL,
   Bent_Fish integer NULL,
   Mature integer NULL,
   Seals integer NULL,
   Other integer NULL,
   Spillage integer NULL,
   Pinhead integer NULL,
   Mort_Count integer NULL,
   Mort_Comment varchar(200) NULL,
   Comment varchar(200) NULL,
   CO2_Flow varchar(10) NULL,
   Stun_Water_Temp numeric(5,2) NULL,
   Circ_Bin_Temp numeric(5,2) NULL,
   Ice_slurry_temp numeric(5,2) NULL,
   Bleed_Rate varchar(10) NULL,
   Supplier_Name varchar(30) NULL,
   DOxy varchar(20) NULL,
   Water_Temp varchar(20) NULL,
   Salinity varchar(20) NULL,
   Weather varchar(200) NULL,
   Wharf_Factory_Variance integer NULL,
   Harvest_Process_Rejects integer NULL,
   Processor_Name varchar(30) NULL,
   Blood_Loss numeric(3,1) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Harvest_Detail_Harvest_Ref_No ON Harvest_Detail (Harvest_Ref_No,Harvest_Date,Fish_Id,Harvest_Time,Stock_Name);

CREATE INDEX Harvest_Detail_Supplier_Name ON Harvest_Detail (Supplier_Name);

DROP TABLE Harvest_Process;

CREATE TABLE Harvest_Process (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Harvest_Date varchar(10) NOT NULL,
   Processor_Name varchar(30) NOT NULL,
   Process_Date varchar(10) NOT NULL,
   Process_Time varchar(10) NOT NULL,
   TTitle char(1) NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Tdummy7 char(1) NULL,
   Prem_2 integer NULL,
   HOGG_Biomass_2 numeric(10,3) NULL,
   Avg_HOGG_2 numeric(8,4) NULL,
   Boxes_2 integer NULL,
   Prem_25 integer NULL,
   HOGG_Biomass_25 numeric(10,3) NULL,
   Avg_HOGG_25 numeric(8,4) NULL,
   Boxes_25 integer NULL,
   Prem_3 integer NULL,
   HOGG_Biomass_3 numeric(10,3) NULL,
   Avg_HOGG_3 numeric(8,4) NULL,
   Boxes_3 integer NULL,
   Prem_35 integer NULL,
   HOGG_Biomass_35 numeric(10,3) NULL,
   Avg_HOGG_35 numeric(8,4) NULL,
   Boxes_35 integer NULL,
   Prem_4 integer NULL,
   HOGG_Biomass_4 numeric(10,3) NULL,
   Avg_HOGG_4 numeric(8,4) NULL,
   Boxes_4 integer NULL,
   Prem_5 integer NULL,
   HOGG_Biomass_5 numeric(10,3) NULL,
   Avg_HOGG_5 numeric(8,4) NULL,
   Boxes_5 integer NULL,
   Prem_6 integer NULL,
   HOGG_Biomass_6 numeric(10,3) NULL,
   Avg_HOGG_6 numeric(8,4) NULL,
   Boxes_6 integer NULL,
   Prem_7 integer NULL,
   HOGG_Biomass_7 numeric(10,3) NULL,
   Avg_HOGG_7 numeric(8,4) NULL,
   Boxes_7 integer NULL,
   Prem_8 integer NULL,
   HOGG_Biomass_8 numeric(10,3) NULL,
   Avg_HOGG_8 numeric(8,4) NULL,
   Boxes_8 integer NULL,
   HS_Cat_1_A varchar(20) NULL,
   HS_Fish_No_1_A integer NULL,
   HS_Biomass_1_A numeric(10,2) NULL,
   HS_Ctn_1_A integer NULL,
   HS_Cat_2_A varchar(20) NULL,
   HS_Fish_No_2_A integer NULL,
   HS_Biomass_2_A numeric(10,2) NULL,
   HS_Ctn_2_A integer NULL,
   HS_Cat_3_A varchar(20) NULL,
   HS_Fish_No_3_A integer NULL,
   HS_Biomass_3_A numeric(10,2) NULL,
   HS_Ctn_3_A integer NULL,
   HS_Cat_4_A varchar(20) NULL,
   HS_Fish_No_4_A integer NULL,
   HS_Biomass_4_A numeric(10,2) NULL,
   HS_Ctn_4_A integer NULL,
   HS_Cat_5_A varchar(20) NULL,
   HS_Fish_No_5_A integer NULL,
   HS_Biomass_5_A numeric(10,2) NULL,
   HS_Ctn_5_A integer NULL,
   Total_Count_Prem integer NULL,
   Total_Biomass_Prem numeric(10,3) NULL,
   Total_Prem_Avg numeric(12,4) NULL,
   Tdummy4 char(1) NULL,
   TTitle2 char(1) NULL,
   Tdummy5 char(1) NULL,
   Tdummy6 char(1) NULL,
   Tdummy8 char(1) NULL,
   Vaps_2 integer NULL,
   HOGG_Biomass_2V numeric(10,3) NULL,
   Avg_HOGG_2V numeric(8,4) NULL,
   Boxes_2V integer NULL,
   Vaps_25 integer NULL,
   HOGG_Biomass_25V numeric(10,3) NULL,
   Avg_HOGG_25V numeric(8,4) NULL,
   Boxes_25V integer NULL,
   Vaps_3 integer NULL,
   HOGG_Biomass_3V numeric(10,3) NULL,
   Avg_HOGG_3V numeric(8,4) NULL,
   Boxes_3V integer NULL,
   Vaps_35 integer NULL,
   HOGG_Biomass_35V numeric(10,3) NULL,
   Avg_HOGG_35V numeric(8,4) NULL,
   Boxes_35V integer NULL,
   Vaps_4 integer NULL,
   HOGG_Biomass_4V numeric(10,3) NULL,
   Avg_HOGG_4V numeric(8,4) NULL,
   Boxes_4V integer NULL,
   Vaps_5 integer NULL,
   HOGG_Biomass_5V numeric(10,3) NULL,
   Avg_HOGG_5V numeric(8,4) NULL,
   Boxes_5V integer NULL,
   Vaps_6 integer NULL,
   HOGG_Biomass_6V numeric(10,3) NULL,
   Avg_HOGG_6V numeric(8,4) NULL,
   Boxes_6V integer NULL,
   Vaps_7 integer NULL,
   HOGG_Biomass_7V numeric(10,3) NULL,
   Avg_HOGG_7V numeric(8,4) NULL,
   Boxes_7V integer NULL,
   Vaps_8 integer NULL,
   HOGG_Biomass_8V numeric(10,3) NULL,
   Avg_HOGG_8V numeric(8,4) NULL,
   Boxes_8V integer NULL,
   HS_Cat_1_B varchar(20) NULL,
   HS_Fish_No_1_B integer NULL,
   HS_Biomass_1_B numeric(10,2) NULL,
   HS_Ctn_1_B integer NULL,
   HS_Cat_2_B varchar(20) NULL,
   HS_Fish_No_2_B integer NULL,
   HS_Biomass_2_B numeric(10,2) NULL,
   HS_Ctn_2_B integer NULL,
   HS_Cat_3_B varchar(20) NULL,
   HS_Fish_No_3_B integer NULL,
   HS_Biomass_3_B numeric(10,2) NULL,
   HS_Ctn_3_B integer NULL,
   HS_Cat_4_B varchar(20) NULL,
   HS_Fish_No_4_B integer NULL,
   HS_Biomass_4_B numeric(10,2) NULL,
   HS_Ctn_4_B integer NULL,
   HS_Cat_5_B varchar(20) NULL,
   HS_Fish_No_5_B integer NULL,
   HS_Biomass_5_B numeric(10,2) NULL,
   HS_Ctn_5_B integer NULL,
   Total_Count_Vaps integer NULL,
   Total_Biomass_Vaps numeric(10,3) NULL,
   Total_Vaps_Avg numeric(12,4) NULL,
   TTitle3 char(1) NULL,
   Tdummy9 char(1) NULL,
   Tdummy10 char(1) NULL,
   Tdummy11 char(1) NULL,
   Tdummy13 char(1) NULL,
   Export_2 integer NULL,
   HOGG_Biomass_2E numeric(10,3) NULL,
   Avg_HOGG_2E numeric(8,4) NULL,
   Boxes_2E integer NULL,
   Export_25 integer NULL,
   HOGG_Biomass_25E numeric(10,3) NULL,
   Avg_HOGG_25E numeric(8,4) NULL,
   Boxes_25E integer NULL,
   Export_3 integer NULL,
   HOGG_Biomass_3E numeric(10,3) NULL,
   Avg_HOGG_3E numeric(8,4) NULL,
   Boxes_3E integer NULL,
   Export_35 integer NULL,
   HOGG_Biomass_35E numeric(10,3) NULL,
   Avg_HOGG_35E numeric(8,4) NULL,
   Boxes_35E integer NULL,
   Export_4 integer NULL,
   HOGG_Biomass_4E numeric(10,3) NULL,
   Avg_HOGG_4E numeric(8,4) NULL,
   Boxes_4E integer NULL,
   Export_5 integer NULL,
   HOGG_Biomass_5E numeric(10,3) NULL,
   Avg_HOGG_5E numeric(8,4) NULL,
   Boxes_5E integer NULL,
   Export_6 integer NULL,
   HOGG_Biomass_6E numeric(10,3) NULL,
   Avg_HOGG_6E numeric(8,4) NULL,
   Boxes_6E integer NULL,
   Export_7 integer NULL,
   HOGG_Biomass_7E numeric(10,3) NULL,
   Avg_HOGG_7E numeric(8,4) NULL,
   Boxes_7E integer NULL,
   Export_8 integer NULL,
   HOGG_Biomass_8E numeric(10,3) NULL,
   Avg_HOGG_8E numeric(8,4) NULL,
   Boxes_8E integer NULL,
   HS_Cat_1_E varchar(20) NULL,
   HS_Fish_No_1_E integer NULL,
   HS_Biomass_1_E numeric(10,2) NULL,
   HS_Ctn_1_E integer NULL,
   HS_Cat_2_E varchar(20) NULL,
   HS_Fish_No_2_E integer NULL,
   HS_Biomass_2_E numeric(10,2) NULL,
   HS_Ctn_2_E integer NULL,
   HS_Cat_3_E varchar(20) NULL,
   HS_Fish_No_3_E integer NULL,
   HS_Biomass_3_E numeric(10,2) NULL,
   HS_Ctn_3_E integer NULL,
   HS_Cat_4_E varchar(20) NULL,
   HS_Fish_No_4_E integer NULL,
   HS_Biomass_4_E numeric(10,2) NULL,
   HS_Ctn_4_E integer NULL,
   HS_Cat_5_E varchar(20) NULL,
   HS_Fish_No_5_E integer NULL,
   HS_Biomass_5_E numeric(10,2) NULL,
   HS_Ctn_5_E integer NULL,
   Total_Count_Export integer NULL,
   Total_Biomass_Export numeric(10,3) NULL,
   Total_Export_Avg numeric(12,4) NULL,
   Comment varchar(200) NULL,
   Harvest_Process_Rejects integer NULL,
   TDummy14 char(1) NULL,
   TDummy15 char(1) NULL,
   Tdummy16 char(1) NULL,
   Tdummy17 char(1) NULL,
   Tdummy18 char(1) NULL,
   Tdummy19 char(1) NULL,
   Tdummy20 char(1) NULL,
   HS_Cat_1 varchar(20) NULL,
   HS_Fish_No_1 integer NULL,
   HS_Biomass_1 numeric(10,2) NULL,
   HS_Ctn_1 integer NULL,
   HS_Cat_2 varchar(20) NULL,
   HS_Fish_No_2 integer NULL,
   HS_Biomass_2 numeric(10,2) NULL,
   HS_Ctn_2 integer NULL,
   HS_Cat_3 varchar(20) NULL,
   HS_Fish_No_3 integer NULL,
   HS_Biomass_3 numeric(10,2) NULL,
   HS_Ctn_3 integer NULL,
   HS_Cat_4 varchar(20) NULL,
   HS_Fish_No_4 integer NULL,
   HS_Biomass_4 numeric(10,2) NULL,
   HS_Ctn_4 integer NULL,
   HS_Cat_5 varchar(20) NULL,
   HS_Fish_No_5 integer NULL,
   HS_Biomass_5 numeric(10,2) NULL,
   HS_Ctn_5 integer NULL,
   Total_HS integer NULL,
   Total_Biomass_HS numeric(10,3) NULL,
   Total_Avg_HS numeric(12,4) NULL,
   Total_Ctn_HS integer NULL,
   Table_Name varchar(60) NULL
);

CREATE UNIQUE CLUSTERED INDEX Harvest_Process_Name ON Harvest_Process (Name,Cust_Order_No,Order_Date,Order_Item,Harvest_Ref_No,Harvest_Date,Processor_Name,Process_Date,Process_Time);

DROP TABLE Harvest_Process_HO;

CREATE TABLE Harvest_Process_HO (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Harvest_Date varchar(10) NOT NULL,
   Processor_Name varchar(30) NOT NULL,
   Process_Date varchar(10) NOT NULL,
   Process_Time varchar(10) NOT NULL,
   TTitle char(1) NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Tdummy7 char(1) NULL,
   Prem_2 integer NULL,
   HOGG_Biomass_2 numeric(10,3) NULL,
   Avg_HOGG_2 numeric(8,4) NULL,
   Boxes_2 integer NULL,
   Prem_25 integer NULL,
   HOGG_Biomass_25 numeric(10,3) NULL,
   Avg_HOGG_25 numeric(8,4) NULL,
   Boxes_25 integer NULL,
   Prem_3 integer NULL,
   HOGG_Biomass_3 numeric(10,3) NULL,
   Avg_HOGG_3 numeric(8,4) NULL,
   Boxes_3 integer NULL,
   Prem_35 integer NULL,
   HOGG_Biomass_35 numeric(10,3) NULL,
   Avg_HOGG_35 numeric(8,4) NULL,
   Boxes_35 integer NULL,
   Prem_4 integer NULL,
   HOGG_Biomass_4 numeric(10,3) NULL,
   Avg_HOGG_4 numeric(8,4) NULL,
   Boxes_4 integer NULL,
   Prem_5 integer NULL,
   HOGG_Biomass_5 numeric(10,3) NULL,
   Avg_HOGG_5 numeric(8,4) NULL,
   Boxes_5 integer NULL,
   Prem_6 integer NULL,
   HOGG_Biomass_6 numeric(10,3) NULL,
   Avg_HOGG_6 numeric(8,4) NULL,
   Boxes_6 integer NULL,
   Prem_7 integer NULL,
   HOGG_Biomass_7 numeric(10,3) NULL,
   Avg_HOGG_7 numeric(8,4) NULL,
   Boxes_7 integer NULL,
   Prem_8 integer NULL,
   HOGG_Biomass_8 numeric(10,3) NULL,
   Avg_HOGG_8 numeric(8,4) NULL,
   Boxes_8 integer NULL,
   HS_Cat_1_A varchar(20) NULL,
   HS_Fish_No_1_A integer NULL,
   HS_Biomass_1_A numeric(10,2) NULL,
   HS_Ctn_1_A integer NULL,
   HS_Cat_2_A varchar(20) NULL,
   HS_Fish_No_2_A integer NULL,
   HS_Biomass_2_A numeric(10,2) NULL,
   HS_Ctn_2_A integer NULL,
   HS_Cat_3_A varchar(20) NULL,
   HS_Fish_No_3_A integer NULL,
   HS_Biomass_3_A numeric(10,2) NULL,
   HS_Ctn_3_A integer NULL,
   HS_Cat_4_A varchar(20) NULL,
   HS_Fish_No_4_A integer NULL,
   HS_Biomass_4_A numeric(10,2) NULL,
   HS_Ctn_4_A integer NULL,
   HS_Cat_5_A varchar(20) NULL,
   HS_Fish_No_5_A integer NULL,
   HS_Biomass_5_A numeric(10,2) NULL,
   HS_Ctn_5_A integer NULL,
   Total_Count_Prem integer NULL,
   Total_Biomass_Prem numeric(10,3) NULL,
   Total_Prem_Avg numeric(12,4) NULL,
   Tdummy4 char(1) NULL,
   TTitle2 char(1) NULL,
   Tdummy5 char(1) NULL,
   Tdummy6 char(1) NULL,
   Tdummy8 char(1) NULL,
   Vaps_2 integer NULL,
   HOGG_Biomass_2V numeric(10,3) NULL,
   Avg_HOGG_2V numeric(8,4) NULL,
   Boxes_2V integer NULL,
   Vaps_25 integer NULL,
   HOGG_Biomass_25V numeric(10,3) NULL,
   Avg_HOGG_25V numeric(8,4) NULL,
   Boxes_25V integer NULL,
   Vaps_3 integer NULL,
   HOGG_Biomass_3V numeric(10,3) NULL,
   Avg_HOGG_3V numeric(8,4) NULL,
   Boxes_3V integer NULL,
   Vaps_35 integer NULL,
   HOGG_Biomass_35V numeric(10,3) NULL,
   Avg_HOGG_35V numeric(8,4) NULL,
   Boxes_35V integer NULL,
   Vaps_4 integer NULL,
   HOGG_Biomass_4V numeric(10,3) NULL,
   Avg_HOGG_4V numeric(8,4) NULL,
   Boxes_4V integer NULL,
   Vaps_5 integer NULL,
   HOGG_Biomass_5V numeric(10,3) NULL,
   Avg_HOGG_5V numeric(8,4) NULL,
   Boxes_5V integer NULL,
   Vaps_6 integer NULL,
   HOGG_Biomass_6V numeric(10,3) NULL,
   Avg_HOGG_6V numeric(8,4) NULL,
   Boxes_6V integer NULL,
   Vaps_7 integer NULL,
   HOGG_Biomass_7V numeric(10,3) NULL,
   Avg_HOGG_7V numeric(8,4) NULL,
   Boxes_7V integer NULL,
   Vaps_8 integer NULL,
   HOGG_Biomass_8V numeric(10,3) NULL,
   Avg_HOGG_8V numeric(8,4) NULL,
   Boxes_8V integer NULL,
   HS_Cat_1_B varchar(20) NULL,
   HS_Fish_No_1_B integer NULL,
   HS_Biomass_1_B numeric(10,2) NULL,
   HS_Ctn_1_B integer NULL,
   HS_Cat_2_B varchar(20) NULL,
   HS_Fish_No_2_B integer NULL,
   HS_Biomass_2_B numeric(10,2) NULL,
   HS_Ctn_2_B integer NULL,
   HS_Cat_3_B varchar(20) NULL,
   HS_Fish_No_3_B integer NULL,
   HS_Biomass_3_B numeric(10,2) NULL,
   HS_Ctn_3_B integer NULL,
   HS_Cat_4_B varchar(20) NULL,
   HS_Fish_No_4_B integer NULL,
   HS_Biomass_4_B numeric(10,2) NULL,
   HS_Ctn_4_B integer NULL,
   HS_Cat_5_B varchar(20) NULL,
   HS_Fish_No_5_B integer NULL,
   HS_Biomass_5_B numeric(10,2) NULL,
   HS_Ctn_5_B integer NULL,
   Total_Count_Vaps integer NULL,
   Total_Biomass_Vaps numeric(10,3) NULL,
   Total_Vaps_Avg numeric(12,4) NULL,
   TTitle3 char(1) NULL,
   Tdummy9 char(1) NULL,
   Tdummy10 char(1) NULL,
   Tdummy11 char(1) NULL,
   Tdummy13 char(1) NULL,
   Export_2 integer NULL,
   HOGG_Biomass_2E numeric(10,3) NULL,
   Avg_HOGG_2E numeric(8,4) NULL,
   Boxes_2E integer NULL,
   Export_25 integer NULL,
   HOGG_Biomass_25E numeric(10,3) NULL,
   Avg_HOGG_25E numeric(8,4) NULL,
   Boxes_25E integer NULL,
   Export_3 integer NULL,
   HOGG_Biomass_3E numeric(10,3) NULL,
   Avg_HOGG_3E numeric(8,4) NULL,
   Boxes_3E integer NULL,
   Export_35 integer NULL,
   HOGG_Biomass_35E numeric(10,3) NULL,
   Avg_HOGG_35E numeric(8,4) NULL,
   Boxes_35E integer NULL,
   Export_4 integer NULL,
   HOGG_Biomass_4E numeric(10,3) NULL,
   Avg_HOGG_4E numeric(8,4) NULL,
   Boxes_4E integer NULL,
   Export_5 integer NULL,
   HOGG_Biomass_5E numeric(10,3) NULL,
   Avg_HOGG_5E numeric(8,4) NULL,
   Boxes_5E integer NULL,
   Export_6 integer NULL,
   HOGG_Biomass_6E numeric(10,3) NULL,
   Avg_HOGG_6E numeric(8,4) NULL,
   Boxes_6E integer NULL,
   Export_7 integer NULL,
   HOGG_Biomass_7E numeric(10,3) NULL,
   Avg_HOGG_7E numeric(8,4) NULL,
   Boxes_7E integer NULL,
   Export_8 integer NULL,
   HOGG_Biomass_8E numeric(10,3) NULL,
   Avg_HOGG_8E numeric(8,4) NULL,
   Boxes_8E integer NULL,
   HS_Cat_1_E varchar(20) NULL,
   HS_Fish_No_1_E integer NULL,
   HS_Biomass_1_E numeric(10,2) NULL,
   HS_Ctn_1_E integer NULL,
   HS_Cat_2_E varchar(20) NULL,
   HS_Fish_No_2_E integer NULL,
   HS_Biomass_2_E numeric(10,2) NULL,
   HS_Ctn_2_E integer NULL,
   HS_Cat_3_E varchar(20) NULL,
   HS_Fish_No_3_E integer NULL,
   HS_Biomass_3_E numeric(10,2) NULL,
   HS_Ctn_3_E integer NULL,
   HS_Cat_4_E varchar(20) NULL,
   HS_Fish_No_4_E integer NULL,
   HS_Biomass_4_E numeric(10,2) NULL,
   HS_Ctn_4_E integer NULL,
   HS_Cat_5_E varchar(20) NULL,
   HS_Fish_No_5_E integer NULL,
   HS_Biomass_5_E numeric(10,2) NULL,
   HS_Ctn_5_E integer NULL,
   Total_Count_Export integer NULL,
   Total_Biomass_Export numeric(10,3) NULL,
   Total_Export_Avg numeric(12,4) NULL,
   Comment varchar(200) NULL,
   Harvest_Process_Rejects integer NULL,
   TDummy14 char(1) NULL,
   TDummy15 char(1) NULL,
   Tdummy16 char(1) NULL,
   Tdummy17 char(1) NULL,
   Tdummy18 char(1) NULL,
   Tdummy19 char(1) NULL,
   Tdummy20 char(1) NULL,
   HS_Cat_1 varchar(20) NULL,
   HS_Fish_No_1 integer NULL,
   HS_Biomass_1 numeric(10,2) NULL,
   HS_Ctn_1 integer NULL,
   HS_Cat_2 varchar(20) NULL,
   HS_Fish_No_2 integer NULL,
   HS_Biomass_2 numeric(10,2) NULL,
   HS_Ctn_2 integer NULL,
   HS_Cat_3 varchar(20) NULL,
   HS_Fish_No_3 integer NULL,
   HS_Biomass_3 numeric(10,2) NULL,
   HS_Ctn_3 integer NULL,
   HS_Cat_4 varchar(20) NULL,
   HS_Fish_No_4 integer NULL,
   HS_Biomass_4 numeric(10,2) NULL,
   HS_Ctn_4 integer NULL,
   HS_Cat_5 varchar(20) NULL,
   HS_Fish_No_5 integer NULL,
   HS_Biomass_5 numeric(10,2) NULL,
   HS_Ctn_5 integer NULL,
   Total_HS integer NULL,
   Total_Biomass_HS numeric(10,3) NULL,
   Total_Avg_HS numeric(12,4) NULL,
   Total_Ctn_HS integer NULL,
   Table_Name varchar(60) NULL
);

CREATE UNIQUE CLUSTERED INDEX Harvest_Process_HO_Name ON Harvest_Process_HO (Name,Cust_Order_No,Order_Date,Order_Item,Harvest_Ref_No,Harvest_Date,Processor_Name,Process_Date,Process_Time);

DROP TABLE Hatchery;

CREATE TABLE Hatchery (
   Name varchar(40) NOT NULL,
   Contact varchar(30) NULL,
   Address varchar(50) NULL,
   Suburb varchar(30) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL,
   Sales_Tax varchar(10) NULL,
   ABN_No varchar(20) NULL,
   ACN_No varchar(20) NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Hatchery_Name ON Hatchery (Name);

DROP TABLE Hatchery_Despatch;

CREATE TABLE Hatchery_Despatch (
   Fish_Id varchar(10) NOT NULL,
   Despatch_Form_No varchar(10) NOT NULL,
   Fish_Stock_No integer NOT NULL,
   Despatch_Date varchar(10) NOT NULL,
   Fish_Medication varchar(70) NULL,
   Feed_Type varchar(30) NULL,
   Water_Temp numeric(4,2) NOT NULL,
   Carrier_Name varchar(30) NULL,
   Driver_Name varchar(30) NULL,
   Staff_Name varchar(20) NULL,
   Total_Fish integer NULL,
   Total_Weight numeric(10,2) NULL,
   Mean_Weight numeric(10,2) NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Hatchery_Despatch_Fish_Id ON Hatchery_Despatch (Fish_Id,Despatch_Form_No);

CREATE INDEX Hatchery_Despatch_Fish_Stock_No ON Hatchery_Despatch (Fish_Stock_No);

CREATE INDEX Hatchery_Despatch_Despatch_Date ON Hatchery_Despatch (Despatch_Date);

CREATE INDEX Hatchery_Despatch_Carrier_Name ON Hatchery_Despatch (Carrier_Name);

CREATE INDEX Hatchery_Despatch_Staff_Name ON Hatchery_Despatch (Staff_Name);

DROP TABLE HP_Invoice_Detail;

CREATE TABLE HP_Invoice_Detail (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Harvest_Date varchar(10) NOT NULL,
   Processor_Name varchar(30) NOT NULL,
   Process_Date varchar(10) NOT NULL,
   Process_Time varchar(10) NOT NULL,
   Ref_No varchar(15) NOT NULL,
   Invoice_Type varchar(4) NOT NULL,
   Ctn_No integer NULL,
   Fish_No integer NULL,
   Biomass numeric(10,2) NULL,
   Invoice_Value numeric(10,2) NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX HP_Invoice_Detail_Name ON HP_Invoice_Detail (Name,Cust_Order_No,Order_Date,Order_Item,Harvest_Ref_No,Harvest_Date,Processor_Name,Process_Date,Process_Time,Ref_No);

DROP TABLE HP_Invoice_Detail_HO;

CREATE TABLE HP_Invoice_Detail_HO (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Harvest_Date varchar(10) NOT NULL,
   Processor_Name varchar(30) NOT NULL,
   Process_Date varchar(10) NOT NULL,
   Process_Time varchar(10) NOT NULL,
   Ref_No varchar(15) NOT NULL,
   Invoice_Type varchar(4) NOT NULL,
   Ctn_No integer NULL,
   Fish_No integer NULL,
   Biomass numeric(10,2) NULL,
   Invoice_Value numeric(10,2) NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX HP_Invoice_Detail_HO_Name ON HP_Invoice_Detail_HO (Name,Cust_Order_No,Order_Date,Order_Item,Harvest_Ref_No,Harvest_Date,Processor_Name,Process_Date,Process_Time,Ref_No);

DROP TABLE HS_Fish_Sale_Item;

CREATE TABLE HS_Fish_Sale_Item (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Fish_Category_Name_1 varchar(20) NULL,
   No_Cartons_1 integer NULL,
   Comments_1 varchar(80) NULL,
   Fish_Category_Name_2 varchar(20) NULL,
   No_Cartons_2 integer NULL,
   Comments_2 varchar(80) NULL,
   Fish_Category_Name_3 varchar(20) NULL,
   No_Cartons_3 integer NULL,
   Comments_3 varchar(80) NULL,
   Fish_Category_Name_4 varchar(20) NULL,
   No_Cartons_4 integer NULL,
   Comments_4 varchar(80) NULL,
   Fish_Category_Name_5 varchar(20) NULL,
   No_Cartons_5 integer NULL,
   Comments_5 varchar(80) NULL
);

CREATE UNIQUE CLUSTERED INDEX HS_Fish_Sale_Item_Name ON HS_Fish_Sale_Item (Name,Cust_Order_No,Order_Date,Order_Item);

DROP TABLE Int_Feed_Move_Invoice;

CREATE TABLE Int_Feed_Move_Invoice (
   Feed_Move_Date varchar(10) NOT NULL,
   From_Company_Name varchar(30) NOT NULL,
   From_Site_Name varchar(20) NOT NULL,
   Del_Docket_No varchar(20) NOT NULL,
   Supplier_Name varchar(30) NOT NULL,
   Feed_Name varchar(40) NOT NULL,
   To_Company_Name varchar(30) NOT NULL,
   To_Site_Name varchar(20) NOT NULL,
   Load_No integer NOT NULL,
   Date_Invoice varchar(10) NOT NULL,
   Invoice_No varchar(20) NOT NULL,
   Qty_Feed numeric(10,2) NOT NULL,
   Invoice_Price numeric(10,2) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Int_Feed_Move_Invoice_Feed_Move_Date ON Int_Feed_Move_Invoice (Feed_Move_Date,From_Company_Name,From_Site_Name,Del_Docket_No,Supplier_Name,Feed_Name,To_Company_Name,To_Site_Name,Load_No,Date_Invoice,Invoice_No);

DROP TABLE Item_Category;

CREATE TABLE Item_Category (
   Item_Category varchar(50) NOT NULL,
   Comment varchar(255) NULL
);

CREATE UNIQUE CLUSTERED INDEX Item_Category_Item_Category ON Item_Category (Item_Category);

DROP TABLE Item_Type;

CREATE TABLE Item_Type (
   Name varchar(20) NOT NULL,
   Comment varchar(200) NULL,
   Item_Category varchar(50) NULL,
   Conv_Factor numeric(5,2) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Item_Type_Name ON Item_Type (Name);

DROP TABLE Liner;

CREATE TABLE Liner (
   Liner_Size integer NOT NULL,
   Liner_Depth numeric(10,2) NOT NULL,
   Est_Stocking_Density numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Liner_Liner_Size ON Liner (Liner_Size);

DROP TABLE Location;

CREATE TABLE Location (
   Supplier_Name varchar(30) NOT NULL,
   Loc_Name varchar(50) NOT NULL,
   Address varchar(200) NULL,
   Contact_Name varchar(100) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL
);

CREATE UNIQUE CLUSTERED INDEX Location_Supplier_Name ON Location (Supplier_Name,Loc_Name);

DROP TABLE Maintanence_Type;

CREATE TABLE Maintanence_Type (
   Name varchar(20) NOT NULL,
   Item_Name varchar(20) NOT NULL,
   Description varchar(80) NULL
);

CREATE UNIQUE CLUSTERED INDEX Maintanence_Type_Name ON Maintanence_Type (Name,Item_Name);

DROP TABLE Maintenance_Item;

CREATE TABLE Maintenance_Item (
   Job_No varchar(15) NOT NULL,
   Maint_Schedule_Date varchar(10) NOT NULL,
   Completed_Date varchar(10) NOT NULL,
   Completed_Time varchar(8) NOT NULL,
   Work_Staff_Name varchar(20) NOT NULL,
   Maint_Details varchar(255) NULL,
   Replaced_Name varchar(40) NOT NULL,
   Replaced_Type_Name varchar(20) NULL,
   Items_Used integer NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Maintenance_Item_Job_No ON Maintenance_Item (Job_No,Maint_Schedule_Date,Completed_Date,Completed_Time);

CREATE INDEX Maintenance_Item_Work_Staff_Name ON Maintenance_Item (Work_Staff_Name);

CREATE INDEX Maintenance_Item_Replaced_Name ON Maintenance_Item (Replaced_Name);

CREATE INDEX Maintenance_Item_Replaced_Type_Name ON Maintenance_Item (Replaced_Type_Name);

DROP TABLE Maintenance_Schedule;

CREATE TABLE Maintenance_Schedule (
   Job_No integer NOT NULL,
   Schedule_Date varchar(10) NOT NULL,
   Fish_Id varchar(10) NULL,
   Cage_Id varchar(10) NULL,
   Vessel_Name varchar(20) NULL,
   Maint_Type_Name varchar(20) NOT NULL,
   Item_Name varchar(20) NOT NULL,
   Urgent_Att varchar(4) NULL,
   Suggest_Action varchar(150) NULL,
   Staff_Maint_Name varchar(20) NOT NULL,
   Comment varchar(200) NULL,
   Period varchar(20) NULL,
   Monday bit NOT NULL,
   Monday_Pm bit NOT NULL,
   Tuesday bit NOT NULL,
   Tuesday_Pm bit NOT NULL,
   Wednesday bit NOT NULL,
   Wednesday_Pm bit NOT NULL,
   Thursday bit NOT NULL,
   Thursday_Pm bit NOT NULL,
   Friday bit NOT NULL,
   Friday_Pm bit NOT NULL,
   Saturday bit NOT NULL,
   Saturday_Pm bit NOT NULL,
   Sunday bit NOT NULL,
   Sunday_Pm bit NOT NULL,
   Specific_Date1 varchar(10) NULL,
   Specific_Date2 varchar(10) NULL,
   Specific_Time varchar(8) NULL,
   Frequency varchar(20) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Maintenance_Schedule_Job_No ON Maintenance_Schedule (Job_No,Schedule_Date);

CREATE INDEX Maintenance_Schedule_Fish_Id ON Maintenance_Schedule (Fish_Id);

CREATE INDEX Maintenance_Schedule_Cage_Id ON Maintenance_Schedule (Cage_Id);

CREATE INDEX Maintenance_Schedule_Vessel_Name ON Maintenance_Schedule (Vessel_Name);

CREATE INDEX Maintenance_Schedule_Maint_Type_Name ON Maintenance_Schedule (Maint_Type_Name);

CREATE INDEX Maintenance_Schedule_Item_Name ON Maintenance_Schedule (Item_Name);

CREATE INDEX Maintenance_Schedule_Staff_Maint_Name ON Maintenance_Schedule (Staff_Maint_Name);

DROP TABLE Maint_Request;

CREATE TABLE Maint_Request (
   Maint_No integer NOT NULL,
   Request_Date varchar(10) NOT NULL,
   Status varchar(15) NOT NULL,
   Request_Name varchar(60) NOT NULL,
   Ack_Date varchar(10) NULL,
   Hazard varchar(150) NOT NULL,
   Cause varchar(150) NOT NULL,
   Ack_Name varchar(60) NULL,
   Ack_Details varchar(255) NULL,
   Request_Details varchar(255) NOT NULL,
   Action_Date varchar(10) NULL,
   Action_Name varchar(60) NULL,
   Action_Taken varchar(255) NULL,
   Request_Priority varchar(10) NOT NULL,
   Ack_Priority varchar(10) NULL,
   Assigned_Name varchar(60) NULL,
   Est_Time varchar(20) NULL
);

CREATE UNIQUE CLUSTERED INDEX Maint_Request_Maint_No ON Maint_Request (Maint_No);

CREATE INDEX Maint_Request_Request_Date ON Maint_Request (Request_Date);

CREATE INDEX Maint_Request_Request_Name ON Maint_Request (Request_Name);

CREATE INDEX Maint_Request_Ack_Name ON Maint_Request (Ack_Name);

CREATE INDEX Maint_Request_Action_Name ON Maint_Request (Action_Name);

CREATE INDEX Maint_Request_Assigned_Name ON Maint_Request (Assigned_Name);

DROP TABLE Menus;

CREATE TABLE Menus (
   Menu_Name varchar(15) NOT NULL,
   Menu_Item varchar(120) NOT NULL,
   Common varchar(4) NOT NULL,
   Description varchar(60) NOT NULL,
   Item_No integer NOT NULL,
   X_Pos integer NULL,
   Y_Pos integer NULL,
   Bitmap_Name varchar(20) NULL
);

CREATE UNIQUE CLUSTERED INDEX Menus_Menu_Name ON Menus (Menu_Name,Menu_Item);

DROP TABLE Menu_Items;

CREATE TABLE Menu_Items (
   Menu_Name varchar(15) NOT NULL,
   Menu_Item varchar(120) NOT NULL,
   Menu_Item_Name varchar(15) NOT NULL,
   Menu_Item_Name_Item varchar(120) NOT NULL,
   Common varchar(4) NOT NULL,
   Description varchar(60) NOT NULL,
   Item_No integer NULL
);

CREATE UNIQUE CLUSTERED INDEX Menu_Items_Menu_Name ON Menu_Items (Menu_Name,Menu_Item,Menu_Item_Name,Menu_Item_Name_Item);

DROP TABLE Mesh_Group;

CREATE TABLE Mesh_Group (
   Mesh_Group_Size varchar(10) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Mesh_Group_Mesh_Group_Size ON Mesh_Group (Mesh_Group_Size);

DROP TABLE Monitoring_Parameters;

CREATE TABLE Monitoring_Parameters (
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(20) NOT NULL,
   Schedule_Date varchar(10) NOT NULL,
   Monitor_Time varchar(10) NOT NULL,
   Parameters_Name varchar(30) NOT NULL,
   Parameter_Value varchar(20) NOT NULL,
   Report_Column_No integer NULL
);

CREATE UNIQUE CLUSTERED INDEX Monitoring_Parameters_Company_Name ON Monitoring_Parameters (Company_Name,Site_Name,Schedule_Date,Monitor_Time,Parameters_Name);

DROP TABLE Monitoring_Schedule;

CREATE TABLE Monitoring_Schedule (
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(20) NOT NULL,
   Monitor_Date varchar(10) NOT NULL,
   Monitor_Time varchar(10) NOT NULL,
   Temp0a numeric(10,2) NULL,
   Temp0p numeric(10,2) NULL,
   Temp3a numeric(10,2) NULL,
   Temp3p numeric(10,2) NULL,
   Temp5a numeric(10,2) NULL,
   Temp5p numeric(10,2) NULL,
   Salinity0a numeric(10,2) NULL,
   Salinity0p numeric(10,2) NULL,
   Salinity1a numeric(10,2) NULL,
   Salinity1p numeric(10,2) NULL,
   Salinity3a numeric(10,2) NULL,
   Salinity3p numeric(10,2) NULL,
   Salinity5a numeric(10,2) NULL,
   Salinity5p numeric(10,2) NULL,
   Halocline numeric(10,2) NULL,
   DOsn numeric(10,2) NULL,
   DO0p numeric(10,2) NULL,
   DOnt numeric(10,2) NULL,
   DO3p numeric(10,2) NULL,
   DOts numeric(10,2) NULL,
   DO5p numeric(10,2) NULL,
   DOst numeric(10,2) NULL,
   Secci_Depth_am varchar(8) NULL,
   Secci_Depth_am_m numeric(10,2) NULL,
   Secci_Depth_pm varchar(8) NULL,
   Secci_Depth_pm_m numeric(10,2) NULL,
   Comment varchar(200) NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Bivalve varchar(15) NULL,
   Tdummy3 char(1) NULL,
   Tdummy4 char(1) NULL,
   Copepod varchar(15) NULL,
   l_Aurelia varchar(15) NULL,
   A_Aurelia varchar(15) NULL,
   Crustacean varchar(15) NULL,
   Obelia varchar(15) NULL,
   Combs varchar(15) NULL,
   Tdummy5 char(1) NULL,
   Turritopsis varchar(15) NULL,
   Salps varchar(15) NULL,
   Lions_Mane varchar(15) NULL,
   Zoo_Comment varchar(255) NULL,
   Tdummy6 char(1) NULL,
   Tdummy7 char(1) NULL,
   Cfurca varchar(15) NULL,
   Cfusus varchar(15) NULL,
   Gcaterernatum varchar(15) NULL,
   Gpulchellum varchar(15) NULL,
   Ctripos varchar(15) NULL,
   CSpp varchar(15) NULL,
   Tdummy8 char(1) NULL,
   Tdummy9 char(1) NULL,
   Ppellucidum varchar(15) NULL,
   PSpp varchar(15) NULL,
   Pgracile varchar(15) NULL,
   PPSpp varchar(15) NULL,
   Tdummy10 char(1) NULL,
   Tdummy11 char(1) NULL,
   Dacuminata varchar(15) NULL,
   Dfortii varchar(15) NULL,
   Noctscin varchar(15) NULL,
   Pfiesteria varchar(15) NULL,
   DSpp varchar(15) NULL,
   Alexandrium varchar(15) NULL,
   Chatonella varchar(15) NULL,
   Heterosigma varchar(15) NULL,
   Takayama_tasmanica varchar(15) NULL,
   Takayama_helix varchar(15) NULL,
   Karenia varchar(15) NULL,
   Karlodinium varchar(15) NULL,
   Dino_Comment varchar(255) NULL,
   Tdummy12 char(1) NULL,
   Tdummy13 char(1) NULL,
   Tdummy14 char(1) NULL,
   DCSocialis varchar(15) NULL,
   DCdebilis varchar(15) NULL,
   DPseuSpp varchar(15) NULL,
   DCCriophilus varchar(15) NULL,
   DCSpp varchar(15) NULL,
   Tdummy15 char(1) NULL,
   Tdummy16 char(1) NULL,
   DRSpp varchar(15) NULL,
   DTSpp varchar(15) NULL,
   Diatom_Comment varchar(255) NULL,
   Tdummy17 char(1) NULL
);

CREATE UNIQUE CLUSTERED INDEX Monitoring_Schedule_Company_Name ON Monitoring_Schedule (Company_Name,Site_Name,Monitor_Date,Monitor_Time);

DROP TABLE Mooring_Id;

CREATE TABLE Mooring_Id (
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(20) NOT NULL,
   Mooring_Id varchar(15) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Mooring_Id_Site_Name ON Mooring_Id (Site_Name,Mooring_Id);

CREATE INDEX Mooring_Id_Company_Name ON Mooring_Id (Company_Name);

DROP TABLE Mooring_Position;

CREATE TABLE Mooring_Position (
   Site_Name varchar(20) NOT NULL,
   Mooring_Id varchar(15) NOT NULL,
   Occupy_Date varchar(10) NOT NULL,
   GPS_Position varchar(20) NULL,
   Longtitude varchar(10) NULL,
   Latitude varchar(10) NULL,
   Grid_Ref_No varchar(20) NULL,
   GPS_Position_2 varchar(20) NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Mooring_Position_Site_Name ON Mooring_Position (Site_Name,Mooring_Id,Occupy_Date);

DROP TABLE Mort_Dive;

CREATE TABLE Mort_Dive (
   Job_No integer NOT NULL,
   Dive_Date varchar(10) NOT NULL,
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(20) NOT NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Mort_Dive_Job_No ON Mort_Dive (Job_No,Dive_Date,Company_Name,Site_Name);

DROP TABLE Mort_Dive_Item;

CREATE TABLE Mort_Dive_Item (
   Job_No integer NOT NULL,
   Dive_Date varchar(10) NOT NULL,
   Dive_Time varchar(10) NOT NULL,
   Fish_Id varchar(10) NOT NULL,
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(20) NOT NULL,
   Diver_Name varchar(20) NOT NULL,
   Total_Morts integer NULL,
   Good_fish integer NULL,
   Old integer NULL,
   Bent integer NULL,
   Def_Jaw integer NULL,
   Parr integer NULL,
   Pinhead integer NULL,
   Runts integer NULL,
   Mature_Male integer NULL,
   Mature_Female integer NULL,
   Seal_Strike integer NULL,
   Bird_Strike integer NULL,
   Jellyfish integer NULL,
   Other_Predator integer NULL,
   Sampling integer NULL,
   CN integer NULL,
   Handling integer NULL,
   Scale_Loss integer NULL,
   Amoeba integer NULL,
   CNSyndrome integer NULL,
   Yesiniosis integer NULL,
   Fish_Tail_Loss integer NULL,
   Lesion integer NULL,
   Opericulum integer NULL,
   Fin_Rot integer NULL,
   ED integer NULL,
   Other integer NULL,
   Trout integer NULL,
   Squid integer NULL,
   Fish_count integer NULL,
   Comments varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Mort_Dive_Item_Job_No ON Mort_Dive_Item (Job_No,Dive_Date,Dive_Time,Fish_Id);

CREATE INDEX Mort_Dive_Item_Company_Name ON Mort_Dive_Item (Company_Name);

CREATE INDEX Mort_Dive_Item_Site_Name ON Mort_Dive_Item (Site_Name);

CREATE INDEX Mort_Dive_Item_Diver_Name ON Mort_Dive_Item (Diver_Name);

DROP TABLE Mort_Size_Range;

CREATE TABLE Mort_Size_Range (
   Size_Name varchar(30) NOT NULL,
   Start_Size numeric(10,2) NOT NULL,
   End_Size numeric(10,2) NOT NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Mort_Size_Range_Size_Name ON Mort_Size_Range (Size_Name,Start_Size,End_Size);

DROP TABLE Net;

CREATE TABLE Net (
   Net_No varchar(20) NOT NULL,
   Cage_Size varchar(10) NOT NULL,
   In_Use varchar(4) NULL,
   Net_Status varchar(30) NOT NULL,
   Mesh_Group_Size varchar(10) NOT NULL,
   Net_Depth numeric(3,1) NULL,
   Net_Depth_Cone numeric(3,1) NULL,
   m3 integer NULL,
   Date_Manufactured varchar(10) NULL,
   Name varchar(30) NULL,
   Comment varchar(200) NULL,
   Cost_Price numeric(10,2) NULL,
   Net_Size varchar(10) NULL
);

CREATE UNIQUE CLUSTERED INDEX Net_Net_No ON Net (Net_No,Cage_Size);

CREATE INDEX Net_Mesh_Group_Size ON Net (Mesh_Group_Size);

CREATE INDEX Net_Name ON Net (Name);

CREATE INDEX Net_Net_Size ON Net (Net_Size);

DROP TABLE Net_Change;

CREATE TABLE Net_Change (
   Job_No integer NOT NULL,
   Job_Date varchar(10) NOT NULL,
   Fish_Id varchar(10) NULL,
   Cage_Id varchar(10) NULL,
   Date_Assigned varchar(10) NULL,
   Old_Net_No varchar(20) NOT NULL,
   Old_Date_Installed varchar(10) NOT NULL,
   Old_Cage_Size varchar(10) NULL,
   Cage_Net_Cage_Id varchar(10) NULL,
   Current_Loc varchar(80) NULL,
   Staff_Maint_Name varchar(20) NOT NULL,
   Side_Above varchar(5) NULL,
   Side_Below varchar(5) NULL,
   Base_Panels varchar(5) NULL,
   New_Net_No varchar(20) NULL,
   New_Date_Installed varchar(10) NULL,
   New_Cage_Net_Cage_Id varchar(10) NULL,
   New_Net_Cage_Size varchar(10) NULL,
   Primary_Net varchar(4) NULL,
   Antifoul varchar(5) NULL,
   New_Side_Above varchar(5) NULL,
   New_Side_Below varchar(5) NULL,
   New_Base_Panels varchar(5) NULL,
   Comment varchar(200) NULL,
   Fish_count integer NULL,
   Change_Type varchar(10) NOT NULL,
   Net_Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Net_Change_Job_No ON Net_Change (Job_No,Job_Date);

CREATE INDEX Net_Change_Fish_Id ON Net_Change (Fish_Id);

CREATE INDEX Net_Change_Cage_Id ON Net_Change (Cage_Id);

CREATE INDEX Net_Change_Date_Assigned ON Net_Change (Date_Assigned);

CREATE INDEX Net_Change_Old_Net_No ON Net_Change (Old_Net_No);

CREATE INDEX Net_Change_Old_Date_Installed ON Net_Change (Old_Date_Installed);

CREATE INDEX Net_Change_Cage_Net_Cage_Id ON Net_Change (Cage_Net_Cage_Id);

CREATE INDEX Net_Change_Staff_Maint_Name ON Net_Change (Staff_Maint_Name);

CREATE INDEX Net_Change_New_Net_No ON Net_Change (New_Net_No);

CREATE INDEX Net_Change_New_Date_Installed ON Net_Change (New_Date_Installed);

CREATE INDEX Net_Change_New_Cage_Net_Cage_Id ON Net_Change (New_Cage_Net_Cage_Id);

CREATE INDEX Net_Change_New_Net_Cage_Size ON Net_Change (New_Net_Cage_Size);

DROP TABLE Net_Change_History;

CREATE TABLE Net_Change_History (
   Job_No integer NOT NULL,
   Job_Date varchar(10) NOT NULL,
   Fish_Id varchar(10) NULL,
   Cage_Id varchar(10) NULL,
   Date_Assigned varchar(10) NULL,
   Old_Net_No varchar(20) NOT NULL,
   Old_Date_Installed varchar(10) NOT NULL,
   Old_Cage_Size varchar(10) NULL,
   Cage_Net_Cage_Id varchar(10) NULL,
   Current_Loc varchar(80) NULL,
   Staff_Maint_Name varchar(20) NOT NULL,
   Side_Above varchar(5) NULL,
   Side_Below varchar(5) NULL,
   Base_Panels varchar(5) NULL,
   New_Net_No varchar(20) NULL,
   New_Date_Installed varchar(10) NULL,
   New_Cage_Net_Cage_Id varchar(10) NULL,
   New_Net_Cage_Size varchar(10) NULL,
   Primary_Net varchar(4) NULL,
   Antifoul varchar(5) NULL,
   New_Side_Above varchar(5) NULL,
   New_Side_Below varchar(5) NULL,
   New_Base_Panels varchar(5) NULL,
   Comment varchar(200) NULL,
   Fish_count integer NULL,
   Change_Type varchar(10) NOT NULL,
   Net_Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Net_Change_History_Job_No ON Net_Change_History (Job_No,Job_Date);

CREATE INDEX Net_Change_History_Fish_Id ON Net_Change_History (Fish_Id);

CREATE INDEX Net_Change_History_Cage_Id ON Net_Change_History (Cage_Id);

CREATE INDEX Net_Change_History_Date_Assigned ON Net_Change_History (Date_Assigned);

CREATE INDEX Net_Change_History_Old_Net_No ON Net_Change_History (Old_Net_No);

CREATE INDEX Net_Change_History_Old_Date_Installed ON Net_Change_History (Old_Date_Installed);

CREATE INDEX Net_Change_History_Cage_Net_Cage_Id ON Net_Change_History (Cage_Net_Cage_Id);

CREATE INDEX Net_Change_History_Staff_Maint_Name ON Net_Change_History (Staff_Maint_Name);

CREATE INDEX Net_Change_History_New_Net_No ON Net_Change_History (New_Net_No);

CREATE INDEX Net_Change_History_New_Date_Installed ON Net_Change_History (New_Date_Installed);

CREATE INDEX Net_Change_History_New_Cage_Net_Cage_Id ON Net_Change_History (New_Cage_Net_Cage_Id);

CREATE INDEX Net_Change_History_New_Net_Cage_Size ON Net_Change_History (New_Net_Cage_Size);

DROP TABLE Net_Control;

CREATE TABLE Net_Control (
   Job_No integer NOT NULL,
   Job_Date varchar(10) NOT NULL,
   Net_No varchar(20) NOT NULL,
   Cage_Size varchar(10) NOT NULL,
   Cage_Id varchar(10) NOT NULL,
   Date_Installed varchar(10) NULL,
   Date_Removed varchar(10) NULL
);

CREATE UNIQUE CLUSTERED INDEX Net_Control_Job_No ON Net_Control (Job_No,Job_Date,Net_No,Cage_Size,Cage_Id);

CREATE INDEX Net_Control_Date_Installed ON Net_Control (Date_Installed);

CREATE INDEX Net_Control_Date_Removed ON Net_Control (Date_Removed);

DROP TABLE Net_Holes;

CREATE TABLE Net_Holes (
   Net_No varchar(20) NOT NULL,
   Net_Cage_Size varchar(10) NOT NULL,
   Repair_Date varchar(10) NOT NULL,
   Repair_Time varchar(8) NOT NULL,
   Repaired_By varchar(20) NOT NULL,
   Hole_Location varchar(100) NOT NULL,
   Repair_done varchar(10) NULL,
   Hole_Was varchar(25) NULL,
   Mend varchar(10) NULL,
   Repair_Was varchar(20) NULL,
   Cause_Hole varchar(20) NULL,
   Hole_Size varchar(30) NULL,
   No_Hole_1 integer NULL,
   Hole_Size_1 varchar(40) NULL,
   No_Hole_2 integer NULL,
   Hole_Size_2 varchar(40) NULL,
   No_Hole_3 integer NULL,
   Hole_Size_3 varchar(40) NULL,
   No_Hole_4 integer NULL,
   Hole_Size_4 varchar(40) NULL,
   No_Hole_5 integer NULL,
   Hole_Size_5 varchar(40) NULL,
   Comment varchar(400) NULL
);

CREATE UNIQUE CLUSTERED INDEX Net_Holes_Net_No ON Net_Holes (Net_No,Net_Cage_Size,Repair_Date,Repair_Time,Repaired_By,Hole_Location);

DROP TABLE Net_Profile;

CREATE TABLE Net_Profile (
   Net_No varchar(20) NOT NULL,
   Check_Date varchar(10) NOT NULL,
   Cage_Size varchar(10) NOT NULL,
   Net_Status varchar(30) NOT NULL,
   Mesh_Group_Size varchar(10) NOT NULL,
   Net_Depth integer NOT NULL,
   m3 integer NULL,
   Tdummy char(1) NULL,
   Mesh_Size varchar(10) NOT NULL,
   Date_Checked varchar(10) NULL,
   Ply varchar(10) NULL,
   Swim_Door_Size_Depth numeric(10,2) NULL,
   Swim_Door_Size_Width numeric(10,2) NULL,
   Circumference numeric(10,2) NULL,
   Jump_Fence numeric(6,2) NULL,
   Side numeric(6,2) NULL,
   General_Condition varchar(30) NULL,
   Deflect_Flat_Base varchar(10) NULL,
   Comment varchar(200) NULL,
   Date_Strength_Tested varchar(10) NULL,
   Breaking_Strain_Side numeric(7,2) NULL,
   Breaking_Strain_Base numeric(7,2) NULL,
   Breaking_Strain_Jump_Fence numeric(7,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Net_Profile_Net_No ON Net_Profile (Net_No,Check_Date);

CREATE INDEX Net_Profile_Date_Checked ON Net_Profile (Date_Checked);

DROP TABLE Net_Score;

CREATE TABLE Net_Score (
   Net_No varchar(20) NOT NULL,
   Cage_Id varchar(10) NOT NULL,
   Cage_Size varchar(10) NULL,
   Date_Installed varchar(10) NOT NULL,
   Score_Date varchar(10) NOT NULL,
   Feeder_Staff_Name varchar(20) NULL,
   Dive_Job_No integer NULL,
   Dive_Fish_Id varchar(10) NULL,
   Mort_Job_No integer NULL,
   Mort_Dive_Date varchar(10) NULL,
   Mort_Dive_Time varchar(10) NULL,
   Mort_Fish_Id varchar(10) NULL,
   Side_Above varchar(5) NULL,
   Side_Below varchar(5) NULL,
   Base_Panels varchar(5) NULL,
   Holes varchar(100) NULL,
   Comment varchar(100) NULL,
   Net_Use_Type varchar(15) NULL,
   NW_Cage_Id varchar(10) NULL,
   NW_Net_No varchar(20) NULL,
   NW_Date_Installed varchar(10) NULL,
   Date_Washed varchar(10) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Net_Score_Net_No ON Net_Score (Net_No,Cage_Id,Score_Date);

CREATE INDEX Net_Score_Cage_Size ON Net_Score (Cage_Size);

CREATE INDEX Net_Score_Date_Installed ON Net_Score (Date_Installed);

CREATE INDEX Net_Score_Feeder_Staff_Name ON Net_Score (Feeder_Staff_Name);

CREATE INDEX Net_Score_Dive_Job_No ON Net_Score (Dive_Job_No);

CREATE INDEX Net_Score_Dive_Fish_Id ON Net_Score (Dive_Fish_Id);

CREATE INDEX Net_Score_Mort_Job_No ON Net_Score (Mort_Job_No);

CREATE INDEX Net_Score_Mort_Dive_Date ON Net_Score (Mort_Dive_Date);

CREATE INDEX Net_Score_Mort_Fish_Id ON Net_Score (Mort_Fish_Id);

CREATE INDEX Net_Score_NW_Cage_Id ON Net_Score (NW_Cage_Id);

CREATE INDEX Net_Score_NW_Net_No ON Net_Score (NW_Net_No);

CREATE INDEX Net_Score_NW_Date_Installed ON Net_Score (NW_Date_Installed);

DROP TABLE Net_Score_History;

CREATE TABLE Net_Score_History (
   Net_No varchar(20) NOT NULL,
   Cage_Id varchar(10) NOT NULL,
   Cage_Size varchar(10) NULL,
   Date_Installed varchar(10) NOT NULL,
   Score_Date varchar(10) NOT NULL,
   Feeder_Staff_Name varchar(20) NULL,
   Dive_Job_No integer NULL,
   Dive_Fish_Id varchar(10) NULL,
   Mort_Job_No integer NULL,
   Mort_Dive_Date varchar(10) NULL,
   Mort_Dive_Time varchar(10) NULL,
   Mort_Fish_Id varchar(10) NULL,
   Side_Above varchar(5) NULL,
   Side_Below varchar(5) NULL,
   Base_Panels varchar(5) NULL,
   Holes varchar(20) NULL,
   Comment varchar(100) NULL
);

CREATE UNIQUE CLUSTERED INDEX Net_Score_History_Net_No ON Net_Score_History (Net_No,Cage_Id,Score_Date);

CREATE INDEX Net_Score_History_Cage_Size ON Net_Score_History (Cage_Size);

CREATE INDEX Net_Score_History_Date_Installed ON Net_Score_History (Date_Installed);

CREATE INDEX Net_Score_History_Feeder_Staff_Name ON Net_Score_History (Feeder_Staff_Name);

CREATE INDEX Net_Score_History_Dive_Job_No ON Net_Score_History (Dive_Job_No);

CREATE INDEX Net_Score_History_Dive_Fish_Id ON Net_Score_History (Dive_Fish_Id);

CREATE INDEX Net_Score_History_Mort_Job_No ON Net_Score_History (Mort_Job_No);

CREATE INDEX Net_Score_History_Mort_Dive_Date ON Net_Score_History (Mort_Dive_Date);

CREATE INDEX Net_Score_History_Mort_Fish_Id ON Net_Score_History (Mort_Fish_Id);

DROP TABLE Net_Size;

CREATE TABLE Net_Size (
   Net_Size varchar(10) NOT NULL,
   Ply varchar(10) NULL,
   Swim_Door_Size_Depth numeric(10,2) NULL,
   Swim_Door_Size_Width numeric(10,2) NULL,
   Circumference numeric(10,2) NULL,
   Jump_Fence numeric(6,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Net_Size_Net_Size ON Net_Size (Net_Size);

DROP TABLE Net_Wash;

CREATE TABLE Net_Wash (
   Cage_Id varchar(10) NOT NULL,
   Net_No varchar(20) NOT NULL,
   Date_Installed varchar(10) NOT NULL,
   Date_Washed varchar(10) NOT NULL,
   Date_Antifouled varchar(10) NULL,
   Depth_Washed varchar(20) NOT NULL,
   Airlift varchar(4) NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Net_Wash_Cage_Id ON Net_Wash (Cage_Id,Net_No,Date_Installed,Date_Washed);

DROP TABLE Orders;

CREATE TABLE Orders (
   Order_No varchar(20) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Supplier_Name varchar(30) NOT NULL,
   Status varchar(20) NULL,
   Exp_Del_Date varchar(10) NULL,
   Delivery_Detail varchar(300) NULL,
   Carrier varchar(30) NULL
);

CREATE UNIQUE CLUSTERED INDEX Orders_Order_No ON Orders (Order_No,Order_Date);

CREATE INDEX Orders_Supplier_Name ON Orders (Supplier_Name);

CREATE INDEX Orders_Exp_Del_Date ON Orders (Exp_Del_Date);

DROP TABLE Order_Item;

CREATE TABLE Order_Item (
   Order_No varchar(20) NOT NULL,
   Supplier_Name varchar(30) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Stock_Item_Type varchar(20) NOT NULL,
   Year_Class varchar(6) NULL,
   Order_Date varchar(10) NOT NULL,
   Qty_Ordered numeric(10,2) NOT NULL,
   Status varchar(20) NULL,
   Exp_Del_Date varchar(10) NULL,
   Cost_Price numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Order_Item_Order_No ON Order_Item (Order_No,Supplier_Name,Stock_Name);

CREATE INDEX Order_Item_Stock_Item_Type ON Order_Item (Stock_Item_Type);

CREATE INDEX Order_Item_Order_Date ON Order_Item (Order_Date);

CREATE INDEX Order_Item_Exp_Del_Date ON Order_Item (Exp_Del_Date);

DROP TABLE Order_Location;

CREATE TABLE Order_Location (
   Order_No varchar(20) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Supplier_Name varchar(30) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Loc_Name varchar(50) NOT NULL,
   Sup_Loc_Name varchar(30) NOT NULL,
   Qty_on_Hand numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Order_Location_Order_No ON Order_Location (Order_No,Supplier_Name,Stock_Name);

CREATE INDEX Order_Location_Order_Date ON Order_Location (Order_Date);

CREATE INDEX Order_Location_Loc_Name ON Order_Location (Loc_Name);

CREATE INDEX Order_Location_Sup_Loc_Name ON Order_Location (Sup_Loc_Name);

DROP TABLE Package_Size;

CREATE TABLE Package_Size (
   Pack_Size varchar(10) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Package_Size_Pack_Size ON Package_Size (Pack_Size);

DROP TABLE Package_Type;

CREATE TABLE Package_Type (
   Pack_Type varchar(10) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Package_Type_Pack_Type ON Package_Type (Pack_Type);

DROP TABLE Parameter;

CREATE TABLE Parameter (
   Name varchar(30) NOT NULL,
   Description varchar(50) NULL
);

CREATE UNIQUE CLUSTERED INDEX Parameter_Name ON Parameter (Name);

DROP TABLE Passwords;

CREATE TABLE Passwords (
   Password_Id varchar(20) NOT NULL,
   Value varchar(40) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Passwords_Password_Id ON Passwords (Password_Id);

DROP TABLE Pen;

CREATE TABLE Pen (
   Fish_Id varchar(10) NOT NULL,
   Src_Fish_Id varchar(10) NULL,
   Create_Date varchar(10) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Stock_Item_Type varchar(20) NOT NULL,
   Trial_Fish varchar(4) NULL,
   Smolt_Total integer NULL,
   Mort_Deaths integer NULL,
   Adjust_Count integer NULL,
   Swim_Off integer NULL,
   Swim_To integer NULL,
   Graded_From integer NULL,
   Graded integer NULL,
   Harvest_Count integer NULL,
   Fish_Total integer NULL,
   Total_Feed numeric(10,2) NULL,
   Biomass numeric(10,2) NULL,
   Avg_Weight numeric(10,2) NULL,
   Comment varchar(200) NULL,
   Status varchar(10) NULL,
   Graded_Fish varchar(4) NULL,
   Grade_Start_Weight numeric(10,2) NULL,
   Start_Fish_Count integer NULL,
   Status_Date_Changed varchar(10) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Pen_Fish_Id ON Pen (Fish_Id);

CREATE INDEX Pen_Src_Fish_Id ON Pen (Src_Fish_Id);

CREATE INDEX Pen_Create_Date ON Pen (Create_Date);

CREATE INDEX Pen_Stock_Name ON Pen (Stock_Name);

CREATE INDEX Pen_Stock_Item_Type ON Pen (Stock_Item_Type);

DROP TABLE Pen_FCR;

CREATE TABLE Pen_FCR (
   Fish_Id varchar(10) NOT NULL,
   FCR_Name varchar(15) NOT NULL,
   Start_Date varchar(10) NOT NULL,
   End_Date varchar(10) NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Pen_FCR_Fish_Id ON Pen_FCR (Fish_Id,FCR_Name,Start_Date);

DROP TABLE Pen_Movement;

CREATE TABLE Pen_Movement (
   Job_No integer NOT NULL,
   Fish_Id varchar(10) NOT NULL,
   Date_Moved varchar(10) NOT NULL,
   Cage_Id varchar(10) NOT NULL,
   Date_Assigned varchar(10) NOT NULL,
   Assigned_to varchar(20) NOT NULL,
   FishID_Fish_Id varchar(10) NOT NULL,
   Mooring_from_Mooring_Id varchar(15) NOT NULL,
   Mooring_from_Site_Name varchar(20) NOT NULL,
   Mooring_From_Occupy_Date varchar(10) NOT NULL,
   Mooring_to_Mooring_Id varchar(15) NOT NULL,
   Mooring_to_Site_Name varchar(20) NOT NULL,
   Mooring_To_Occupy_Date varchar(10) NOT NULL,
   Comment varchar(200) NULL,
   Total_Feed numeric(10,2) NULL,
   Fish_count integer NULL,
   Cage_size varchar(10) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Pen_Movement_Job_No ON Pen_Movement (Job_No,Fish_Id,Date_Moved);

CREATE INDEX Pen_Movement_Cage_Id ON Pen_Movement (Cage_Id);

CREATE INDEX Pen_Movement_Date_Assigned ON Pen_Movement (Date_Assigned);

CREATE INDEX Pen_Movement_Assigned_to ON Pen_Movement (Assigned_to);

CREATE INDEX Pen_Movement_FishID_Fish_Id ON Pen_Movement (FishID_Fish_Id);

CREATE INDEX Pen_Movement_Mooring_from_Mooring_Id ON Pen_Movement (Mooring_from_Mooring_Id);

CREATE INDEX Pen_Movement_Mooring_from_Site_Name ON Pen_Movement (Mooring_from_Site_Name);

CREATE INDEX Pen_Movement_Mooring_From_Occupy_Date ON Pen_Movement (Mooring_From_Occupy_Date);

CREATE INDEX Pen_Movement_Mooring_to_Mooring_Id ON Pen_Movement (Mooring_to_Mooring_Id);

CREATE INDEX Pen_Movement_Mooring_to_Site_Name ON Pen_Movement (Mooring_to_Site_Name);

CREATE INDEX Pen_Movement_Mooring_To_Occupy_Date ON Pen_Movement (Mooring_To_Occupy_Date);

DROP TABLE Plankton_Monitoring;

CREATE TABLE Plankton_Monitoring (
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(20) NOT NULL,
   Monitor_Date varchar(10) NOT NULL,
   Monitor_Time varchar(10) NOT NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Bivalve varchar(15) NULL,
   Tdummy3 char(1) NULL,
   Tdummy4 char(1) NULL,
   Copepod varchar(15) NULL,
   l_Aurelia varchar(15) NULL,
   A_Aurelia varchar(15) NULL,
   Crustacean varchar(15) NULL,
   Obelia varchar(15) NULL,
   Combs varchar(15) NULL,
   Tdummy5 char(1) NULL,
   Turritopsis varchar(15) NULL,
   Salps varchar(15) NULL,
   Lions_Mane varchar(15) NULL,
   Zoo_Comment varchar(255) NULL,
   Tdummy6 char(1) NULL,
   Tdummy7 char(1) NULL,
   Cfurca varchar(15) NULL,
   Cfusus varchar(15) NULL,
   Gcaterernatum varchar(15) NULL,
   Gpulchellum varchar(15) NULL,
   Ctripos varchar(15) NULL,
   CSpp varchar(15) NULL,
   Tdummy8 char(1) NULL,
   Tdummy9 char(1) NULL,
   Ppellucidum varchar(15) NULL,
   PSpp varchar(15) NULL,
   Pgracile varchar(15) NULL,
   PPSpp varchar(15) NULL,
   Tdummy10 char(1) NULL,
   Tdummy11 char(1) NULL,
   Dacuminata varchar(15) NULL,
   Dfortii varchar(15) NULL,
   Noctscin varchar(15) NULL,
   Pfiesteria varchar(15) NULL,
   DSpp varchar(15) NULL,
   Alexandrium varchar(15) NULL,
   Chatonella varchar(15) NULL,
   Heterosigma varchar(15) NULL,
   Takayama_tasmanica varchar(15) NULL,
   Takayama_helix varchar(15) NULL,
   Karenia varchar(15) NULL,
   Karlodinium varchar(15) NULL,
   Dino_Comment varchar(255) NULL,
   Tdummy12 char(1) NULL,
   Tdummy13 char(1) NULL,
   Tdummy14 char(1) NULL,
   DCSocialis varchar(15) NULL,
   DCdebilis varchar(15) NULL,
   DPseuSpp varchar(15) NULL,
   DCCriophilus varchar(15) NULL,
   DCSpp varchar(15) NULL,
   Tdummy15 char(1) NULL,
   Tdummy16 char(1) NULL,
   DRSpp varchar(15) NULL,
   DTSpp varchar(15) NULL,
   Diatom_Comment varchar(255) NULL,
   Tdummy17 char(1) NULL
);

CREATE UNIQUE CLUSTERED INDEX Plankton_Monitoring_Company_Name ON Plankton_Monitoring (Company_Name,Site_Name,Monitor_Date,Monitor_Time);

DROP TABLE Position_Type;

CREATE TABLE Position_Type (
   Position_Name varchar(30) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Position_Type_Position_Name ON Position_Type (Position_Name);

DROP TABLE Premium_Fish_Sale_Item;

CREATE TABLE Premium_Fish_Sale_Item (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Fish_Category_Name_1 varchar(20) NULL,
   No_Cartons_1 integer NULL,
   Comments_1 varchar(80) NULL,
   Fish_Category_Name_2 varchar(20) NULL,
   No_Cartons_2 integer NULL,
   Comments_2 varchar(80) NULL,
   Fish_Category_Name_3 varchar(20) NULL,
   No_Cartons_3 integer NULL,
   Comments_3 varchar(80) NULL,
   Fish_Category_Name_4 varchar(20) NULL,
   No_Cartons_4 integer NULL,
   Comments_4 varchar(80) NULL,
   Fish_Category_Name_5 varchar(20) NULL,
   No_Cartons_5 integer NULL,
   Comments_5 varchar(80) NULL
);

CREATE UNIQUE CLUSTERED INDEX Premium_Fish_Sale_Item_Name ON Premium_Fish_Sale_Item (Name,Cust_Order_No,Order_Date,Order_Item);

DROP TABLE Pricing;

CREATE TABLE Pricing (
   Customer_Name varchar(30) NOT NULL,
   Price_Date varchar(10) NOT NULL,
   Description varchar(50) NOT NULL,
   TTitle char(1) NULL,
   TDummy1 char(1) NULL,
   TDummy2 char(1) NULL,
   TDummy3 char(1) NULL,
   Under_2_A numeric(10,2) NULL,
   Under_2_B numeric(10,2) NULL,
   Under_2_E numeric(10,2) NULL,
   Mid_2_25_A numeric(10,2) NULL,
   Mid_2_25_B numeric(10,2) NULL,
   Mid_2_25_E numeric(10,2) NULL,
   Mid_25_3_A numeric(10,2) NULL,
   Mid_25_3_B numeric(10,2) NULL,
   Mid_25_3_E numeric(10,2) NULL,
   Mid_3_35_A numeric(10,2) NULL,
   Mid_3_35_B numeric(10,2) NULL,
   Mid_3_35_E numeric(10,2) NULL,
   Mid_35_4_A numeric(10,2) NULL,
   Mid_35_4_B numeric(10,2) NULL,
   Mid_35_4_E numeric(10,2) NULL,
   High_4_A numeric(10,2) NULL,
   High_4_B numeric(10,2) NULL,
   High_4_E numeric(10,2) NULL,
   High_5_A numeric(10,2) NULL,
   High_5_B numeric(10,2) NULL,
   High_5_E numeric(10,2) NULL,
   GST_A numeric(10,2) NULL,
   GST_B numeric(10,2) NULL,
   GST_E numeric(10,2) NULL,
   Comment varchar(200) NULL,
   Payment_Terms varchar(30) NULL,
   TDummy4 char(1) NULL,
   TDummy5 char(1) NULL,
   TDummy6 char(1) NULL,
   TDummy7 char(1) NULL,
   Fish_Size_Class_1 varchar(20) NULL,
   HS_Price_1 numeric(10,2) NULL,
   HSV_Price_1 numeric(10,2) NULL,
   HSE_Price_1 numeric(10,2) NULL,
   Fish_Size_Class_2 varchar(20) NULL,
   HS_Price_2 numeric(10,2) NULL,
   HSV_Price_2 numeric(10,2) NULL,
   HSE_Price_2 numeric(10,2) NULL,
   Fish_Size_Class_3 varchar(20) NULL,
   HS_Price_3 numeric(10,2) NULL,
   HSV_Price_3 numeric(10,2) NULL,
   HSE_Price_3 numeric(10,2) NULL,
   Fish_Size_Class_4 varchar(20) NULL,
   HS_Price_4 numeric(10,2) NULL,
   HSV_Price_4 numeric(10,2) NULL,
   HSE_Price_4 numeric(10,2) NULL,
   Fish_Size_Class_5 varchar(20) NULL,
   HS_Price_5 numeric(10,2) NULL,
   HSV_Price_5 numeric(10,2) NULL,
   HSE_Price_5 numeric(10,2) NULL,
   GST_Rate numeric(10,2) NULL,
   Inactive_Date varchar(10) NULL,
   TTitle1 char(1) NULL,
   TDummy9 char(1) NULL,
   TDummy10 char(1) NULL,
   TDummy11 char(1) NULL,
   Under_2_A_OFF numeric(10,2) NULL,
   Under_2_B_OFF numeric(10,2) NULL,
   Under_2_E_OFF numeric(10,2) NULL,
   Mid_2_25_A_OFF numeric(10,2) NULL,
   Mid_2_25_B_OFF numeric(10,2) NULL,
   Mid_2_25_E_OFF numeric(10,2) NULL,
   Mid_25_3_A_OFF numeric(10,2) NULL,
   Mid_25_3_B_OFF numeric(10,2) NULL,
   Mid_25_3_E_OFF numeric(10,2) NULL,
   Mid_3_35_A_OFF numeric(10,2) NULL,
   Mid_3_35_B_OFF numeric(10,2) NULL,
   Mid_3_35_E_OFF numeric(10,2) NULL,
   Mid_35_4_A_OFF numeric(10,2) NULL,
   Mid_35_4_B_OFF numeric(10,2) NULL,
   Mid_35_4_E_OFF numeric(10,2) NULL,
   High_4_A_OFF numeric(10,2) NULL,
   High_4_B_OFF numeric(10,2) NULL,
   High_4_E_OFF numeric(10,2) NULL,
   High_5_A_OFF numeric(10,2) NULL,
   High_5_B_OFF numeric(10,2) NULL,
   High_5_E_OFF numeric(10,2) NULL,
   TTitle11 char(1) NULL,
   TTitle12 char(1) NULL,
   TTitle13 char(1) NULL,
   TTitle14 char(1) NULL,
   Fish_Size_Class_1_OFF varchar(20) NULL,
   HS_Price_1_OFF numeric(10,2) NULL,
   HSV_Price_1_OFF numeric(10,2) NULL,
   HSE_Price_1_OFF numeric(10,2) NULL,
   Fish_Size_Class_2_OFF varchar(20) NULL,
   HS_Price_2_OFF numeric(10,2) NULL,
   HSV_Price_2_OFF numeric(10,2) NULL,
   HSE_Price_2_OFF numeric(10,2) NULL,
   Fish_Size_Class_3_OFF varchar(20) NULL,
   HS_Price_3_OFF numeric(10,2) NULL,
   HSV_Price_3_OFF numeric(10,2) NULL,
   HSE_Price_3_OFF numeric(10,2) NULL,
   Fish_Size_Class_4_OFF varchar(20) NULL,
   HS_Price_4_OFF numeric(10,2) NULL,
   HSV_Price_4_OFF numeric(10,2) NULL,
   HSE_Price_4_OFF numeric(10,2) NULL,
   Fish_Size_Class_5_OFF varchar(20) NULL,
   HS_Price_5_OFF numeric(10,2) NULL,
   HSV_Price_5_OFF numeric(10,2) NULL,
   HSE_Price_5_OFF numeric(10,2) NULL,
   TTitle15 char(1) NULL,
   TTitle16 char(1) NULL,
   TTitle17 char(1) NULL,
   TTitle18 char(1) NULL,
   Fish_Size_Class_1_BY varchar(20) NULL,
   HS_Price_1_BY numeric(10,2) NULL,
   HSV_Price_1_BY numeric(10,2) NULL,
   HSE_Price_1_BY numeric(10,2) NULL,
   Fish_Size_Class_2_BY varchar(20) NULL,
   HS_Price_2_BY numeric(10,2) NULL,
   HSV_Price_2_BY numeric(10,2) NULL,
   HSE_Price_2_BY numeric(10,2) NULL,
   Fish_Size_Class_3_BY varchar(20) NULL,
   HS_Price_3_BY numeric(10,2) NULL,
   HSV_Price_3_BY numeric(10,2) NULL,
   HSE_Price_3_BY numeric(10,2) NULL,
   Fish_Size_Class_4_BY varchar(20) NULL,
   HS_Price_4_BY numeric(10,2) NULL,
   HSV_Price_4_BY numeric(10,2) NULL,
   HSE_Price_4_BY numeric(10,2) NULL,
   Fish_Size_Class_5_BY varchar(20) NULL,
   HS_Price_5_BY numeric(10,2) NULL,
   HSV_Price_5_BY numeric(10,2) NULL,
   HSE_Price_5_BY numeric(10,2) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Pricing_Customer_Name ON Pricing (Customer_Name,Price_Date,Description);

DROP TABLE Process_Consignment;

CREATE TABLE Process_Consignment (
   Company_Name varchar(30) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Fish_Species varchar(20) NOT NULL,
   Consignment_Note varchar(20) NOT NULL,
   Consignment_Date varchar(10) NOT NULL,
   Deliver_To_Name varchar(30) NOT NULL,
   Customer_Scanner_Name varchar(30) NULL,
   Total_Weight numeric(10,2) NOT NULL,
   Total_Cartons integer NOT NULL,
   Total_Pallets integer NOT NULL,
   Carrier_Name varchar(30) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Process_Consignment_Company_Name ON Process_Consignment (Company_Name,Delivered_Date,Delivered_Time,Harvest_Ref_No,Fish_Species,Consignment_Note,Consignment_Date,Deliver_To_Name);

CREATE INDEX Process_Consignment_Carrier_Name ON Process_Consignment (Carrier_Name);

DROP TABLE Process_Item;

CREATE TABLE Process_Item (
   Company_Name varchar(30) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Customer_Name varchar(30) NOT NULL,
   Customer_Scanner_Name varchar(30) NULL,
   Fish_Species varchar(20) NOT NULL,
   Carton_Serial_No integer NOT NULL,
   Grade_Type varchar(5) NOT NULL,
   Grade_Weight_Range varchar(20) NOT NULL,
   Fish_No integer NOT NULL,
   Total_Weight numeric(10,2) NOT NULL,
   Order_No varchar(20) NULL,
   Batch_No varchar(30) NULL,
   Pallet_No varchar(20) NULL,
   Process_Type varchar(20) NULL,
   Bin_No varchar(20) NULL,
   Destination_Customer varchar(30) NULL,
   Dest_Scanner_Name varchar(30) NULL
);

CREATE UNIQUE CLUSTERED INDEX Process_Item_Company_Name ON Process_Item (Company_Name,Delivered_Date,Delivered_Time,Harvest_Ref_No,Fish_Species,Carton_Serial_No,Grade_Type,Grade_Weight_Range);

CREATE INDEX Process_Item_Customer_Name ON Process_Item (Customer_Name);

CREATE INDEX Process_Item_Process_Type ON Process_Item (Process_Type);

CREATE INDEX Process_Item_Destination_Customer ON Process_Item (Destination_Customer);

DROP TABLE Process_Type;

CREATE TABLE Process_Type (
   Process_Name varchar(20) NOT NULL,
   Scanner_Default varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Process_Type_Process_Name ON Process_Type (Process_Name);

DROP TABLE Product_Delivery;

CREATE TABLE Product_Delivery (
   Company_Name varchar(30) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Fish_Species varchar(20) NOT NULL,
   No_of_Fish integer NOT NULL,
   Total_Weight numeric(10,2) NULL,
   No_of_Bins integer NULL,
   Comment varchar(128) NULL,
   Suppliers_Ref_No varchar(20) NULL,
   Process_Date varchar(10) NULL,
   Process_Invoice_No varchar(20) NULL,
   Process_Inv_Amt numeric(10,2) NULL,
   Transport_Invoice_No varchar(20) NULL,
   Transport_Inv_Amt numeric(10,2) NULL,
   Scanner_Ref_No varchar(20) NULL,
   Frz_Weight varchar(6) NULL
);

CREATE UNIQUE CLUSTERED INDEX Product_Delivery_Company_Name ON Product_Delivery (Company_Name,Delivered_Date,Delivered_Time,Harvest_Ref_No,Fish_Species);

DROP TABLE Product_Delivery_Customer;

CREATE TABLE Product_Delivery_Customer (
   Company_Name varchar(30) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Customer_Name varchar(30) NOT NULL,
   Customer_Scanner_Name varchar(30) NOT NULL,
   Fish_Species varchar(20) NOT NULL,
   Order_No varchar(20) NULL,
   Batch_No varchar(30) NULL,
   Comment varchar(128) NULL,
   Destination_Customer varchar(30) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Product_Delivery_Customer_Company_Name ON Product_Delivery_Customer (Company_Name,Delivered_Date,Delivered_Time,Harvest_Ref_No,Customer_Name,Customer_Scanner_Name,Fish_Species);

CREATE INDEX Product_Delivery_Customer_Destination_Customer ON Product_Delivery_Customer (Destination_Customer);

DROP TABLE Product_Size;

CREATE TABLE Product_Size (
   Prod_Size varchar(10) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Product_Size_Prod_Size ON Product_Size (Prod_Size);

DROP TABLE Report_Option;

CREATE TABLE Report_Option (
   Report_Code integer NOT NULL,
   Water_Temp numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Report_Option_Report_Code ON Report_Option (Report_Code);

CREATE INDEX Report_Option_Water_Temp ON Report_Option (Water_Temp);

DROP TABLE Report_Options;

CREATE TABLE Report_Options (
   Record_Id integer NOT NULL,
   Add_Title varchar(4) NOT NULL,
   Company_Details varchar(4) NOT NULL,
   Zeros varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Report_Options_Record_Id ON Report_Options (Record_Id);

DROP TABLE Run_Button;

CREATE TABLE Run_Button (
   Table_Name varchar(50) NOT NULL,
   Button_No integer NOT NULL,
   Run_Command varchar(120) NOT NULL,
   Common varchar(4) NOT NULL,
   Description varchar(60) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Run_Button_Table_Name ON Run_Button (Table_Name,Button_No,Run_Command);

DROP TABLE SeqNum;

CREATE TABLE SeqNum (
   tablename varchar(30) NOT NULL,
   nextid integer NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX SeqNum_tablename ON SeqNum (tablename);

DROP TABLE Site_Comment;

CREATE TABLE Site_Comment (
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(20) NOT NULL,
   Site_Abbrev_Name varchar(3) NOT NULL,
   Comment_Date varchar(10) NOT NULL,
   Comment_Time varchar(10) NOT NULL,
   Item_Type varchar(20) NULL,
   Comment varchar(200) NOT NULL,
   Staff_Name varchar(20) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Site_Comment_Company_Name ON Site_Comment (Company_Name,Site_Name,Comment_Date,Comment_Time);

CREATE INDEX Site_Comment_Item_Type ON Site_Comment (Item_Type);

CREATE INDEX Site_Comment_Staff_Name ON Site_Comment (Staff_Name);

DROP TABLE Site_Location;

CREATE TABLE Site_Location (
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(20) NOT NULL,
   Site_Abbrev_Name varchar(3) NOT NULL,
   Contact varchar(30) NULL,
   Address varchar(50) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL,
   Mooring_System varchar(30) NULL,
   Date_Installed varchar(10) NULL,
   Manufactured_By varchar(30) NULL,
   Installed_By varchar(30) NULL,
   Map_Location varchar(50) NULL
);

CREATE UNIQUE CLUSTERED INDEX Site_Location_Company_Name ON Site_Location (Company_Name,Site_Name);

CREATE INDEX Site_Location_Date_Installed ON Site_Location (Date_Installed);

DROP TABLE Staff;

CREATE TABLE Staff (
   Name varchar(20) NOT NULL,
   Home_No varchar(15) NULL,
   Mobile_No varchar(20) NULL,
   Address varchar(40) NULL,
   Emergency_Name varchar(20) NULL,
   Em_Home_Ph varchar(15) NULL,
   Em_Work_Ph varchar(15) NULL,
   Emerg_Mobile_No varchar(15) NULL,
   Emg_Relationship varchar(15) NULL,
   Email varchar(40) NULL
);

CREATE UNIQUE CLUSTERED INDEX Staff_Name ON Staff (Name);

DROP TABLE Staff_Position;

CREATE TABLE Staff_Position (
   Staff_Name varchar(30) NOT NULL,
   Position_Held varchar(30) NOT NULL,
   Date_Joined varchar(10) NOT NULL,
   Transfer_Date varchar(10) NULL
);

CREATE UNIQUE CLUSTERED INDEX Staff_Position_Staff_Name ON Staff_Position (Staff_Name,Position_Held,Date_Joined);

DROP TABLE Stock_Density;

CREATE TABLE Stock_Density (
   Name varchar(20) NOT NULL,
   Jan integer NULL,
   Feb integer NULL,
   Mar integer NULL,
   Apr integer NULL,
   May integer NULL,
   Jun integer NULL,
   Jul integer NULL,
   Aug integer NULL,
   Sep integer NULL,
   Oct integer NULL,
   Nov integer NULL,
   December integer NULL
);

CREATE UNIQUE CLUSTERED INDEX Stock_Density_Name ON Stock_Density (Name);

DROP TABLE Stock_Item;

CREATE TABLE Stock_Item (
   Stock_Name varchar(40) NOT NULL,
   Item_Type_Name varchar(20) NOT NULL,
   Specie_Name varchar(20) NULL,
   Serial_No varchar(30) NULL,
   Product_Size varchar(10) NULL,
   Package_Size varchar(10) NULL,
   Package_Type varchar(10) NULL,
   Product_Length varchar(10) NULL,
   Sink_Rate numeric(10,2) NULL,
   Head_Code varchar(10) NULL,
   Stocktake numeric(10,2) NULL,
   Last_Stocktake numeric(10,2) NULL,
   Cost_Price numeric(10,2) NULL,
   Comment varchar(200) NULL,
   Fat_gm numeric(10,2) NULL,
   Protein numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Stock_Item_Stock_Name ON Stock_Item (Stock_Name,Item_Type_Name);

CREATE INDEX Stock_Item_Specie_Name ON Stock_Item (Specie_Name);

CREATE INDEX Stock_Item_Product_Size ON Stock_Item (Product_Size);

CREATE INDEX Stock_Item_Package_Size ON Stock_Item (Package_Size);

CREATE INDEX Stock_Item_Package_Type ON Stock_Item (Package_Type);

DROP TABLE Stripping;

CREATE TABLE Stripping (
   Fish_Id varchar(6) NOT NULL,
   Stripping_Date varchar(10) NOT NULL,
   Fish_No integer NOT NULL,
   Total_Eggs integer NOT NULL,
   Avg_Size numeric(10,2) NULL,
   Staff_Name varchar(20) NOT NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Stripping_Fish_Id ON Stripping (Fish_Id,Stripping_Date);

CREATE INDEX Stripping_Staff_Name ON Stripping (Staff_Name);

DROP TABLE Supplier;

CREATE TABLE Supplier (
   Name varchar(30) NOT NULL,
   Contact varchar(30) NULL,
   Address varchar(50) NULL,
   Suburb varchar(30) NULL,
   State varchar(10) NULL,
   Postcode numeric(6,0) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Email varchar(50) NULL,
   Sales_Tax varchar(10) NULL,
   ABN_No varchar(20) NULL,
   ACN_No varchar(20) NULL,
   Comment varchar(200) NULL,
   Web_Site varchar(40) NULL
);

CREATE UNIQUE CLUSTERED INDEX Supplier_Name ON Supplier (Name);

DROP TABLE Supplier_Stock_Item;

CREATE TABLE Supplier_Stock_Item (
   Supplier_Name varchar(30) NOT NULL,
   Stock_Name varchar(40) NOT NULL,
   Stock_Item_Type varchar(20) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Supplier_Stock_Item_Supplier_Name ON Supplier_Stock_Item (Supplier_Name,Stock_Name);

CREATE INDEX Supplier_Stock_Item_Stock_Item_Type ON Supplier_Stock_Item (Stock_Item_Type);

DROP TABLE Swim_Thru;

CREATE TABLE Swim_Thru (
   Job_No integer NOT NULL,
   Date_Swim_Thru varchar(10) NOT NULL,
   Source_Fish_Id varchar(10) NOT NULL,
   Source_Cage_Id varchar(10) NULL,
   Src_Date_Assigned varchar(10) NOT NULL,
   Est_Fish_Swum_Off integer NOT NULL,
   New_Fish_Id varchar(10) NULL,
   New_Cage_Size varchar(10) NULL,
   Dest_Fish_Id varchar(10) NULL,
   Dest_Cage_Id varchar(10) NULL,
   Dest_Date_Assigned varchar(10) NULL,
   No_Fish_Swum_Off integer NULL,
   Reason_For_Swim_Thru varchar(100) NULL,
   Leading_Hand_Name varchar(20) NOT NULL,
   Wind_Speed varchar(10) NULL,
   Wind_Direction varchar(10) NULL,
   Sea_Height varchar(10) NULL,
   Tide varchar(10) NULL,
   Water_Visibility varchar(10) NULL,
   Job_Time integer NULL,
   Comment varchar(200) NULL,
   Src_Fish_Count integer NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Swim_Thru_Job_No ON Swim_Thru (Job_No,Date_Swim_Thru,Source_Fish_Id);

CREATE INDEX Swim_Thru_Source_Cage_Id ON Swim_Thru (Source_Cage_Id);

CREATE INDEX Swim_Thru_Dest_Fish_Id ON Swim_Thru (Dest_Fish_Id);

CREATE INDEX Swim_Thru_Dest_Cage_Id ON Swim_Thru (Dest_Cage_Id);

CREATE INDEX Swim_Thru_Leading_Hand_Name ON Swim_Thru (Leading_Hand_Name);

DROP TABLE Temperature;

CREATE TABLE Temperature (
   Temp_Year integer NOT NULL,
   Company_Name varchar(30) NOT NULL,
   Site_Name varchar(20) NOT NULL,
   Jan numeric(3,1) NULL,
   Feb numeric(3,1) NULL,
   Mar numeric(3,1) NULL,
   Apr numeric(3,1) NULL,
   May numeric(3,1) NULL,
   Jun numeric(3,1) NULL,
   Jul numeric(3,1) NULL,
   Aug numeric(3,1) NULL,
   Sep numeric(3,1) NULL,
   Oct numeric(3,1) NULL,
   Nov numeric(3,1) NULL,
   December numeric(3,1) NULL
);

CREATE UNIQUE CLUSTERED INDEX Temperature_Temp_Year ON Temperature (Temp_Year,Company_Name,Site_Name);

DROP TABLE Towing;

CREATE TABLE Towing (
   Job_No integer NOT NULL,
   Fish_Id varchar(10) NOT NULL,
   Date_Moved varchar(10) NOT NULL,
   Tow_Type_Name varchar(20) NULL,
   Weather_Forecast varchar(80) NULL,
   Wind_Speed varchar(10) NULL,
   Wind_Direction varchar(10) NULL,
   Other_Job_No varchar(20) NULL,
   Job_Assigned_Name varchar(20) NOT NULL,
   Cage_in_location varchar(5) NULL,
   Cage_not_location varchar(20) NULL,
   Was_Weather_Correct varchar(5) NULL,
   Weather_Not_Correct varchar(60) NULL,
   Vessel_Name varchar(20) NULL,
   Skipper_Name varchar(20) NULL,
   Deck_Hand_Name varchar(20) NULL,
   Dep_Time varchar(8) NULL,
   Arrv_Time varchar(8) NULL,
   Comment varchar(200) NULL,
   Archive varchar(4) NULL
);

CREATE UNIQUE CLUSTERED INDEX Towing_Job_No ON Towing (Job_No);

CREATE INDEX Towing_Fish_Id ON Towing (Fish_Id);

CREATE INDEX Towing_Date_Moved ON Towing (Date_Moved);

CREATE INDEX Towing_Tow_Type_Name ON Towing (Tow_Type_Name);

CREATE INDEX Towing_Job_Assigned_Name ON Towing (Job_Assigned_Name);

CREATE INDEX Towing_Vessel_Name ON Towing (Vessel_Name);

CREATE INDEX Towing_Skipper_Name ON Towing (Skipper_Name);

CREATE INDEX Towing_Deck_Hand_Name ON Towing (Deck_Hand_Name);

DROP TABLE Tow_Check;

CREATE TABLE Tow_Check (
   Tow_Check_No integer NOT NULL,
   Job_No varchar(10) NOT NULL,
   Time_Check varchar(8) NOT NULL,
   Staff_Name varchar(20) NOT NULL,
   Net varchar(20) NULL,
   Fish varchar(20) NULL,
   Wind_Speed varchar(20) NULL,
   Tide varchar(20) NULL,
   Comments varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Tow_Check_Tow_Check_No ON Tow_Check (Tow_Check_No,Job_No);

CREATE INDEX Tow_Check_Staff_Name ON Tow_Check (Staff_Name);

DROP TABLE Tow_Type;

CREATE TABLE Tow_Type (
   Name varchar(20) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Tow_Type_Name ON Tow_Type (Name);

DROP TABLE URIGHTS;

CREATE TABLE URIGHTS (
   USER_ID varchar(30) NOT NULL,
   TABLE_NAME varchar(50) NOT NULL,
   USTORE varchar(4) NOT NULL,
   UDELETE varchar(4) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX URIGHTS_USER_ID ON URIGHTS (USER_ID,TABLE_NAME);

DROP TABLE USERIDS;

CREATE TABLE USERIDS (
   USER_ID varchar(30) NOT NULL,
   NPASSWORD varchar(30) NOT NULL,
   Staff_Name varchar(20) NOT NULL,
   Start_up_file varchar(128) NULL,
   User_Status varchar(10) NULL,
   INI_File varchar(128) NULL,
   On_Exit_Run varchar(128) NULL
);

CREATE UNIQUE CLUSTERED INDEX USERIDS_USER_ID ON USERIDS (USER_ID);

CREATE INDEX USERIDS_Staff_Name ON USERIDS (Staff_Name);

DROP TABLE User_Menu;

CREATE TABLE User_Menu (
   USER_ID varchar(30) NOT NULL,
   Menu_Name varchar(15) NOT NULL,
   Menu_Item varchar(120) NOT NULL,
   Menu_Item_Name varchar(15) NOT NULL,
   Menu_Item_Name_Item varchar(120) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX User_Menu_USER_ID ON User_Menu (USER_ID,Menu_Name,Menu_Item,Menu_Item_Name,Menu_Item_Name_Item);

DROP TABLE User_Preferences;

CREATE TABLE User_Preferences (
   USER_ID varchar(30) NOT NULL,
   Pref_Name varchar(60) NOT NULL,
   Pref_Setting varchar(128) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX User_Preferences_USER_ID ON User_Preferences (USER_ID,Pref_Name);

DROP TABLE User_Run_Button;

CREATE TABLE User_Run_Button (
   USER_ID varchar(30) NOT NULL,
   Table_Name varchar(50) NOT NULL,
   Button_No integer NOT NULL,
   Run_Command varchar(120) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX User_Run_Button_USER_ID ON User_Run_Button (USER_ID,Table_Name,Button_No,Run_Command);

DROP TABLE UTABLES;

CREATE TABLE UTABLES (
   TABLE_NAME varchar(50) NOT NULL,
   Screen_Name varchar(60) NULL
);

CREATE UNIQUE CLUSTERED INDEX UTABLES_TABLE_NAME ON UTABLES (TABLE_NAME);

DROP TABLE Vaps_Fish_Sale_Item;

CREATE TABLE Vaps_Fish_Sale_Item (
   Name varchar(30) NOT NULL,
   Cust_Order_No varchar(15) NOT NULL,
   Order_Date varchar(10) NOT NULL,
   Order_Item varchar(20) NOT NULL,
   Tdummy1 char(1) NULL,
   Tdummy2 char(1) NULL,
   Tdummy3 char(1) NULL,
   Fish_Category_Name_1 varchar(20) NULL,
   No_Cartons_1 integer NULL,
   Comments_1 varchar(80) NULL,
   Fish_Category_Name_2 varchar(20) NULL,
   No_Cartons_2 integer NULL,
   Comments_2 varchar(80) NULL,
   Fish_Category_Name_3 varchar(20) NULL,
   No_Cartons_3 integer NULL,
   Comments_3 varchar(80) NULL,
   Fish_Category_Name_4 varchar(20) NULL,
   No_Cartons_4 integer NULL,
   Comments_4 varchar(80) NULL,
   Fish_Category_Name_5 varchar(20) NULL,
   No_Cartons_5 integer NULL,
   Comments_5 varchar(80) NULL
);

CREATE UNIQUE CLUSTERED INDEX Vaps_Fish_Sale_Item_Name ON Vaps_Fish_Sale_Item (Name,Cust_Order_No,Order_Date,Order_Item);

DROP TABLE Vessel;

CREATE TABLE Vessel (
   Name varchar(20) NOT NULL,
   Owner varchar(30) NULL,
   Address varchar(50) NULL,
   Suburb varchar(30) NULL,
   Phone varchar(15) NULL,
   Fax varchar(15) NULL,
   Date_Built varchar(10) NULL,
   Length numeric(5,1) NULL,
   Outboard_Serial_1 varchar(30) NULL,
   Outboard_Serial_2 varchar(30) NULL,
   Cost_Price numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Vessel_Name ON Vessel (Name);

CREATE INDEX Vessel_Date_Built ON Vessel (Date_Built);

DROP TABLE Process_Assist_Spares;

CREATE TABLE Process_Assist_Spares (
   Company_Name varchar(30) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Customer_Name varchar(30) NOT NULL,
   Customer_Scanner_Name varchar(30) NULL,
   Fish_Species varchar(20) NOT NULL,
   Carton_Serial_No integer NOT NULL,
   Grade_Type varchar(5) NOT NULL,
   Grade_Weight_Range varchar(20) NOT NULL,
   Fish_No integer NOT NULL,
   Total_Weight numeric(10,2) NOT NULL,
   Order_No varchar(20) NULL,
   Batch_No varchar(30) NULL,
   Pallet_No varchar(20) NULL,
   Process_Type varchar(20) NULL,
   Bin_No varchar(20) NULL,
   Destination_Customer varchar(30) NULL,
   Dest_Scanner_Name varchar(30) NULL
);

CREATE UNIQUE CLUSTERED INDEX Process_Assist_Spares_Company_Name ON Process_Assist_Spares (Company_Name,Delivered_Date,Delivered_Time,Harvest_Ref_No,Fish_Species,Carton_Serial_No,Grade_Type,Grade_Weight_Range);

CREATE INDEX Process_Assist_Spares_Customer_Name ON Process_Assist_Spares (Customer_Name);

CREATE INDEX Process_Assist_Spares_Process_Type ON Process_Assist_Spares (Process_Type);

CREATE INDEX Process_Assist_Spares_Destination_Customer ON Process_Assist_Spares (Destination_Customer);

DROP TABLE Proc_Assist_Alloc_Spares;

CREATE TABLE Proc_Assist_Alloc_Spares (
   Company_Name varchar(30) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Customer_Name varchar(30) NOT NULL,
   Customer_Scanner_Name varchar(30) NULL,
   Fish_Species varchar(20) NOT NULL,
   Carton_Serial_No integer NOT NULL,
   Grade_Type varchar(5) NOT NULL,
   Grade_Weight_Range varchar(20) NOT NULL,
   Fish_No integer NOT NULL,
   Total_Weight numeric(10,2) NOT NULL,
   Order_No varchar(20) NULL,
   Batch_No varchar(30) NULL,
   Pallet_No varchar(20) NULL,
   Process_Type varchar(20) NULL,
   Bin_No varchar(20) NULL,
   Destination_Customer varchar(30) NULL,
   Dest_Scanner_Name varchar(30) NULL
);

CREATE UNIQUE CLUSTERED INDEX Proc_Assist_Alloc_Spares_Company_Name ON Proc_Assist_Alloc_Spares (Company_Name,Delivered_Date,Delivered_Time,Harvest_Ref_No,Fish_Species,Carton_Serial_No,Grade_Type,Grade_Weight_Range);

CREATE INDEX Proc_Assist_Alloc_Spares_Customer_Name ON Proc_Assist_Alloc_Spares (Customer_Name);

CREATE INDEX Proc_Assist_Alloc_Spares_Process_Type ON Proc_Assist_Alloc_Spares (Process_Type);

CREATE INDEX Proc_Assist_Alloc_Spares_Destination_Customer ON Proc_Assist_Alloc_Spares (Destination_Customer);

DROP TABLE Process_Assist_Frozen_Stock;

CREATE TABLE Process_Assist_Frozen_Stock (
   Company_Name varchar(30) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Fish_Species varchar(20) NOT NULL,
   Frozen_Ref_No varchar(20) NOT NULL,
   Frozen_down_date varchar(10) NOT NULL,
   Fish_No integer NOT NULL,
   Biomass numeric(10,2) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Process_Assist_Frozen_Stock_Company_Name ON Process_Assist_Frozen_Stock (Company_Name,Delivered_Date,Delivered_Time,Harvest_Ref_No,Fish_Species,Frozen_Ref_No,Frozen_down_date);

DROP TABLE Frozen_Stock_Item;

CREATE TABLE Frozen_Stock_Item (
   Company_Name varchar(30) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Fish_Species varchar(20) NOT NULL,
   Frozen_Ref_No varchar(20) NOT NULL,
   Frozen_down_date varchar(10) NOT NULL,
   Bin_No varchar(20) NOT NULL,
   Frozen_Date varchar(10) NOT NULL,
   Adjust_Fish_No integer NULL,
   Adjust_Bin_Weight numeric(10,2) NULL
);

CREATE UNIQUE CLUSTERED INDEX Frozen_Stock_Item_Company_Name ON Frozen_Stock_Item (Company_Name,Delivered_Date,Delivered_Time,Harvest_Ref_No,Fish_Species,Frozen_Ref_No,Frozen_down_date,Bin_No,Frozen_Date);

DROP TABLE Frozen_Bin_No;

CREATE TABLE Frozen_Bin_No (
   Bin_No varchar(20) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Frozen_Bin_No_Bin_No ON Frozen_Bin_No (Bin_No);

DROP TABLE Frozen_Stock_Into_Freezer;

CREATE TABLE Frozen_Stock_Into_Freezer (
   Company_Name varchar(30) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Fish_Species varchar(20) NOT NULL,
   Frozen_Ref_No varchar(20) NOT NULL,
   Frozen_down_date varchar(10) NOT NULL,
   Bin_No varchar(20) NOT NULL,
   Frozen_Date varchar(10) NOT NULL,
   Grade_Type varchar(15) NOT NULL,
   Grade_Weight_Range varchar(20) NOT NULL,
   Gut_Status varchar(10) NOT NULL,
   Fish_No integer NOT NULL,
   Total_Weight numeric(10,2) NOT NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Frozen_Stock_Into_Freezer_Company_Name ON Frozen_Stock_Into_Freezer (Company_Name,Delivered_Date,Delivered_Time,Harvest_Ref_No,Fish_Species,Frozen_Ref_No,Frozen_down_date,Bin_No,Frozen_Date,Grade_Type,Grade_Weight_Range);

DROP TABLE Frozen_Stock_Despatch;

CREATE TABLE Frozen_Stock_Despatch (
   Company_Name varchar(30) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Fish_Species varchar(20) NOT NULL,
   Frozen_Ref_No varchar(20) NOT NULL,
   Frozen_down_date varchar(10) NOT NULL,
   Bin_No varchar(20) NOT NULL,
   Frozen_Date varchar(10) NOT NULL,
   Grade_Type varchar(15) NOT NULL,
   Grade_Weight_Range varchar(20) NOT NULL,
   Customer_Name varchar(30) NOT NULL,
   Pallet_No varchar(20) NOT NULL,
   Fish_No integer NOT NULL,
   Total_Weight numeric(10,2) NOT NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Frozen_Stock_Despatch_Company_Name ON Frozen_Stock_Despatch (Company_Name,Delivered_Date,Delivered_Time,Harvest_Ref_No,Fish_Species,Frozen_Ref_No,Frozen_down_date,Bin_No,Frozen_Date,Grade_Type,Grade_Weight_Range,Customer_Name,Pallet_No);

DROP TABLE Frozen_Value_Added;

CREATE TABLE Frozen_Value_Added (
   Company_Name varchar(30) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Fish_Species varchar(20) NOT NULL,
   Value_Ref_No varchar(20) NOT NULL,
   Fish_No integer NOT NULL,
   Value_Biomass numeric(10,2) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Frozen_Value_Added_Company_Name ON Frozen_Value_Added (Company_Name,Delivered_Date,Delivered_Time,Harvest_Ref_No,Fish_Species,Value_Ref_No);

DROP TABLE Value_Added_Despatch;

CREATE TABLE Value_Added_Despatch (
   Company_Name varchar(30) NOT NULL,
   Delivered_Date varchar(10) NOT NULL,
   Delivered_Time varchar(8) NOT NULL,
   Harvest_Ref_No varchar(20) NOT NULL,
   Fish_Species varchar(20) NOT NULL,
   Value_Ref_No varchar(20) NOT NULL,
   Customer_Name varchar(30) NOT NULL,
   Pallet_No varchar(20) NOT NULL,
   Fish_No integer NOT NULL,
   Total_Weight numeric(10,2) NOT NULL,
   Comment varchar(200) NULL
);

CREATE UNIQUE CLUSTERED INDEX Value_Added_Despatch_Company_Name ON Value_Added_Despatch (Company_Name,Delivered_Date,Delivered_Time,Harvest_Ref_No,Fish_Species,Value_Ref_No,Customer_Name,Pallet_No);

DROP TABLE Feed_Moved;

CREATE TABLE Feed_Moved (
   Feed_Move_Date varchar(10) NOT NULL,
   From_Company_Name varchar(30) NOT NULL,
   From_Site_Name varchar(20) NOT NULL,
   Del_Docket_No varchar(20) NOT NULL,
   Supplier_Name varchar(30) NOT NULL,
   Feed_Name varchar(40) NOT NULL,
   To_Company_Name varchar(30) NOT NULL,
   To_Site_Name varchar(20) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Moved_Feed_Move_Date ON Feed_Moved (Feed_Move_Date,From_Company_Name,From_Site_Name,Del_Docket_No,Supplier_Name,Feed_Name,To_Company_Name,To_Site_Name);

DROP TABLE Feed_Moved_Invoice;

CREATE TABLE Feed_Moved_Invoice (
   Feed_Move_Date varchar(10) NOT NULL,
   From_Company_Name varchar(30) NOT NULL,
   From_Site_Name varchar(20) NOT NULL,
   Del_Docket_No varchar(20) NOT NULL,
   Supplier_Name varchar(30) NOT NULL,
   Feed_Name varchar(40) NOT NULL,
   To_Company_Name varchar(30) NOT NULL,
   To_Site_Name varchar(20) NOT NULL,
   Date_Invoice varchar(10) NOT NULL,
   Invoice_No varchar(20) NOT NULL,
   Qty_Feed numeric(10,2) NOT NULL,
   Invoice_Price numeric(10,2) NOT NULL
);

CREATE UNIQUE CLUSTERED INDEX Feed_Moved_Invoice_Feed_Move_Date ON Feed_Moved_Invoice (Feed_Move_Date,From_Company_Name,From_Site_Name,Del_Docket_No,Supplier_Name,Feed_Name,To_Company_Name,To_Site_Name,Date_Invoice,Invoice_No);

